@@ -69,6 +69,22 @@ public class SQLRCursor {
 	public native void	cacheOff();
 
 
+	/** Sends a query that returns a list of
+	 *  databases/schemas matching "wild".  If wild is empty
+	 *  or NULL then a list of all databases/schemas will be
+	 *  returned. */
+	public native boolean	getDatabaseList(String wild);
+	/** Sends a query that returns a list of tables
+	 *  matching "wild".  If wild is empty or NULL then
+	 *  a list of all tables will be returned. */
+	public native boolean	getTableList(String wild);
+	/** Sends a query that returns a list of columns
+	 *  in the table specified by the "table" parameter
+	 *  matching "wild".  If wild is empty or NULL then
+	 *  a list of all columns will be returned. */
+	public native boolean	getColumnList(String table, String wild);
+
+
 	/** Sends "query" and gets a result set.  */
 	public native boolean	sendQuery(String query);
 	/** Sends the query in file "path"/"filename" 
@@ -110,8 +126,15 @@ public class SQLRCursor {
 	/** Define an input bind variable.  */
 	public native void	inputBind(String variable, String value);
 	/** Define an input bind variable.  */
-	public native void	inputBind(String variable, long value);
+	public native void	inputBind(String variable,
+						String value, int length);
 	/** Define an input bind variable.  */
+	public native void	inputBind(String variable, long value);
+	/** Define an input bind variable.
+	  * (If you don't have the precision and scale then they may
+	  * both be set to 0.  However in that case you may get
+	  * unexpected rounding behavior if the server is faking
+	  * binds.) */
 	public native void	inputBind(String variable, double value, 
 					int precision, int scale);
 	/** Define an input bind variable.  */
@@ -252,9 +275,15 @@ public class SQLRCursor {
 	/** If a query failed and generated an error, 
 	 *  the error message is available here.  If 
 	 *  the query succeeded then this method 
-	 *  returns a NULL.  */
+	 *  returns NULL.  */
 	public native String	errorMessage();
 
+	/** If a query failed and generated an
+	 *  error, the error number is available here.
+	 *  If there is no error then this method 
+	 *  returns 0. */
+	public native long	errorNumber();
+
 
 	/** Tells the connection to return NULL fields
 	 *  and output bind variables as empty strings. 
@@ -418,6 +447,11 @@ public class SQLRCursor {
 	 *  Returns 1 on success and 0 on failure.  */
 	public native boolean	resumeCachedResultSet(short id,
 							String filename);
+	/** Closes the current result set, if one is open.  Data
+ 	 *  that has been fetched already is still available but
+ 	 *  no more data may be fetched.  Server side resources
+ 	 *  for the result set are freed as well. */
+	public native void	closeResultSet();
 
 
 	/** cursor and connection are used internally, they're just
