@@ -3,6 +3,23 @@
 
 from SQLRelay import CSQLRelay
 
+def getNumericFieldsAsStrings():
+    """
+    Instructs the API to return numeric fields as strings.  This is the
+    default setting.  Truncation cannot occur if this setting is used.
+    """
+    CSQLRelay.getNumericFieldsAsStrings()
+
+def getNumericFieldsAsNumbers():
+    """
+    Instructs the API to return numeric fields as numbers.  Integer fields will
+    be returned as integers and floating point fields will be returned as
+    Decimals if that class is avialable or floats otherwise.  The drawback to
+    using numerics is that under some circumstances truncation can occur.
+    """
+    CSQLRelay.getNumericFieldsAsNumbers()
+
+
 class sqlrconnection:
 
     """
@@ -11,11 +28,11 @@ class sqlrconnection:
 
     def __init__(self, host, port, socket, user, password, retrytime=0, tries=1):
         """ 
-        Opens a connection to the sqlrelay server and authenticates with
-        user and password.  Failed connections are retried for tries times
-        at retrytime interval.  If tries is 0 then retries will continue
-        forever.  If retrytime is 0 then retries will be attempted on a
-        default interval.
+        Opens a connection to the sqlrelay server and auths with
+        user and password.  Failed connections are retried for tries times,
+        waiting retrytime seconds between each try.  If tries is 0 then retries
+        will continue forever.  If retrytime is 0 then retries will be attempted
+        on a default interval.
         """
         self.connection = CSQLRelay.sqlrcon_alloc(host, port, socket, user, password, retrytime, tries)
 
@@ -23,6 +40,154 @@ class sqlrconnection:
     def __del__(self):
         CSQLRelay.sqlrcon_free(self.connection)
 
+    def setConnectTimeout(self, timeoutsec, timeoutusec):
+        """
+        Sets the server connect timeout in seconds and
+        milliseconds.  Setting either parameter to -1 disables the
+        timeout.  You can also set this timeout using the
+        SQLR_CLIENT_CONNECT_TIMEOUT environment variable.
+        """
+        return CSQLRelay.setConnectTimeout(self.connection, timeoutsec, timeoutusec)
+
+    def setAuthenticationTimeout(self, timeoutsec, timeoutusec):
+        """
+        Sets the authentication timeout in seconds and
+        milliseconds.  Setting either parameter to -1 disables the
+        timeout.   You can also set this timeout using the
+        SQLR_CLIENT_AUTHENTICATION_TIMEOUT environment variable.
+        """
+        return CSQLRelay.setAuthenticationTimeout(self.connection, timeoutsec, timeoutusec)
+
+    def setResponseTimeout(self, timeoutsec, timeoutusec):
+        """
+        Sets the response timeout (for queries, commits, rollbacks,
+        pings, etc.) in seconds and milliseconds.  Setting either
+        parameter to -1 disables the timeout.  You can also set
+        this timeout using the SQLR_CLIENT_RESPONSE_TIMEOUT
+        environment variable.
+        """
+        return CSQLRelay.setResponseTimeout(self.connection, timeoutsec, timeoutusec)
+
+    def enableKerberos(self, service, mech, flags):
+        """
+        Enables Kerberos authentication and encryption.
+
+        "service" indicates the Kerberos service name of the
+        SQL Relay server.  If left empty or NULL then the service
+        name "sqlrelay" will be used. "sqlrelay" is the default
+        service name of the SQL Relay server.  Note that on Windows
+        platforms the service name must be fully qualified,
+        including the host and realm name.  For example:
+        "sqlrelay/sqlrserver.firstworks.com@AD.FIRSTWORKS.COM".
+      
+        "mech" indicates the specific Kerberos mechanism to use.
+        On Linux/Unix platforms, this should be a string
+        representation of the mechnaism's OID, such as:
+            { 1 2 840 113554 1 2 2 }
+        On Windows platforms, this should be a string like:
+            Kerberos
+        If left empty or NULL then the default mechanism will be
+        used.  Only set this if you know that you have a good
+        reason to.
+      
+        "flags" indicates what Kerberos flags to use.  Multiple
+        flags may be specified, separated by commas.  If left
+        empty or NULL then a defalt set of flags will be used.
+        Only set this if you know that you have a good reason to.
+      
+        Valid flags include:
+         * GSS_C_MUTUAL_FLAG
+         * GSS_C_REPLAY_FLAG
+         * GSS_C_SEQUENCE_FLAG
+         * GSS_C_CONF_FLAG
+         * GSS_C_INTEG_FLAG
+      
+        For a full list of flags, consult the GSSAPI documentation,
+        though note that only the flags listed above are supported
+        on Windows.
+        """
+        return CSQLRelay.enableKerberos(self.connection, service, mech, flags)
+
+    def enableTls(self, version, cert, password, ciphers, validate, ca, depth):
+        """
+        Enables TLS/SSL encryption, and optionally authentication.
+
+        "version" specifies the TLS/SSL protocol version that the
+        client will attempt to use.  Valid values include SSL2,
+        SSL3, TLS1, TLS1.1, TLS1.2 or any more recent version of
+        TLS, as supported by and enabled in the underlying TLS/SSL
+        library.  If left blank or empty then the highest supported
+        version will be negotiated.
+        
+        "cert" is the file name of the certificate chain file to
+        send to the SQL Relay server.  This is only necessary if
+        the SQL Relay server is configured to authenticate and
+        authorize clients by certificate.
+        
+        If "cert" contains a password-protected private key, then
+        "password" may be supplied to access it.  If the private
+        key is not password-protected, then this argument is
+        ignored, and may be left empty or NULL.
+        
+        "ciphers" is a list of ciphers to allow.  Ciphers may be
+        separated by spaces, commas, or colons.  If "ciphers" is
+        empty or NULL then a default set is used.  Only set this if
+        you know that you have a good reason to.
+        
+        For a list of valid ciphers on Linux/Unix platforms, see:
+            man ciphers
+        
+        For a list of valid ciphers on Windows platforms, see:
+            https://msdn.microsoft.com/en-us/library/windows/desktop/aa375549%28v=vs.85%29.aspx
+        On Windows platforms, the ciphers (alg_id's) should omit
+        CALG_ and may be given with underscores or dashes.
+        For example: 3DES_112
+        
+        "validate" indicates whether to validate the SQL Relay's
+        server certificate, and may be set to one of the following:
+            "no" - Don't validate the server's certificate.
+            "ca" - Validate that the server's certificate was
+                   signed by a trusted certificate authority.
+            "ca+host" - Perform "ca" validation and also validate
+                   that one of the subject altenate names (or the
+                   common name if no SANs are present) in the
+                   certificate matches the host parameter.
+                   (Falls back to "ca" validation when a unix
+                   socket is used.)
+            "ca+domain" - Perform "ca" validation and also validate
+                   that the domain name of one of the subject
+                   alternate names (or the common name if no SANs
+                   are present) in the certificate matches the
+                   domain name of the host parameter.  (Falls back
+                   to "ca" validation when a unix socket is used.)
+        
+        "ca" is the location of a certificate authority file to
+        use, in addition to the system's root certificates, when
+        validating the SQL Relay server's certificate.  This is
+        useful if the SQL Relay server's certificate is self-signed.
+        
+        On Windows, "ca" must be a file name.
+        
+        On non-Windows systems, "ca" can be either a file or
+        directory name.  If it is a directory name, then all
+        certificate authority files found in that directory will be
+        used.  If it a file name, then only that file will be used.
+        
+        
+        Note that the supported "cert" and "ca" file formats may
+        vary between platforms.  A variety of file formats are
+        generally supported on Linux/Unix platfoms (.pem, .pfx,
+        etc.) but only the .pfx format is currently supported on
+        Windows. */
+        """
+        return CSQLRelay.enableTls(self.connection, version, cert, password, ciphers, validate, ca, depth)
+
+    def disableEncryption(self):
+        """
+        Disables encryption.
+        """
+        return CSQLRelay.disableEncryption(self.connection)
+
     def endSession(self):
         """
         Ends the current session.
@@ -78,7 +243,7 @@ class sqlrconnection:
     def identify(self):
         """
         Returns the type of database: 
-          oracle8, postgresql, mysql, etc.
+          oracle, postgresql, mysql, etc.
         """
         return CSQLRelay.identify(self.connection)
 
@@ -88,6 +253,32 @@ class sqlrconnection:
         """
         return CSQLRelay.dbVersion(self.connection)
 
+    def dbHostName(self):
+        """
+        Returns the host name of the database
+        """
+        return CSQLRelay.dbHostName(self.connection)
+
+    def dbIpAddress(self):
+        """
+        Returns the ip address of the database
+        """
+        return CSQLRelay.dbIpAddress(self.connection)
+
+
+    def serverVersion(self):
+        """
+        Returns the version of the SQL Relay server version
+        """
+        return CSQLRelay.serverVersion(self.connection)
+
+
+    def clientVersion(self):
+        """
+        Returns the version of the SQL Relay client version
+        """
+        return CSQLRelay.clientVersion(self.connection)
+
     def bindFormat(self):
         """
         Returns a string representing the format
@@ -95,6 +286,24 @@ class sqlrconnection:
         """
         return CSQLRelay.bindFormat(self.connection)
 
+    def selectDatabase(self,database):
+        """
+        Sets the current database/schema to "database"
+        """
+        return CSQLRelay.selectDatabase(self.connection,database)
+
+    def getCurrentDatabase(self):
+        """
+        Returns the database/schema that is currently in use.
+        """
+        return CSQLRelay.getCurrentDatabase(self.connection)
+
+    def getLastInsertId(self):
+        """
+        Returns the value of the autoincrement column for the last insert
+        """
+        return CSQLRelay.getLastInsertId(self.connection)
+
     def autoCommitOn(self):
         """
         Instructs the database to perform a commit
@@ -109,25 +318,53 @@ class sqlrconnection:
         """
         return CSQLRelay.autoCommitOff(self.connection)
 
+    def begin(self):
+        """
+        Begins a transaction.  Returns true if the begin
+        succeeded, false if it failed.  If the database
+        automatically begins a new transaction when a
+        commit or rollback is issued then this doesn't
+        do anything unless SQL Relay is faking transaction
+        blocks.
+        """
+        return CSQLRelay.begin(self.connection)
+
     def commit(self):
         """
-        Issues a commit, returns 1 if the commit
-        succeeded, 0 if it failed and -1 if an
-        error occurred.
+        Issues a commit, returns true if the commit
+        succeeded, false if it failed.
         """
         return CSQLRelay.commit(self.connection)
 
     def rollback(self):
         """
-        Issues a rollback, returns 1 if the rollback
-        succeeded, 0 if it failed and -1 if an
-        error occurred.
+        Issues a rollback, returns true if the rollback
+        succeeded, false if it failed.
         """
         return CSQLRelay.rollback(self.connection)
 
+    def errorMessage(self):
+        """
+        If the operation failed, the error message will be returned
+        from this method.  Otherwise, it returns None.
+        """
+        return CSQLRelay.connectionErrorMessage(self.connection)
+
+    def errorNumber(self):
+        """
+        If an operation failed and generated an
+        error, the error number is available here.
+        If there is no error then this method 
+        returns 0.
+        """
+        return CSQLRelay.connectionErrorNumber(self.connection)
+
     def debugOn(self):
         """
         Turn verbose debugging on.
+        Another way to do this is to start a query with "-- debug\n".
+        Yet another way is to set the environment variable SQLR_CLIENT_DEBUG
+        to "ON"
         """
         return CSQLRelay.debugOn(self.connection)
 
@@ -143,6 +380,29 @@ class sqlrconnection:
         """
         return CSQLRelay.getDebug(self.connection)
 
+    def setDebugFile(self,filename):
+        """
+        Allows you to specify a file to write debug to.
+        Setting "filename" to NULL or an empty string causes debug
+        to be written to standard output (the default).
+        """
+        return CSQLRelay.setDebugFile(self.connection,filename)
+
+    def setClientInfo(self,clientinfo):
+        """
+        Allows you to set a string that will be passed to the
+        server and ultimately included in server-side logging
+        along with queries that were run by this instance of
+        the client.
+        """
+        return CSQLRelay.setClientInfo(self.connection,clientinfo)
+
+    def getClientInfo(self):
+        """
+        Returns the string that was set by setClientInfo().
+        """
+        return CSQLRelay.getClientInfo(self.connection)
+
 
 
 
@@ -252,6 +512,31 @@ class sqlrcursor:
         """
         return CSQLRelay.cacheOff(self.cursor)
 
+    def getDatabaseList(self,wild):
+        """
+        Sends a query that returns a list of
+        databases/schemas matching "wild".  If wild is empty
+        or NULL then a list of all databases/schemas will be
+        returned.
+        """
+        return CSQLRelay.setDatabaseList(self.cursor,wild)
+
+    def getTableList(self,wild):
+        """
+        Sends a query that returns a list of tables
+        matching "wild".  If wild is empty or NULL then
+        a list of all tables will be returned.
+        """
+        return CSQLRelay.setTableList(self.cursor,wild)
+
+    def getColumnList(sefl,table,wild):
+        """
+        Sends a query that returns a list of columns
+        in the table specified by the "table" parameter
+        matching "wild".  If wild is empty or NULL then
+        a list of all columns will be returned.
+        """
+        return CSQLRelay.setColumnList(self.cursor,table,wild)
 
     """
     If you don't need to use substitution or bind variables
@@ -331,8 +616,10 @@ class sqlrcursor:
         """
         Define an input bind varaible.
         Returns true if the variable was successfully bound or false if the
-        variable isn't a string, integer or floating point number, or if
-        precision and scale aren't provided for a floating point number.
+        variable isn't a string, integer or decimal.  If the value is a decimal
+        then precision and scale may also be specified.  If you don't have the
+        precision and scale then set them both to 0.  However in that case you
+        may get unexpected rounding behavior if the server is faking binds.
         """
         return CSQLRelay.inputBind(self.cursor, variable, value, precision, scale)
 
@@ -416,8 +703,8 @@ class sqlrcursor:
 
     def validBind(self,variable):
         """
-	Returns true if "variable" was a valid
-	input bind variable of the query.
+        Returns true if "variable" was a valid
+        input bind variable of the query.
         """
         return CSQLRelay.validBind(self.cursor,variable)
         
@@ -555,7 +842,16 @@ class sqlrcursor:
         If the query failed, the error message will be returned
         from this method.  Otherwise, it returns None.
         """
-        return CSQLRelay.errorMessage(self.cursor)
+        return CSQLRelay.cursorErrorMessage(self.cursor)
+
+    def errorNumber(self):
+        """
+        If the query failed and generated an
+        error, the error number is available here.
+        If there is no error then this method 
+        returns 0.
+        """
+        return CSQLRelay.cursorErrorNumber(self.cursor)
 
     def getNullsAsEmptyStrings(self):
         """
@@ -782,3 +1078,12 @@ class sqlrcursor:
         Returns 1 on success and 0 on failure.
         """
         return CSQLRelay.resumeCachedResultSet(self.cursor, id, filename)
+
+    def closeResultSet():
+        """
+        Closes the current result set, if one is open.  Data
+        that has been fetched already is still available but
+        no more data may be fetched.  Server side resources
+        for the result set are freed as well.
+        """
+        return CSQLRelay.closeResultSet(self.cursor)
