@@ -1,11 +1,19 @@
 require "mkmf"
+
 drive = File::PATH_SEPARATOR == ";" ? /\A\w:/ : /\A/
 print "\n"
 print "arch = "
 print CONFIG["arch"]
 print "\n"
+print "sitearch = "
+print CONFIG["sitearch"]
+print "\n"
 print "ruby_version = "
+begin
 print Config::CONFIG["ruby_version"]
+rescue
+print CONFIG["ruby_version"]
+end
 print "\n"
 print "prefix = "
 print CONFIG["prefix"].sub(drive, "")
@@ -28,7 +36,7 @@ print "\n"
 print "srcdir = "
 print $srcdir
 print "\n"
-print "CFLAGS = -I. -I$(topdir) -I$(hdrdir) -I$(srcdir) "
+print "CFLAGS = -I. -I$(topdir) -I$(hdrdir) -I$(hdrdir)/$(sitearch) -I$(srcdir) -I$(hdrdir)/../$(arch)/ruby-$(ruby_version)"
 print "\n"
 print "CPPFLAGS = "
 print $CFLAGS
