@@ -5,8 +5,6 @@
 #define DATATYPES_H
 #include <rudiments/charstring.h>
 
-using namespace rudiments;
-
 extern "C" {
 
 #define COLUMN_TYPE_IDS		0
@@ -191,12 +189,24 @@ typedef	enum {
 	TRIGGER_DATATYPE,
 	LANGUAGE_HANDLER_DATATYPE,
 	INTERNAL_DATATYPE,
-	OPAQUE_DATATYPE
+	OPAQUE_DATATYPE,
+	ANYELEMENT_DATATYPE,
+	PG_TYPE_DATATYPE,
+	PG_ATTRIBUTE_DATATYPE,
+	PG_PROC_DATATYPE,
+	PG_CLASS_DATATYPE,
 	// none added by sqlite
+	// added by sqlserver
+	UBIGINT_DATATYPE,
+	UNIQUEIDENTIFIER_DATATYPE,
+	// added by informix
+	SMALLFLOAT_DATATYPE,
+	BYTE_DATATYPE,
+	BOOLEAN_DATATYPE
 } datatype;
 
 #ifdef NEED_DATATYPESTRING
-static char	*datatypestring[] = {
+static const char	*datatypestring[] = {
 	"UNKNOWN",
 	// addded by freetds
 	"CHAR",		// 1
@@ -298,76 +308,76 @@ static char	*datatypestring[] = {
 	"BOX",
 	"POLYGON",
 	"LINE",
-	"_LINE",
+	"LINE_ARRAY",
 	"FLOAT4",
 	"FLOAT8",
 	"ABSTIME",
 	"RELTIME",
 	"TINTERVAL",
 	"CIRCLE",
-	"_CIRCLE",
-	"_MONEY",
+	"CIRCLE_ARRAY",
+	"MONEY_ARRAY",
 	"MACADDR",
 	"INET",
 	"CIDR",
-	"_BOOL",
-	"_BYTEA",
-	"_CHAR",
-	"_NAME",
-	"_INT2",
-	"_INT2VECTOR",
-	"_INT4",
-	"_REGPROC",
-	"_TEXT",
-	"_oid",
-	"_TID",
-	"_XID",
-	"_CID",
-	"_OIDVECTOR",
-	"_BPCHAR",
-	"_VARCHAR",
-	"_INT8",
-	"_POINT",
-	"_LSEG",
-	"_PATH",
-	"_BOX",
-	"_FLOAT4",
-	"_FLOAT8",
-	"_ABSTIME",
-	"_RELTIME",
-	"_TINTERVAL",
-	"_POLYGON",
+	"BOOL_ARRAY",
+	"BYTEA_ARRAY",
+	"CHAR_ARRAY",
+	"NAME_ARRAY",
+	"INT2_ARRAY",
+	"INT2VECTOR_ARRAY",
+	"INT4_ARRAY",
+	"REGPROC_ARRAY",
+	"TEXT_ARRAY",
+	"OID_ARRAY",
+	"TID_ARRAY",
+	"XID_ARRAY",
+	"CID_ARRAY",
+	"OIDVECTOR_ARRAY",
+	"BPCHAR_ARRAY",
+	"VARCHAR_ARRAY",
+	"INT8_ARRAY",
+	"POINT_ARRAY",
+	"LSEG_ARRAY",
+	"PATH_ARRAY",
+	"BOX_ARRAY",
+	"FLOAT4_ARRAY",
+	"FLOAT8_ARRAY",
+	"ABSTIME_ARRAY",
+	"RELTIME_ARRAY",
+	"TINTERVAL_ARRAY",
+	"POLYGON_ARRAY",
 	"ACLITEM",
-	"_ACLITEM",
-	"_MACADDR",
-	"_INET",
-	"_CIDR",
+	"ACLITEM_ARRAY",
+	"MACADDR_ARRAY",
+	"INET_ARRAY",
+	"CIDR_ARRAY",
 	"BPCHAR",
-	"_TIMESTAMP",
-	"_DATE",
-	"_TIME",
+	"TIMESTAMP_ARRAY",
+	"DATE_ARRAY",
+	"TIME_ARRAY",
 	"TIMESTAMPTZ",
-	"_TIMESTAMPTZ",
+	"TIMESTAMPTZ_ARRAY",
 	"INTERVAL",
-	"_INTERVAL",
-	"_NUMERIC",
+	"INTERVAL_ARRAY",
+	"NUMERIC_ARRAY",
 	"TIMETZ",
-	"_TIMETZ",
-	"_BIT",
+	"TIMETZ_ARRAY",
+	"BIT_ARRAY",
 	"VARBIT",
-	"_VARBIT",
+	"VARBIT_ARRAY",
 	"REFCURSOR",
-	"_REFCURSOR",
+	"REFCURSOR_ARRAY",
 	"REGPROCEDURE",
 	"REGOPER",
 	"REGOPERATOR",
 	"REGCLASS",
 	"REGTYPE",
-	"_REGPROCEDURE",
-	"_REGOPER",
-	"_REGOPERATOR",
-	"_REGCLASS",
-	"_REGTYPE",
+	"REGPROCEDURE_ARRAY",
+	"REGOPER_ARRAY",
+	"REGOPERATOR_ARRAY",
+	"REGCLASS_ARRAY",
+	"REGTYPE_ARRAY",
 	"RECORD",
 	"CSTRING",
 	"ANY",
@@ -376,38 +386,89 @@ static char	*datatypestring[] = {
 	"LANGUAGE_HANDLER",
 	"INTERNAL",
 	"OPAQUE",
+	"ANYELEMENT",
+	"PG_TYPE",
+	"PG_ATTRIBUTE",
+	"PG_PROC",
+	"PG_CLASS",
 	// none added by sqlite
+	// added by sqlserver
+	"UBIGINT",
+	"UNIQUEIDENTIFIER",
+	// added by informix
+	"SMALLFLOAT",
+	"BYTE",
+	"BOOLEAN",
 	NULL
 };
 #endif
 
+#ifdef NEED_IS_BIT_TYPE_CHAR
+static bool isBitTypeChar(const char *type) {
+  return (!charstring::compareIgnoringCase(type,"BIT") ||
+	  !charstring::compareIgnoringCase(type,"VARBIT"));
+}
+#endif
+
+#ifdef NEED_IS_BOOL_TYPE_CHAR
+static bool isBoolTypeChar(const char *type) {
+  return !charstring::compareIgnoringCase(type,"BOOL");
+}
+#endif
+
+#ifdef NEED_IS_FLOAT_TYPE_CHAR
+static bool isFloatTypeChar(const char *type) {
+  return (!charstring::compareIgnoringCase(type,"NUMERIC") ||
+	  !charstring::compareIgnoringCase(type,"REAL") ||
+	  !charstring::compareIgnoringCase(type,"FLOAT") ||
+	  !charstring::compareIgnoringCase(type,"DOUBLE") ||
+	  !charstring::compareIgnoringCase(type,"D_FLOAT") ||
+	  !charstring::compareIgnoringCase(type,"DECIMAL") ||
+	  !charstring::compareIgnoringCase(type,"MONEY") ||
+	  !charstring::compareIgnoringCase(type,"SMALLMONEY") ||
+	  !charstring::compareIgnoringCase(type,"DOUBLE PRECISION") ||
+	  !charstring::compareIgnoringCase(type,"FLOAT4") ||
+	  !charstring::compareIgnoringCase(type,"FLOAT8") ||
+	  !charstring::compareIgnoringCase(type,"_NUMERIC"));
+}
+#endif
+
+#ifdef NEED_BIT_STRING_TO_LONG
+static int32_t bitStringToLong(const char *str) {
+	uint32_t	result=0;
+	size_t		length=charstring::length(str);
+	for (size_t i=0; i<length; i++) {
+		result=(result<<1)|(str[i]=='1');
+	}
+	return result;
+}
+#endif
+
 #ifdef NEED_IS_NUMBER_TYPE_CHAR
 static bool isNumberTypeChar(const char *type) { 
-	return (!charstring::compare(type,"NUMBER") ||
-		!charstring::compare(type,"INT") ||
-		!charstring::compare(type,"SMALLINT") ||
-		!charstring::compare(type,"TINYINT") ||
-		!charstring::compare(type,"NUMERIC") ||
-		!charstring::compare(type,"BIT") ||
-		!charstring::compare(type,"REAL") ||
-		!charstring::compare(type,"FLOAT") ||
-		!charstring::compare(type,"USHORT") ||
-		!charstring::compare(type,"DOUBLE") ||
-		!charstring::compare(type,"UINT") ||
-		!charstring::compare(type,"LASTREAL") ||
-		!charstring::compare(type,"TINY") ||
-		!charstring::compare(type,"SHORT") ||
-		!charstring::compare(type,"LONGLONG") ||
-		!charstring::compare(type,"MEDIUMINT") ||
-		!charstring::compare(type,"YEAR") ||
-		!charstring::compare(type,"BIGINT") ||
-		!charstring::compare(type,"INTEGER") ||
-		!charstring::compare(type,"D_FLOAT") ||
-		!charstring::compare(type,"DECIMAL") ||
-		!charstring::compare(type,"INT64") ||
-		!charstring::compare(type,"MONEY") ||
-		!charstring::compare(type,"SMALLMONEY") ||
-		!charstring::compare(type,"DOUBLE PRECISION") ||
+	return (!charstring::compareIgnoringCase(type,"NUMBER") ||
+		!charstring::compareIgnoringCase(type,"INT") ||
+		!charstring::compareIgnoringCase(type,"SMALLINT") ||
+		!charstring::compareIgnoringCase(type,"TINYINT") ||
+		!charstring::compareIgnoringCase(type,"REAL") ||
+		!charstring::compareIgnoringCase(type,"FLOAT") ||
+		!charstring::compareIgnoringCase(type,"USHORT") ||
+		!charstring::compareIgnoringCase(type,"DOUBLE") ||
+		!charstring::compareIgnoringCase(type,"UINT") ||
+		!charstring::compareIgnoringCase(type,"LASTREAL") ||
+		!charstring::compareIgnoringCase(type,"TINY") ||
+		!charstring::compareIgnoringCase(type,"SHORT") ||
+		!charstring::compareIgnoringCase(type,"LONGLONG") ||
+		!charstring::compareIgnoringCase(type,"MEDIUMINT") ||
+		!charstring::compareIgnoringCase(type,"YEAR") ||
+		!charstring::compareIgnoringCase(type,"BIGINT") ||
+		!charstring::compareIgnoringCase(type,"INTEGER") ||
+		!charstring::compareIgnoringCase(type,"D_FLOAT") ||
+		!charstring::compareIgnoringCase(type,"DECIMAL") ||
+		!charstring::compareIgnoringCase(type,"INT64") ||
+		!charstring::compareIgnoringCase(type,"MONEY") ||
+		!charstring::compareIgnoringCase(type,"SMALLMONEY") ||
+		!charstring::compareIgnoringCase(type,"DOUBLE PRECISION") ||
 		!charstring::compareIgnoringCase(type,"INT8") ||
 		!charstring::compareIgnoringCase(type,"INT2") ||
 		!charstring::compareIgnoringCase(type,"INT4") ||
@@ -430,65 +491,75 @@ static bool isNumberTypeChar(const char *type) {
 		!charstring::compareIgnoringCase(type,"_FLOAT8") ||
 		!charstring::compareIgnoringCase(type,"_TINTERVAL") ||
 		!charstring::compareIgnoringCase(type,"INTERVAL") ||
-		!charstring::compareIgnoringCase(type,"_INTERVAL") ||
-		!charstring::compareIgnoringCase(type,"_NUMERIC"));
+		!charstring::compareIgnoringCase(type,"_INTERVAL"));
 }
 #endif
 
 #ifdef NEED_IS_BLOB_TYPE_CHAR
 static bool isBlobTypeChar(const char *type) { 
-	return (!charstring::compare(type,"IMAGE") ||
-		!charstring::compare(type,"BINARY") ||
-		!charstring::compare(type,"VARBINARY") ||
-		!charstring::compare(type,"LONGCHAR") ||
-		!charstring::compare(type,"LONGBINARY") ||
-		!charstring::compare(type,"LONG") ||
-		!charstring::compare(type,"TINYBLOB") ||
-		!charstring::compare(type,"MEDIUMBLOB") ||
-		!charstring::compare(type,"LONGBLOB") ||
-		!charstring::compare(type,"BLOB") ||
-		!charstring::compare(type,"RAW") ||
-		!charstring::compare(type,"LONG_RAW") ||
-		!charstring::compare(type,"CLOB") ||
-		!charstring::compare(type,"BFILE") ||
-		!charstring::compare(type,"DBCLOB"));
+	return (!charstring::compareIgnoringCase(type,"IMAGE") ||
+		!charstring::compareIgnoringCase(type,"BINARY") ||
+		!charstring::compareIgnoringCase(type,"VARBINARY") ||
+		!charstring::compareIgnoringCase(type,"LONGCHAR") ||
+		!charstring::compareIgnoringCase(type,"LONGBINARY") ||
+		!charstring::compareIgnoringCase(type,"LONG") ||
+		!charstring::compareIgnoringCase(type,"TINYBLOB") ||
+		!charstring::compareIgnoringCase(type,"MEDIUMBLOB") ||
+		!charstring::compareIgnoringCase(type,"LONGBLOB") ||
+		!charstring::compareIgnoringCase(type,"BLOB") ||
+		!charstring::compareIgnoringCase(type,"RAW") ||
+		!charstring::compareIgnoringCase(type,"LONG_RAW") ||
+		!charstring::compareIgnoringCase(type,"CLOB") ||
+		!charstring::compareIgnoringCase(type,"BFILE") ||
+		!charstring::compareIgnoringCase(type,"DBCLOB"));
 }
 #endif
 
 #ifdef NEED_IS_UNSIGNED_TYPE_CHAR
 static bool isUnsignedTypeChar(const char *type) { 
-	return (!charstring::compare(type,"USHORT") ||
-		!charstring::compare(type,"UINT"));
+	return (!charstring::compareIgnoringCase(type,"USHORT") ||
+		!charstring::compareIgnoringCase(type,"UINT"));
 }
 #endif
 
 #ifdef NEED_IS_BINARY_TYPE_CHAR
 static bool isBinaryTypeChar(const char *type) { 
-	return (!charstring::compare(type,"IMAGE") ||
-		!charstring::compare(type,"BINARY") ||
-		!charstring::compare(type,"VARBINARY") ||
-		!charstring::compare(type,"LONGBINARY") ||
-		!charstring::compare(type,"TINYBLOB") ||
-		!charstring::compare(type,"MEDIUMBLOB") ||
-		!charstring::compare(type,"LONGBLOB") ||
-		!charstring::compare(type,"BLOB") ||
-		!charstring::compare(type,"BFILE") ||
-		!charstring::compare(type,"LONGVARBINARY") ||
-		!charstring::compare(type,"GRAPHIC") ||
-		!charstring::compare(type,"VARGRAPHIC") ||
-		!charstring::compare(type,"LONGVARGRAPHIC") ||
-		!charstring::compare(type,"OID") ||
-		!charstring::compare(type,"_OID") ||
-		!charstring::compare(type,"OIDVECTOR") ||
-		!charstring::compare(type,"_BYTEA"));
+	return (!charstring::compareIgnoringCase(type,"IMAGE") ||
+		!charstring::compareIgnoringCase(type,"BINARY") ||
+		!charstring::compareIgnoringCase(type,"VARBINARY") ||
+		!charstring::compareIgnoringCase(type,"LONGBINARY") ||
+		!charstring::compareIgnoringCase(type,"TINYBLOB") ||
+		!charstring::compareIgnoringCase(type,"MEDIUMBLOB") ||
+		!charstring::compareIgnoringCase(type,"LONGBLOB") ||
+		!charstring::compareIgnoringCase(type,"BLOB") ||
+		!charstring::compareIgnoringCase(type,"BFILE") ||
+		!charstring::compareIgnoringCase(type,"LONGVARBINARY") ||
+		!charstring::compareIgnoringCase(type,"GRAPHIC") ||
+		!charstring::compareIgnoringCase(type,"VARGRAPHIC") ||
+		!charstring::compareIgnoringCase(type,"LONGVARGRAPHIC") ||
+		!charstring::compareIgnoringCase(type,"OID") ||
+		!charstring::compareIgnoringCase(type,"_OID") ||
+		!charstring::compareIgnoringCase(type,"OIDVECTOR") ||
+		!charstring::compareIgnoringCase(type,"_BYTEA"));
+}
+#endif
+
+#ifdef NEED_IS_DATETIME_TYPE_CHAR
+static bool isDateTimeTypeChar(const char *type) {
+	return (!charstring::compareIgnoringCase(type,"DATETIME") ||
+		!charstring::compareIgnoringCase(type,"SMALLDATETIME") ||
+		!charstring::compareIgnoringCase(type,"DATE") ||
+		!charstring::compareIgnoringCase(type,"TIME") ||
+		!charstring::compareIgnoringCase(type,"TIMESTAMP") ||
+		!charstring::compareIgnoringCase(type,"NEWDATE"));
 }
 #endif
 
 #ifdef NEED_IS_NUMBER_TYPE_INT
-static bool isNumberTypeInt(int32_t type) {
+static bool isNumberTypeInt(int16_t type) {
 	return (type==NUMBER_DATATYPE || type==INT_DATATYPE ||
 		type==SMALLINT_DATATYPE || type==TINYINT_DATATYPE ||
-		type==NUMERIC_DATATYPE || type==BIT_DATATYPE ||
+		type==BIT_DATATYPE ||
 		type==REAL_DATATYPE || type==FLOAT_DATATYPE ||
 		type==USHORT_DATATYPE || type==DOUBLE_DATATYPE ||
 		type==UINT_DATATYPE || type==LASTREAL_DATATYPE ||
@@ -509,8 +580,18 @@ static bool isNumberTypeInt(int32_t type) {
 		type==_XID_DATATYPE || type==_CID_DATATYPE ||
 		type==_INT8_DATATYPE || type==_FLOAT4_DATATYPE ||
 		type==_FLOAT8_DATATYPE || type==_TINTERVAL_DATATYPE ||
-		type==INTERVAL_DATATYPE || type==_INTERVAL_DATATYPE ||
-		type==_NUMERIC_DATATYPE);
+		type==INTERVAL_DATATYPE || type==_INTERVAL_DATATYPE);
+}
+#endif
+
+#ifdef NEED_IS_DATETIME_TYPE_INT
+static bool isDateTimeTypeInt(int16_t type) {
+	return (type==DATETIME_DATATYPE ||
+		type==SMALLDATETIME_DATATYPE ||
+		type==DATE_DATATYPE ||
+		type==TIME_DATATYPE ||
+		type==TIMESTAMP_DATATYPE ||
+		type==NEWDATE_DATATYPE);
 }
 #endif
 
