@@ -19,20 +19,22 @@ void checkSuccessString(const char *value, const char *success) {
 			printf("success ");
 			return;
 		} else {
+			printf("\"%s\"!=\"%s\"",value,success);
 			printf("failure ");
 			sqlrcur_free(cur);
 			sqlrcon_free(con);
-			exit(0);
+			exit(1);
 		}
 	}
 
 	if (!strcmp(value,success)) {
 		printf("success ");
 	} else {
+		printf("\"%s\"!=\"%s\"",value,success);
 		printf("failure ");
 		sqlrcur_free(cur);
 		sqlrcon_free(con);
-		exit(0);
+		exit(1);
 	}
 }
 
@@ -41,10 +43,11 @@ void checkSuccessInt(int value, int success) {
 	if (value==success) {
 		printf("success ");
 	} else {
+		printf("\"%d\"!=\"%d\"",value,success);
 		printf("failure ");
 		sqlrcur_free(cur);
 		sqlrcon_free(con);
-		exit(0);
+		exit(1);
 	}
 }
 
@@ -68,15 +71,9 @@ int	main(int argc, char **argv) {
 	char		*filename;
 	uint32_t	*fieldlens;
 
-	// usage...
-	if (argc<5) {
-		printf("usage: db2 host port socket user password\n");
-		exit(0);
-	}
-
 	// instantiation
-	con=sqlrcon_alloc(argv[1],atoi(argv[2]), 
-					argv[3],argv[4],argv[5],0,1);
+	con=sqlrcon_alloc("sqlrserver",9000,
+				"/tmp/test.socket","test","test",0,1);
 	cur=sqlrcur_alloc(con);
 
 	// get database type
@@ -748,6 +745,4 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
-
-	exit(0);
 }
