@@ -19,20 +19,22 @@ void checkSuccessString(const char *value, const char *success) {
 			printf("success ");
 			return;
 		} else {
+			printf("\"%s\"!=\"%s\"",value,success);
 			printf("failure ");
 			sqlrcur_free(cur);
 			sqlrcon_free(con);
-			exit(0);
+			exit(1);
 		}
 	}
 
 	if (!strcmp(value,success)) {
 		printf("success ");
 	} else {
+		printf("\"%s\"!=\"%s\"",value,success);
 		printf("failure ");
 		sqlrcur_free(cur);
 		sqlrcon_free(con);
-		exit(0);
+		exit(1);
 	}
 }
 
@@ -41,10 +43,11 @@ void checkSuccessInt(int value, int success) {
 	if (value==success) {
 		printf("success ");
 	} else {
+		printf("\"%d\"!=\"%d\"",value,success);
 		printf("failure ");
 		sqlrcur_free(cur);
 		sqlrcon_free(con);
-		exit(0);
+		exit(1);
 	}
 }
 
@@ -69,15 +72,9 @@ int	main(int argc, char **argv) {
 	char		*filename;
 	uint32_t	*fieldlens;
 
-	// usage...
-	if (argc<5) {
-		printf("usage: firebird host port socket user password\n");
-		exit(0);
-	}
-
 	// instantiation
-	con=sqlrcon_alloc(argv[1],atoi(argv[2]), 
-					argv[3],argv[4],argv[5],0,1);
+	con=sqlrcon_alloc("sqlrserver",9000,
+				"/tmp/test.socket","test","test",0,1);
 	cur=sqlrcur_alloc(con);
 
 	// get database type
@@ -95,12 +92,12 @@ int	main(int argc, char **argv) {
 	sqlrcon_commit(con);
 
 	printf("INSERT: \n");
-	checkSuccessInt(sqlrcur_sendQuery(cur,"insert into testtable values (1,1,1.1,1.1,1.1,1.1,'01-JAN-2001','01:00:00','testchar1','testvarchar1',NULL)"),1);
+	checkSuccessInt(sqlrcur_sendQuery(cur,"insert into testtable values (1,1,1.1,1.1,1.1,1.1,'01-JAN-2001','01:00:00','testchar1','testvarchar1',NULL,NULL)"),1);
 	printf("\n");
 
 
 	printf("BIND BY POSITION: \n");
-	sqlrcur_prepareQuery(cur,"insert into testtable values (?,?,?,?,?,?,?,?,?,?,?)");
+	sqlrcur_prepareQuery(cur,"insert into testtable values (?,?,?,?,?,?,?,?,?,?,?,NULL)");
 	checkSuccessInt(sqlrcur_countBindVariables(cur),11);
 	sqlrcur_inputBindLong(cur,"1",2);
 	sqlrcur_inputBindLong(cur,"2",2);
@@ -136,10 +133,10 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("INSERT: \n");
-	checkSuccessInt(sqlrcur_sendQuery(cur,"insert into testtable values (5,5,5.5,5.5,5.5,5.5,'01-JAN-2005','05:00:00','testchar5','testvarchar5',NULL)"),1);
-	checkSuccessInt(sqlrcur_sendQuery(cur,"insert into testtable values (6,6,6.6,6.6,6.6,6.6,'01-JAN-2006','06:00:00','testchar6','testvarchar6',NULL)"),1);
-	checkSuccessInt(sqlrcur_sendQuery(cur,"insert into testtable values (7,7,7.7,7.7,7.7,7.7,'01-JAN-2007','07:00:00','testchar7','testvarchar7',NULL)"),1);
-	checkSuccessInt(sqlrcur_sendQuery(cur,"insert into testtable values (8,8,8.8,8.8,8.8,8.8,'01-JAN-2008','08:00:00','testchar8','testvarchar8',NULL)"),1);
+	checkSuccessInt(sqlrcur_sendQuery(cur,"insert into testtable values (5,5,5.5,5.5,5.5,5.5,'01-JAN-2005','05:00:00','testchar5','testvarchar5',NULL,NULL)"),1);
+	checkSuccessInt(sqlrcur_sendQuery(cur,"insert into testtable values (6,6,6.6,6.6,6.6,6.6,'01-JAN-2006','06:00:00','testchar6','testvarchar6',NULL,NULL)"),1);
+	checkSuccessInt(sqlrcur_sendQuery(cur,"insert into testtable values (7,7,7.7,7.7,7.7,7.7,'01-JAN-2007','07:00:00','testchar7','testvarchar7',NULL,NULL)"),1);
+	checkSuccessInt(sqlrcur_sendQuery(cur,"insert into testtable values (8,8,8.8,8.8,8.8,8.8,'01-JAN-2008','08:00:00','testchar8','testvarchar8',NULL,NULL)"),1);
 	printf("\n");
 
 	printf("AFFECTED ROWS: \n");
@@ -147,12 +144,26 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("STORED PROCEDURE: \n");
-	checkSuccessInt(sqlrcur_sendQuery(cur,"create procedure testproc(invar integer) returns (outvar integer) as begin outvar = invar; suspend; end"),1);
-	sqlrcur_prepareQuery(cur,"select * from testproc(?)");
-	sqlrcur_inputBindLong(cur,"1",5);
+	sqlrcur_prepareQuery(cur,"select * from testproc(?,?,?,NULL)");
+	sqlrcur_inputBindLong(cur,"1",1);
+	sqlrcur_inputBindDouble(cur,"2",1.1,2,1);
+	sqlrcur_inputBindString(cur,"3","hello");
 	checkSuccessInt(sqlrcur_executeQuery(cur),1);
-	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,0),"5");
-	checkSuccessInt(sqlrcur_sendQuery(cur,"drop procedure testproc"),1);
+	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,(uint32_t)0),"1");
+	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,1),"1.1000");
+	checkSuccessString(sqlrcur_getFieldByIndex(cur,0,2),"hello");
+	sqlrcur_prepareQuery(cur,"execute procedure testproc ?, ?, ?, NULL");
+	sqlrcur_inputBindLong(cur,"1",1);
+	sqlrcur_inputBindDouble(cur,"2",1.1,2,1);
+	sqlrcur_inputBindString(cur,"3","hello");
+	sqlrcur_defineOutputBindInteger(cur,"1");
+	sqlrcur_defineOutputBindDouble(cur,"2");
+	sqlrcur_defineOutputBindString(cur,"3",20);
+	sqlrcur_defineOutputBindBlob(cur,"4");
+	checkSuccessInt(sqlrcur_executeQuery(cur),1);
+	checkSuccessInt(sqlrcur_getOutputBindInteger(cur,"1"),1);
+	//checkSuccess(sqlrcur_getOutputBindDouble(cur,"2"),1.1);
+	checkSuccessString(sqlrcur_getOutputBindString(cur,"3"),"hello               ");
 	printf("\n");
 
 	printf("SELECT: \n");
@@ -160,7 +171,7 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("COLUMN COUNT: \n");
-	checkSuccessInt(sqlrcur_colCount(cur),11);
+	checkSuccessInt(sqlrcur_colCount(cur),12);
 	printf("\n");
 
 	printf("COLUMN NAMES: \n");
@@ -601,7 +612,7 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("COLUMN COUNT FOR CACHED RESULT SET: \n");
-	checkSuccessInt(sqlrcur_colCount(cur),11);
+	checkSuccessInt(sqlrcur_colCount(cur),12);
 	printf("\n");
 
 	printf("COLUMN NAMES FOR CACHED RESULT SET: \n");
@@ -705,9 +716,8 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("COMMIT AND ROLLBACK: \n");
-	secondcon=sqlrcon_alloc(argv[1],
-				atoi(argv[2]), 
-				argv[3],argv[4],argv[5],0,1);
+	secondcon=sqlrcon_alloc("sqlrserver",9000,
+				"/tmp/test.socket","test","test",0,1);
 	secondcur=sqlrcur_alloc(secondcon);
 	checkSuccessInt(sqlrcur_sendQuery(secondcur,"select count(*) from testtable"),1);
 	checkSuccessString(sqlrcur_getFieldByIndex(secondcur,0,0),"0");
@@ -715,7 +725,7 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(secondcur,"select count(*) from testtable"),1);
 	checkSuccessString(sqlrcur_getFieldByIndex(secondcur,0,0),"8");
 	checkSuccessInt(sqlrcon_autoCommitOn(con),1);
-	checkSuccessInt(sqlrcur_sendQuery(cur,"insert into testtable values (10,10,10.1,10.1,10.1,10.1,'01-JAN-2010','10:00:00','testchar10','testvarchar10',NULL)"),1);
+	checkSuccessInt(sqlrcur_sendQuery(cur,"insert into testtable values (10,10,10.1,10.1,10.1,10.1,'01-JAN-2010','10:00:00','testchar10','testvarchar10',NULL,NULL)"),1);
 	checkSuccessInt(sqlrcur_sendQuery(secondcur,"select count(*) from testtable"),1);
 	checkSuccessString(sqlrcur_getFieldByIndex(secondcur,0,0),"9");
 	checkSuccessInt(sqlrcon_autoCommitOff(con),1);
@@ -763,6 +773,4 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
-
-	exit(0);
 }
