@@ -1,6 +1,7 @@
 // Copyright (c) 2001  David Muse
 // See the file COPYING for more information.
 
+#include "../../config.h"
 #include <sqlrelay/sqlrclientwrapper.h>
 #include <string.h>
 #include <stdlib.h>
@@ -19,20 +20,22 @@ void checkSuccessString(const char *value, const char *success) {
 			printf("success ");
 			return;
 		} else {
+			printf("\"%s\"!=\"%s\"",value,success);
 			printf("failure ");
 			sqlrcur_free(cur);
 			sqlrcon_free(con);
-			exit(0);
+			exit(1);
 		}
 	}
 
 	if (!strcmp(value,success)) {
 		printf("success ");
 	} else {
+		printf("\"%s\"!=\"%s\"",value,success);
 		printf("failure ");
 		sqlrcur_free(cur);
 		sqlrcon_free(con);
-		exit(0);
+		exit(1);
 	}
 }
 
@@ -41,10 +44,11 @@ void checkSuccessInt(int value, int success) {
 	if (value==success) {
 		printf("success ");
 	} else {
+		printf("\"%d\"!=\"%d\"",value,success);
 		printf("failure ");
 		sqlrcur_free(cur);
 		sqlrcon_free(con);
-		exit(0);
+		exit(1);
 	}
 }
 
@@ -61,18 +65,12 @@ int	main(int argc, char **argv) {
 	uint16_t	port;
 	const char	*socket;
 	uint16_t	id;
-	const char	*filename;
+	char		*filename;
 	uint32_t	*fieldlens;
 
-	// usage...
-	if (argc<5) {
-		printf("usage: sqlite host port socket user password\n");
-		exit(0);
-	}
-
 	// instantiation
-	con=sqlrcon_alloc(argv[1],atoi(argv[2]), 
-					argv[3],argv[4],argv[5],0,1);
+	con=sqlrcon_alloc("sqlrserver",9000,
+				"/tmp/test.socket","test","test",0,1);
 	cur=sqlrcur_alloc(con);
 
 	// get database type
@@ -162,6 +160,16 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("COLUMN TYPES: \n");
+	#ifdef HAVE_SQLITE3_STMT
+	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,0),"INTEGER");
+	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testint"),"INTEGER");
+	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,1),"FLOAT");
+	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testfloat"),"FLOAT");
+	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,2),"STRING");
+	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testchar"),"STRING");
+	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,3),"STRING");
+	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testvarchar"),"STRING");
+	#else
 	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,0),"UNKNOWN");
 	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testint"),"UNKNOWN");
 	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,1),"UNKNOWN");
@@ -170,6 +178,7 @@ int	main(int argc, char **argv) {
 	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testchar"),"UNKNOWN");
 	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,3),"UNKNOWN");
 	checkSuccessString(sqlrcur_getColumnTypeByName(cur,"testvarchar"),"UNKNOWN");
+	#endif
 	printf("\n");
 
 	printf("COLUMN LENGTH: \n");
@@ -199,7 +208,11 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("TOTAL ROWS: \n");
+	#ifdef HAVE_SQLITE3_STMT
+	checkSuccessInt(sqlrcur_totalRows(cur),0);
+	#else
 	checkSuccessInt(sqlrcur_totalRows(cur),8);
+	#endif
 	printf("\n");
 
 	printf("FIRST ROW INDEX: \n");
@@ -391,7 +404,11 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"select * from testtable order by testint"),1);
 	checkSuccessString(sqlrcur_getColumnName(cur,0),"testint");
 	checkSuccessInt(sqlrcur_getColumnLengthByIndex(cur,0),0);
+	#ifdef HAVE_SQLITE3_STMT
+	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,0),"INTEGER");
+	#else
 	checkSuccessString(sqlrcur_getColumnTypeByIndex(cur,0),"UNKNOWN");
+	#endif
 	printf("\n");
 
 	printf("SUSPENDED SESSION: \n");
@@ -575,9 +592,8 @@ int	main(int argc, char **argv) {
 	printf("\n");
 
 	printf("COMMIT AND ROLLBACK: \n");
-	secondcon=sqlrcon_alloc(argv[1],
-				atoi(argv[2]), 
-				argv[3],argv[4],argv[5],0,1);
+	secondcon=sqlrcon_alloc("sqlrserver",9000,
+				"/tmp/test.socket","test","test",0,1);
 	secondcur=sqlrcur_alloc(secondcon);
 	checkSuccessInt(sqlrcur_sendQuery(secondcur,"select count(*) from testtable"),1);
 	checkSuccessString(sqlrcur_getFieldByIndex(secondcur,0,0),"0");
@@ -628,6 +644,4 @@ int	main(int argc, char **argv) {
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	checkSuccessInt(sqlrcur_sendQuery(cur,"create table testtable"),0);
 	printf("\n");
-
-	exit(0);
 }
