@@ -7,56 +7,47 @@ import com.firstworks.sqlrelay.SQLRCursor;
 
 class db2 {
 	
-	
-	
-	
-	
-	
 	private static void checkSuccess(String value, String success) {
 	
 		if (success==null) {
 			if (value==null) {
-				System.out.println("success ");
+				System.out.print("success ");
 				return;
 			} else {
-				System.out.println("failure ");
-				
-				
-				System.exit(0);
+				System.out.print(value+"!="+success+" ");
+				System.out.print("failure ");
+				System.exit(1);
 			}
 		}
 	
 		if (value.equals(success)) {
-			System.out.println("success ");
+			System.out.print("success ");
 		} else {
-			System.out.println("failure ");
-			
-			
-			System.exit(0);
+			System.out.print(value+"!="+success+" ");
+			System.out.print("failure ");
+			System.exit(1);
 		}
 	}
 	
 	private static void checkSuccess(long value, int success) {
 	
 		if (value==success) {
-			System.out.println("success ");
+			System.out.print("success ");
 		} else {
-			System.out.println("failure ");
-			
-			
-			System.exit(0);
+			System.out.print(value+"!="+success+" ");
+			System.out.print("failure ");
+			System.exit(1);
 		}
 	}
 	
 	private static void checkSuccess(boolean value, int success) {
 	
 		if (((value)?1:0)==success) {
-			System.out.println("success ");
+			System.out.print("success ");
 		} else {
-			System.out.println("failure ");
-			
-			
-			System.exit(0);
+			System.out.print(value+"!="+success+" ");
+			System.out.print("failure ");
+			System.exit(1);
 		}
 	}
 	
@@ -83,16 +74,11 @@ class db2 {
 		String	filename;
 		long[]	fieldlens;
 	
-		// usage...
-		if (args.length<5) {
-			System.out.println("usage: java db2 host port socket user password");
-			System.exit(0);
-		}
-	
 		// instantiation
-		SQLRConnection con=new SQLRConnection(args[0],
-					(short)Integer.parseInt(args[1]), 
-						args[2],args[3],args[4],0,1);
+		SQLRConnection con=new SQLRConnection("sqlrserver",
+						(short)9000,
+						"/tmp/test.socket",
+						"test","test",0,1);
 		SQLRCursor cur=new SQLRCursor(con);
 	
 		// get database type
