@@ -7,56 +7,47 @@ import com.firstworks.sqlrelay.SQLRCursor;
 
 class firebird {
 	
-	
-	
-	
-	
-	
 	private static void checkSuccess(String value, String success) {
 	
 		if (success==null) {
 			if (value==null) {
-				System.out.println("success ");
+				System.out.print("success ");
 				return;
 			} else {
-				System.out.println("failure ");
-				
-				
-				System.exit(0);
+				System.out.print(value+"!="+success+" ");
+				System.out.print("failure ");
+				System.exit(1);
 			}
 		}
 	
 		if (value.equals(success)) {
-			System.out.println("success ");
+			System.out.print("success ");
 		} else {
-			System.out.println("failure ");
-			
-			
-			System.exit(0);
+			System.out.print(value+"!="+success+" ");
+			System.out.print("failure ");
+			System.exit(1);
 		}
 	}
 	
 	private static void checkSuccess(long value, int success) {
 	
 		if (value==success) {
-			System.out.println("success ");
+			System.out.print("success ");
 		} else {
-			System.out.println("failure ");
-			
-			
-			System.exit(0);
+			System.out.print(value+"!="+success+" ");
+			System.out.print("failure ");
+			System.exit(1);
 		}
 	}
 	
 	private static void checkSuccess(boolean value, int success) {
 	
 		if (((value)?1:0)==success) {
-			System.out.println("success ");
+			System.out.print("success ");
 		} else {
-			System.out.println("failure ");
-			
-			
-			System.exit(0);
+			System.out.print(value+"!="+success+" ");
+			System.out.print("failure ");
+			System.exit(1);
 		}
 	}
 	
@@ -85,16 +76,11 @@ class firebird {
 		String	filename;
 		long[]	fieldlens;
 	
-		// usage...
-		if (args.length<5) {
-			System.out.println("usage: java firebird host port socket user password");
-			System.exit(0);
-		}
-	
 		// instantiation
-		SQLRConnection con=new SQLRConnection(args[0],
-					(short)Integer.parseInt(args[1]), 
-						args[2],args[3],args[4],0,1);
+		SQLRConnection con=new SQLRConnection("sqlrserver",
+						(short)9000,
+						"/tmp/test.socket",
+						"test","test",0,1);
 		SQLRCursor cur=new SQLRCursor(con);
 	
 		// get database type
@@ -112,13 +98,13 @@ class firebird {
 		con.commit();
 	
 		System.out.println("INSERT: ");
-		checkSuccess(cur.sendQuery("insert into testtable values (1,1,1.1,1.1,1.1,1.1,'01-JAN-2001','01:00:00','testchar1','testvarchar1',null)"),1);
+		checkSuccess(cur.sendQuery("insert into testtable values (1,1,1.1,1.1,1.1,1.1,'01-JAN-2001','01:00:00','testchar1','testvarchar1',null,null)"),1);
 		System.out.println();
 	
 	
 		System.out.println("BIND BY POSITION: ");
 
-		cur.prepareQuery("insert into testtable values (?,?,?,?,?,?,?,?,?,?,?)");
+		cur.prepareQuery("insert into testtable values (?,?,?,?,?,?,?,?,?,?,?,null)");
 		checkSuccess(cur.countBindVariables(),11);
 		cur.inputBind("1",2);
 		cur.inputBind("2",2);
@@ -154,31 +140,45 @@ class firebird {
 		System.out.println();
 	
 		System.out.println("INSERT: ");
-		checkSuccess(cur.sendQuery("insert into testtable values (5,5,5.5,5.5,5.5,5.5,'01-JAN-2005','05:00:00','testchar5','testvarchar5',null)"),1);
-		checkSuccess(cur.sendQuery("insert into testtable values (6,6,6.6,6.6,6.6,6.6,'01-JAN-2006','06:00:00','testchar6','testvarchar6',null)"),1);
-		checkSuccess(cur.sendQuery("insert into testtable values (7,7,7.7,7.7,7.7,7.7,'01-JAN-2007','07:00:00','testchar7','testvarchar7',null)"),1);
-		checkSuccess(cur.sendQuery("insert into testtable values (8,8,8.8,8.8,8.8,8.8,'01-JAN-2008','08:00:00','testchar8','testvarchar8',null)"),1);
+		checkSuccess(cur.sendQuery("insert into testtable values (5,5,5.5,5.5,5.5,5.5,'01-JAN-2005','05:00:00','testchar5','testvarchar5',null,null)"),1);
+		checkSuccess(cur.sendQuery("insert into testtable values (6,6,6.6,6.6,6.6,6.6,'01-JAN-2006','06:00:00','testchar6','testvarchar6',null,null)"),1);
+		checkSuccess(cur.sendQuery("insert into testtable values (7,7,7.7,7.7,7.7,7.7,'01-JAN-2007','07:00:00','testchar7','testvarchar7',null,null)"),1);
+		checkSuccess(cur.sendQuery("insert into testtable values (8,8,8.8,8.8,8.8,8.8,'01-JAN-2008','08:00:00','testchar8','testvarchar8',null,null)"),1);
 		System.out.println();
 	
 		System.out.println("AFFECTED ROWS: ");
 		checkSuccess(cur.affectedRows(),0);
 		System.out.println();
 
-	    System.out.println("STORED PROCEDURE: ");
-	    checkSuccess(cur.sendQuery("create procedure testproc(invar integer) returns (outvar integer) as begin outvar = invar; suspend; end"),1);
-	    cur.prepareQuery("select * from testproc(?)");
-	    cur.inputBind("1",5);
-	    checkSuccess(cur.executeQuery(),1);
-	    checkSuccess(cur.getField(0,0),"5");
-	    checkSuccess(cur.sendQuery("drop procedure testproc"),1);
-	    System.out.println();
+	    	System.out.println("STORED PROCEDURE: ");
+	    	cur.prepareQuery("select * from testproc(?,?,?,null)");
+	    	cur.inputBind("1",1);
+	    	cur.inputBind("2",1.1,2,1);
+	    	cur.inputBind("3","hello");
+	    	checkSuccess(cur.executeQuery(),1);
+	    	checkSuccess(cur.getField(0,0),"1");
+	    	checkSuccess(cur.getField(0,1),"1.1000");
+	    	checkSuccess(cur.getField(0,2),"hello");
+	    	cur.prepareQuery("execute procedure testproc ?, ?, ?, null");
+	    	cur.inputBind("1",1);
+	    	cur.inputBind("2",1.1,2,1);
+	    	cur.inputBind("3","hello");
+		cur.defineOutputBindInteger("1");
+		cur.defineOutputBindDouble("2");
+		cur.defineOutputBindString("3",20);
+		cur.defineOutputBindBlob("4");
+		checkSuccess(cur.executeQuery(),1);
+		checkSuccess(cur.getOutputBindInteger("1"),1);
+		//checkSuccess(cur.getOutputBindDouble("2"),1.1);
+		checkSuccess(cur.getOutputBindString("3"),"hello               ");
+	    	System.out.println();
 	
 		System.out.println("SELECT: ");
 		checkSuccess(cur.sendQuery("select * from testtable order by testinteger"),1);
 		System.out.println();
 	
 		System.out.println("COLUMN COUNT: ");
-		checkSuccess(cur.colCount(),11);
+		checkSuccess(cur.colCount(),12);
 		System.out.println();
 	
 		System.out.println("COLUMN NAMES: ");
@@ -618,7 +618,7 @@ class firebird {
 		System.out.println();
 	
 		System.out.println("COLUMN COUNT FOR CACHED RESULT SET: ");
-		checkSuccess(cur.colCount(),11);
+		checkSuccess(cur.colCount(),12);
 		System.out.println();
 	
 		System.out.println("COLUMN NAMES FOR CACHED RESULT SET: ");
@@ -720,9 +720,10 @@ class firebird {
 		System.out.println();
 	
 		//System.out.println("COMMIT AND ROLLBACK: ");
-		SQLRConnection secondcon=new SQLRConnection(args[0],
-					(short)Integer.parseInt(args[1]), 
-					args[2],args[3],args[4],0,1);
+		SQLRConnection secondcon=new SQLRConnection("sqlrserver",
+						(short)9000,
+						"/tmp/test.socket",
+						"test","test",0,1);
 		SQLRCursor secondcur=new SQLRCursor(secondcon);
 		checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
 		checkSuccess(secondcur.getField(0,0),"0");
@@ -730,7 +731,7 @@ class firebird {
 		checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
 		checkSuccess(secondcur.getField(0,0),"8");
 		checkSuccess(con.autoCommitOn(),1);
-		checkSuccess(cur.sendQuery("insert into testtable values (10,10,10.1,10.1,10.1,10.1,'01-JAN-2010','10:00:00','testchar10','testvarchar10',null)"),1);
+		checkSuccess(cur.sendQuery("insert into testtable values (10,10,10.1,10.1,10.1,10.1,'01-JAN-2010','10:00:00','testchar10','testvarchar10',null,null)"),1);
 		checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
 		checkSuccess(secondcur.getField(0,0),"9");
 		checkSuccess(con.autoCommitOff(),1);
@@ -778,6 +779,5 @@ class firebird {
 		checkSuccess(cur.sendQuery("create table testtable"),0);
 		checkSuccess(cur.sendQuery("create table testtable"),0);
 		System.out.println();
-	
 	}
 }
