@@ -7,56 +7,47 @@ import com.firstworks.sqlrelay.SQLRCursor;
 
 class mysql {
 	
-	
-	
-	
-	
-	
 	private static void checkSuccess(String value, String success) {
 	
 		if (success==null) {
 			if (value==null) {
-				System.out.println("success ");
+				System.out.print("success ");
 				return;
 			} else {
-				System.out.println("failure ");
-				
-				
-				System.exit(0);
+				System.out.print(value+"!="+success+" ");
+				System.out.print("failure ");
+				System.exit(1);
 			}
 		}
 	
 		if (value.equals(success)) {
-			System.out.println("success ");
+			System.out.print("success ");
 		} else {
-			System.out.println("failure ");
-			
-			
-			System.exit(0);
+			System.out.print(value+"!="+success+" ");
+			System.out.print("failure ");
+			System.exit(1);
 		}
 	}
 	
 	private static void checkSuccess(long value, int success) {
 	
 		if (value==success) {
-			System.out.println("success ");
+			System.out.print("success ");
 		} else {
-			System.out.println("failure ");
-			
-			
-			System.exit(0);
+			System.out.print(value+"!="+success+" ");
+			System.out.print("failure ");
+			System.exit(1);
 		}
 	}
 	
 	private static void checkSuccess(boolean value, int success) {
 	
 		if (((value)?1:0)==success) {
-			System.out.println("success ");
+			System.out.print("success ");
 		} else {
-			System.out.println("failure ");
-			
-			
-			System.exit(0);
+			System.out.print(value+"!="+success+" ");
+			System.out.print("failure ");
+			System.exit(1);
 		}
 	}
 	
@@ -81,17 +72,11 @@ class mysql {
 		long[]	fieldlens;
 	
 	
-		// usage...
-		if (args.length<5) {
-			System.out.println("usage: java mysql host port socket user password");
-			System.exit(0);
-		}
-	
-	
 		// instantiation
-		SQLRConnection con=new SQLRConnection(args[0],
-					(short)Integer.parseInt(args[1]), 
-						args[2],args[3],args[4],0,1);
+		SQLRConnection con=new SQLRConnection("sqlrserver",
+						(short)9000,
+						"/tmp/test.socket",
+						"test","test",0,1);
 		SQLRCursor cur=new SQLRCursor(con);
 	
 		// get database type
@@ -122,90 +107,90 @@ class mysql {
 		checkSuccess(cur.affectedRows(),1);
 		System.out.println();
 	
-		System.out.println("BIND BY NAME: ");
-		cur.prepareQuery("insert into testdb.testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7,:var8,:var9,:var10,:var11,:var12,:var13,:var14,:var15,:var16,:var17,:var18,null)");
+		System.out.println("BIND BY POSITION: ");
+		cur.prepareQuery("insert into testdb.testtable values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,null)");
 		checkSuccess(cur.countBindVariables(),18);
-		cur.inputBind("var1",5);
-		cur.inputBind("var2",5);
-		cur.inputBind("var3",5);
-		cur.inputBind("var4",5);
-		cur.inputBind("var5",5);
-		cur.inputBind("var6",5.1,2,1);
-		cur.inputBind("var7",5.1,2,1);
-		cur.inputBind("var8",5.1,2,1);
-		cur.inputBind("var9","2005-01-01");
-		cur.inputBind("var10","05:00:00");
-		cur.inputBind("var11","2005-01-01 05:00:00");
-		cur.inputBind("var12","2005");
-		cur.inputBind("var13","char5");
-		cur.inputBind("var14","text5");
-		cur.inputBind("var15","varchar5");
-		cur.inputBind("var16","tinytext5");
-		cur.inputBind("var17","mediumtext5");
-		cur.inputBind("var18","longtext5");
+		cur.inputBind("1",5);
+		cur.inputBind("2",5);
+		cur.inputBind("3",5);
+		cur.inputBind("4",5);
+		cur.inputBind("5",5);
+		cur.inputBind("6",5.1,2,1);
+		cur.inputBind("7",5.1,2,1);
+		cur.inputBind("8",5.1,2,1);
+		cur.inputBind("9","2005-01-01");
+		cur.inputBind("10","05:00:00");
+		cur.inputBind("11","2005-01-01 05:00:00");
+		cur.inputBind("12","2005");
+		cur.inputBind("13","char5");
+		cur.inputBind("14","text5");
+		cur.inputBind("15","varchar5");
+		cur.inputBind("16","tinytext5");
+		cur.inputBind("17","mediumtext5");
+		cur.inputBind("18","longtext5");
 		checkSuccess(cur.executeQuery(),1);
 		cur.clearBinds();
-		cur.inputBind("var1",6);
-		cur.inputBind("var2",6);
-		cur.inputBind("var3",6);
-		cur.inputBind("var4",6);
-		cur.inputBind("var5",6);
-		cur.inputBind("var6",6.1,2,1);
-		cur.inputBind("var7",6.1,2,1);
-		cur.inputBind("var8",6.1,2,1);
-		cur.inputBind("var9","2006-01-01");
-		cur.inputBind("var10","06:00:00");
-		cur.inputBind("var11","2006-01-01 06:00:00");
-		cur.inputBind("var12","2006");
-		cur.inputBind("var13","char6");
-		cur.inputBind("var14","text6");
-		cur.inputBind("var15","varchar6");
-		cur.inputBind("var16","tinytext6");
-		cur.inputBind("var17","mediumtext6");
-		cur.inputBind("var18","longtext6");
+		cur.inputBind("1",6);
+		cur.inputBind("2",6);
+		cur.inputBind("3",6);
+		cur.inputBind("4",6);
+		cur.inputBind("5",6);
+		cur.inputBind("6",6.1,2,1);
+		cur.inputBind("7",6.1,2,1);
+		cur.inputBind("8",6.1,2,1);
+		cur.inputBind("9","2006-01-01");
+		cur.inputBind("10","06:00:00");
+		cur.inputBind("11","2006-01-01 06:00:00");
+		cur.inputBind("12","2006");
+		cur.inputBind("13","char6");
+		cur.inputBind("14","text6");
+		cur.inputBind("15","varchar6");
+		cur.inputBind("16","tinytext6");
+		cur.inputBind("17","mediumtext6");
+		cur.inputBind("18","longtext6");
 		checkSuccess(cur.executeQuery(),1);
 		cur.clearBinds();
-		cur.inputBind("var1",7);
-		cur.inputBind("var2",7);
-		cur.inputBind("var3",7);
-		cur.inputBind("var4",7);
-		cur.inputBind("var5",7);
-		cur.inputBind("var6",7.1,2,1);
-		cur.inputBind("var7",7.1,2,1);
-		cur.inputBind("var8",7.1,2,1);
-		cur.inputBind("var9","2007-01-01");
-		cur.inputBind("var10","07:00:00");
-		cur.inputBind("var11","2007-01-01 07:00:00");
-		cur.inputBind("var12","2007");
-		cur.inputBind("var13","char7");
-		cur.inputBind("var14","text7");
-		cur.inputBind("var15","varchar7");
-		cur.inputBind("var16","tinytext7");
-		cur.inputBind("var17","mediumtext7");
-		cur.inputBind("var18","longtext7");
+		cur.inputBind("1",7);
+		cur.inputBind("2",7);
+		cur.inputBind("3",7);
+		cur.inputBind("4",7);
+		cur.inputBind("5",7);
+		cur.inputBind("6",7.1,2,1);
+		cur.inputBind("7",7.1,2,1);
+		cur.inputBind("8",7.1,2,1);
+		cur.inputBind("9","2007-01-01");
+		cur.inputBind("10","07:00:00");
+		cur.inputBind("11","2007-01-01 07:00:00");
+		cur.inputBind("12","2007");
+		cur.inputBind("13","char7");
+		cur.inputBind("14","text7");
+		cur.inputBind("15","varchar7");
+		cur.inputBind("16","tinytext7");
+		cur.inputBind("17","mediumtext7");
+		cur.inputBind("18","longtext7");
 		checkSuccess(cur.executeQuery(),1);
 		System.out.println();
 	
-		System.out.println("BIND BY NAME WITH VALIDATION: ");
+		System.out.println("BIND BY POSITION WITH VALIDATION: ");
 		cur.clearBinds();
-		cur.inputBind("var1",8);
-		cur.inputBind("var2",8);
-		cur.inputBind("var3",8);
-		cur.inputBind("var4",8);
-		cur.inputBind("var5",8);
-		cur.inputBind("var6",8.1,2,1);
-		cur.inputBind("var7",8.1,2,1);
-		cur.inputBind("var8",8.1,2,1);
-		cur.inputBind("var9","2008-01-01");
-		cur.inputBind("var10","08:00:00");
-		cur.inputBind("var11","2008-01-01 08:00:00");
-		cur.inputBind("var12","2008");
-		cur.inputBind("var13","char8");
-		cur.inputBind("var14","text8");
-		cur.inputBind("var15","varchar8");
-		cur.inputBind("var16","tinytext8");
-		cur.inputBind("var17","mediumtext8");
-		cur.inputBind("var18","longtext8");
+		cur.inputBind("1",8);
+		cur.inputBind("2",8);
+		cur.inputBind("3",8);
+		cur.inputBind("4",8);
+		cur.inputBind("5",8);
+		cur.inputBind("6",8.1,2,1);
+		cur.inputBind("7",8.1,2,1);
+		cur.inputBind("8",8.1,2,1);
+		cur.inputBind("9","2008-01-01");
+		cur.inputBind("10","08:00:00");
+		cur.inputBind("11","2008-01-01 08:00:00");
+		cur.inputBind("12","2008");
+		cur.inputBind("13","char8");
+		cur.inputBind("14","text8");
+		cur.inputBind("15","varchar8");
+		cur.inputBind("16","tinytext8");
+		cur.inputBind("17","mediumtext8");
+		cur.inputBind("18","longtext8");
 		cur.validateBinds();
 		checkSuccess(cur.executeQuery(),1);
 		System.out.println();
@@ -273,7 +258,7 @@ class mysql {
 		checkSuccess(cur.getColumnType(9),"TIME");
 		checkSuccess(cur.getColumnType(10),"DATETIME");
 		checkSuccess(cur.getColumnType(11),"YEAR");
-		checkSuccess(cur.getColumnType(12),"CHAR");
+		checkSuccess(cur.getColumnType(12),"STRING");
 		checkSuccess(cur.getColumnType(13),"BLOB");
 		checkSuccess(cur.getColumnType(14),"CHAR");
 		checkSuccess(cur.getColumnType(15),"TINYBLOB");
@@ -292,7 +277,7 @@ class mysql {
 		checkSuccess(cur.getColumnType("testtime"),"TIME");
 		checkSuccess(cur.getColumnType("testdatetime"),"DATETIME");
 		checkSuccess(cur.getColumnType("testyear"),"YEAR");
-		checkSuccess(cur.getColumnType("testchar"),"CHAR");
+		checkSuccess(cur.getColumnType("testchar"),"STRING");
 		checkSuccess(cur.getColumnType("testtext"),"BLOB");
 		checkSuccess(cur.getColumnType("testvarchar"),"CHAR");
 		checkSuccess(cur.getColumnType("testtinytext"),"TINYBLOB");
@@ -314,7 +299,7 @@ class mysql {
 		checkSuccess(cur.getColumnLength(9),3);
 		checkSuccess(cur.getColumnLength(10),8);
 		checkSuccess(cur.getColumnLength(11),1);
-		checkSuccess(cur.getColumnLength(12),41);
+		checkSuccess(cur.getColumnLength(12),40);
 		checkSuccess(cur.getColumnLength(13),65535);
 		checkSuccess(cur.getColumnLength(14),41);
 		checkSuccess(cur.getColumnLength(15),255);
@@ -333,7 +318,7 @@ class mysql {
 		checkSuccess(cur.getColumnLength("testtime"),3);
 		checkSuccess(cur.getColumnLength("testdatetime"),8);
 		checkSuccess(cur.getColumnLength("testyear"),1);
-		checkSuccess(cur.getColumnLength("testchar"),41);
+		checkSuccess(cur.getColumnLength("testchar"),40);
 		checkSuccess(cur.getColumnLength("testtext"),65535);
 		checkSuccess(cur.getColumnLength("testvarchar"),41);
 		checkSuccess(cur.getColumnLength("testtinytext"),255);
@@ -916,21 +901,27 @@ class mysql {
 		System.out.println();
 	
 		System.out.println("COMMIT AND ROLLBACK: ");
-		SQLRConnection secondcon=new SQLRConnection(args[0],
-					(short)Integer.parseInt(args[1]), 
-						args[2],args[3],args[4],0,1);
+		// Note: Mysql's default isolation level is repeatable-read,
+		// not read-committed like most other db's.  Both sessions must
+		// commit to see the changes that each other has made.
+		SQLRConnection secondcon=new SQLRConnection("sqlrserver",
+						(short)9000,
+						"/tmp/test.socket",
+						"test","test",0,1);
 		SQLRCursor secondcur=new SQLRCursor(secondcon);
 		checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
-		checkSuccess(secondcur.getField(0,0),"8");
+		checkSuccess(secondcur.getField(0,0),"0");
 		checkSuccess(con.commit(),1);
 		checkSuccess(secondcon.commit(),1);
 		checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
 		checkSuccess(secondcur.getField(0,0),"8");
 		checkSuccess(con.autoCommitOn(),1);
 		checkSuccess(cur.sendQuery("insert into testdb.testtable values (10,10,10,10,10,10.1,10.1,10.1,'2010-01-01','10:00:00','2010-01-01 10:00:00','2010','char10','text10','varchar10','tinytext10','mediumtext10','longtext10',null)"),1);
+		checkSuccess(secondcon.commit(),1);
 		checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
 		checkSuccess(secondcur.getField(0,0),"9");
 		checkSuccess(con.autoCommitOff(),1);
+		secondcon.commit();
 		System.out.println();
 
 		System.out.println("FINISHED SUSPENDED SESSION: ");
