@@ -7,56 +7,47 @@ import com.firstworks.sqlrelay.SQLRCursor;
 
 class sqlite {
 	
-	
-	
-	
-	
-	
 	private static void checkSuccess(String value, String success) {
 	
 		if (success==null) {
 			if (value==null) {
-				System.out.println("success ");
+				System.out.print("success ");
 				return;
 			} else {
-				System.out.println("failure ");
-				
-				
-				System.exit(0);
+				System.out.print(value+"!="+success+" ");
+				System.out.print("failure ");
+				System.exit(1);
 			}
 		}
 	
 		if (value.equals(success)) {
-			System.out.println("success ");
+			System.out.print("success ");
 		} else {
-			System.out.println("failure ");
-			
-			
-			System.exit(0);
+			System.out.print(value+"!="+success+" ");
+			System.out.print("failure ");
+			System.exit(1);
 		}
 	}
 	
 	private static void checkSuccess(long value, int success) {
 	
 		if (value==success) {
-			System.out.println("success ");
+			System.out.print("success ");
 		} else {
-			System.out.println("failure ");
-			
-			
-			System.exit(0);
+			System.out.print(value+"!="+success+" ");
+			System.out.print("failure ");
+			System.exit(1);
 		}
 	}
 	
 	private static void checkSuccess(boolean value, int success) {
 	
 		if (((value)?1:0)==success) {
-			System.out.println("success ");
+			System.out.print("success ");
 		} else {
-			System.out.println("failure ");
-			
-			
-			System.exit(0);
+			System.out.print(value+"!="+success+" ");
+			System.out.print("failure ");
+			System.exit(1);
 		}
 	}
 	
@@ -80,16 +71,11 @@ class sqlite {
 		String	filename;
 		long[]	fieldlens;
 	
-		// usage...
-		if (args.length<5) {
-			System.out.println("usage: java sqlite host port socket user password");
-			System.exit(0);
-		}
-	
 		// instantiation
-		SQLRConnection con=new SQLRConnection(args[0],
-					(short)Integer.parseInt(args[1]), 
-						args[2],args[3],args[4],0,1);
+		SQLRConnection con=new SQLRConnection("sqlrserver",
+						(short)9000,
+						"/tmp/test.socket",
+						"test","test",0,1);
 		SQLRCursor cur=new SQLRCursor(con);
 	
 		// get database type
@@ -179,14 +165,14 @@ class sqlite {
 		System.out.println();
 	
 		System.out.println("COLUMN TYPES: ");
-		checkSuccess(cur.getColumnType(0),"UNKNOWN");
-		checkSuccess(cur.getColumnType("testint"),"UNKNOWN");
-		checkSuccess(cur.getColumnType(1),"UNKNOWN");
-		checkSuccess(cur.getColumnType("testfloat"),"UNKNOWN");
-		checkSuccess(cur.getColumnType(2),"UNKNOWN");
-		checkSuccess(cur.getColumnType("testchar"),"UNKNOWN");
-		checkSuccess(cur.getColumnType(3),"UNKNOWN");
-		checkSuccess(cur.getColumnType("testvarchar"),"UNKNOWN");
+		checkSuccess(cur.getColumnType(0),"INTEGER");
+		checkSuccess(cur.getColumnType("testint"),"INTEGER");
+		checkSuccess(cur.getColumnType(1),"FLOAT");
+		checkSuccess(cur.getColumnType("testfloat"),"FLOAT");
+		checkSuccess(cur.getColumnType(2),"STRING");
+		checkSuccess(cur.getColumnType("testchar"),"STRING");
+		checkSuccess(cur.getColumnType(3),"STRING");
+		checkSuccess(cur.getColumnType("testvarchar"),"STRING");
 		System.out.println();
 	
 		System.out.println("COLUMN LENGTH: ");
@@ -216,7 +202,7 @@ class sqlite {
 		System.out.println();
 	
 		System.out.println("TOTAL ROWS: ");
-		checkSuccess(cur.totalRows(),8);
+		checkSuccess(cur.totalRows(),0);
 		System.out.println();
 	
 		System.out.println("FIRST ROW INDEX: ");
@@ -408,7 +394,7 @@ class sqlite {
 		checkSuccess(cur.sendQuery("select * from testtable order by testint"),1);
 		checkSuccess(cur.getColumnName(0),"testint");
 		checkSuccess(cur.getColumnLength(0),0);
-		checkSuccess(cur.getColumnType(0),"UNKNOWN");
+		checkSuccess(cur.getColumnType(0),"INTEGER");
 		System.out.println();
 	
 		System.out.println("SUSPENDED SESSION: ");
@@ -589,9 +575,10 @@ class sqlite {
 		System.out.println();
 
 	    	System.out.println("COMMIT AND ROLLBACK: \n");
-	    	SQLRConnection secondcon=new SQLRConnection(args[0],
-				    	(short)Integer.parseInt(args[1]), 
-				    	args[2],args[3],args[4],0,1);
+		SQLRConnection secondcon=new SQLRConnection("sqlrserver",
+						(short)9000,
+						"/tmp/test.socket",
+						"test","test",0,1);
 	    	SQLRCursor secondcur=new SQLRCursor(secondcon);
 	    	checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1);
 	    	checkSuccess(secondcur.getField(0,0),"0");
