@@ -15,7 +15,7 @@ sub checkUndef {
 		print("success ");
 	} else {
 		print("failure ");
-		exit;
+		exit(1);
 	}
 }
 
@@ -27,8 +27,9 @@ sub checkSuccess {
 	if ($value==$success) {
 		print("success ");
 	} else {
+		print("$value != $success ");
 		print("failure ");
-		exit;
+		exit(1);
 	}
 }
 
@@ -40,21 +41,16 @@ sub checkSuccessString {
 	if ($value eq $success) {
 		print("success ");
 	} else {
+		print("$value != $success ");
 		print("failure ");
-		exit;
+		exit(1);
 	}
 }
 
 
-# usage...
-if ($#ARGV+1<5) {
-	print("usage: db2.pl host port socket user password");
-	exit;
-}
-
 # instantiation
-$con=SQLRelay::Connection->new($ARGV[0],$ARGV[1],
-					$ARGV[2],$ARGV[3],$ARGV[4],0,1);
+$con=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket",
+							"test","test",0,1);
 $cur=SQLRelay::Cursor->new($con);
 
 # get database type
@@ -132,9 +128,9 @@ $cur->sendQuery("drop procedure testproc");
 checkSuccess($cur->sendQuery("create procedure testproc(in invar int, out outvar int) language sql begin set outvar = invar; end"),1);
 $cur->prepareQuery("call testproc(?,?)");
 $cur->inputBind("1",5);
-$cur->defineOutputBind("2",10);
+$cur->defineOutputBindString("2",10);
 checkSuccess($cur->executeQuery(),1);
-checkSuccess($cur->getOutputBind("2"),"5");
+checkSuccess($cur->getOutputBindString("2"),"5");
 checkSuccess($cur->sendQuery("drop procedure testproc"),1);
 print("\n");
 
