@@ -15,7 +15,7 @@ sub checkUndef {
 		print("success ");
 	} else {
 		print("failure ");
-		exit;
+		exit(1);
 	}
 }
 
@@ -27,8 +27,9 @@ sub checkSuccess {
 	if ($value==$success) {
 		print("success ");
 	} else {
+		print("$value != $success ");
 		print("failure ");
-		exit;
+		exit(1);
 	}
 }
 
@@ -40,21 +41,16 @@ sub checkSuccessString {
 	if ($value eq $success) {
 		print("success ");
 	} else {
+		print("$value != $success ");
 		print("failure ");
-		exit;
+		exit(1);
 	}
 }
 
 
-# usage...
-if ($#ARGV+1<5) {
-	print("usage: firebird.pl host port socket user password");
-	exit;
-}
-
 # instantiation
-$con=SQLRelay::Connection->new($ARGV[0],$ARGV[1],
-		$ARGV[2],$ARGV[3],$ARGV[4],0,1);
+$con=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket",
+							"test","test",0,1);
 $cur=SQLRelay::Cursor->new($con);
 
 # get database type
@@ -72,12 +68,12 @@ $cur->sendQuery("delete from testtable");
 $con->commit();
 
 print("INSERT: \n");
-checkSuccess($cur->sendQuery("insert into testtable values (1,1,1.1,1.1,1.1,1.1,'01-JAN-2001','01:00:00','testchar1','testvarchar1',NULL)"),1);
+checkSuccess($cur->sendQuery("insert into testtable values (1,1,1.1,1.1,1.1,1.1,'01-JAN-2001','01:00:00','testchar1','testvarchar1',NULL,NULL)"),1);
 print("\n");
 
 
 print("BIND BY POSITION: \n");
-$cur->prepareQuery("insert into testtable values (?,?,?,?,?,?,?,?,?,?,?)");
+$cur->prepareQuery("insert into testtable values (?,?,?,?,?,?,?,?,?,?,?,NULL)");
 checkSuccess($cur->countBindVariables(),11);
 $cur->inputBind("1",2);
 $cur->inputBind("2",2);
@@ -118,10 +114,10 @@ checkSuccess($cur->executeQuery(),1);
 print("\n");
 
 print("INSERT: \n");
-checkSuccess($cur->sendQuery("insert into testtable values (5,5,5.5,5.5,5.5,5.5,'01-JAN-2005','05:00:00','testchar5','testvarchar5',NULL)"),1);
-checkSuccess($cur->sendQuery("insert into testtable values (6,6,6.6,6.6,6.6,6.6,'01-JAN-2006','06:00:00','testchar6','testvarchar6',NULL)"),1);
-checkSuccess($cur->sendQuery("insert into testtable values (7,7,7.7,7.7,7.7,7.7,'01-JAN-2007','07:00:00','testchar7','testvarchar7',NULL)"),1);
-checkSuccess($cur->sendQuery("insert into testtable values (8,8,8.8,8.8,8.8,8.8,'01-JAN-2008','08:00:00','testchar8','testvarchar8',NULL)"),1);
+checkSuccess($cur->sendQuery("insert into testtable values (5,5,5.5,5.5,5.5,5.5,'01-JAN-2005','05:00:00','testchar5','testvarchar5',NULL,NULL)"),1);
+checkSuccess($cur->sendQuery("insert into testtable values (6,6,6.6,6.6,6.6,6.6,'01-JAN-2006','06:00:00','testchar6','testvarchar6',NULL,NULL)"),1);
+checkSuccess($cur->sendQuery("insert into testtable values (7,7,7.7,7.7,7.7,7.7,'01-JAN-2007','07:00:00','testchar7','testvarchar7',NULL,NULL)"),1);
+checkSuccess($cur->sendQuery("insert into testtable values (8,8,8.8,8.8,8.8,8.8,'01-JAN-2008','08:00:00','testchar8','testvarchar8',NULL,NULL)"),1);
 print("\n");
 
 print("AFFECTED ROWS: \n");
@@ -129,12 +125,29 @@ checkSuccess($cur->affectedRows(),0);
 print("\n");
 
 print("STORED PROCEDURE: \n");
-checkSuccess($cur->sendQuery("create procedure testproc(invar integer) returns (outvar integer) as begin outvar = invar; suspend; end"),1);
-$cur->prepareQuery("select * from testproc(?)");
-$cur->inputBind("1",5);
+$cur->prepareQuery("select * from testproc(?,?,?,NULL)");
+$cur->inputBind("1",1);
+$cur->inputBind("2",1.1,2,1);
+$cur->inputBind("3","hello");
 checkSuccess($cur->executeQuery(),1);
-checkSuccess($cur->getField(0,0),"5");
-checkSuccess($cur->sendQuery("drop procedure testproc"),1);
+checkSuccess($cur->getField(0,0),"1");
+checkSuccess($cur->getField(0,1),"1.1000");
+checkSuccess($cur->getField(0,2),"hello");
+$cur->prepareQuery("execute procedure testproc ?, ?, ?, NULL");
+$cur->inputBind("1",1);
+$cur->inputBind("2",1.1,2,1);
+$cur->inputBind("3","hello");
+$cur->defineOutputBindInteger("1");
+$cur->defineOutputBindDouble("2");
+$cur->defineOutputBindString("3",20);
+$cur->defineOutputBindBlob("4");
+checkSuccess($cur->executeQuery(),1);
+$numvar=$cur->getOutputBindInteger("1");
+$floatvar=$cur->getOutputBindDouble("2");
+$stringvar=$cur->getOutputBindString("3");
+checkSuccess($numvar,1);
+#checkSuccess($floatvar,1.1);
+checkSuccess($stringvar,"hello               ");
 print("\n");
 
 print("SELECT: \n");
@@ -142,7 +155,7 @@ checkSuccess($cur->sendQuery("select * from testtable order by testinteger"),1);
 print("\n");
 
 print("COLUMN COUNT: \n");
-checkSuccess($cur->colCount(),11);
+checkSuccess($cur->colCount(),12);
 print("\n");
 
 print("COLUMN NAMES: \n");
@@ -614,7 +627,7 @@ checkSuccessString($cur->getField(7,0),"8");
 print("\n");
 
 print("COLUMN COUNT FOR CACHED RESULT SET: \n");
-checkSuccess($cur->colCount(),11);
+checkSuccess($cur->colCount(),12);
 print("\n");
 
 print("COLUMN NAMES FOR CACHED RESULT SET: \n");
@@ -716,9 +729,8 @@ $cur->setResultSetBufferSize(0);
 print("\n");
 
 #print("COMMIT AND ROLLBACK: \n");
-$secondcon=SQLRelay::Connection->new($ARGV[0],
-			$ARGV[1], 
-		$ARGV[2],$ARGV[3],$ARGV[4],0,1);
+$secondcon=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket",
+							"test","test",0,1);
 $secondcur=SQLRelay::Cursor->new($secondcon);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
 checkSuccessString($secondcur->getField(0,0),"0");
@@ -726,7 +738,7 @@ checkSuccess($con->commit(),1);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
 checkSuccessString($secondcur->getField(0,0),"8");
 checkSuccess($con->autoCommitOn(),1);
-checkSuccess($cur->sendQuery("insert into testtable values (10,10,10.1,10.1,10.1,10.1,'01-JAN-2010','10:00:00','testchar10','testvarchar10',NULL)"),1);
+checkSuccess($cur->sendQuery("insert into testtable values (10,10,10.1,10.1,10.1,10.1,'01-JAN-2010','10:00:00','testchar10','testvarchar10',NULL,NULL)"),1);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
 checkSuccessString($secondcur->getField(0,0),"9");
 checkSuccess($con->autoCommitOff(),1);
