@@ -15,7 +15,7 @@ sub checkUndef {
 		print("success ");
 	} else {
 		print("failure ");
-		exit;
+		exit(1);
 	}
 }
 
@@ -27,8 +27,9 @@ sub checkSuccess {
 	if ($value==$success) {
 		print("success ");
 	} else {
+		print("$value != $success ");
 		print("failure ");
-		exit;
+		exit(1);
 	}
 }
 
@@ -40,20 +41,15 @@ sub checkSuccessString {
 	if ($value eq $success) {
 		print("success ");
 	} else {
+		print("$value != $success ");
 		print("failure ");
-		exit;
+		exit(1);
 	}
 }
 
-# usage...
-if ($#ARGV+1<5) {
-	print("usage: sqlite.pl host port socket user password");
-	exit;
-}
-
 # instantiation
-$con=SQLRelay::Connection->new($ARGV[0],$ARGV[1],
-		$ARGV[2],$ARGV[3],$ARGV[4],0,1);
+$con=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket",
+							"test","test",0,1);
 $cur=SQLRelay::Cursor->new($con);
 
 # get database type
@@ -147,14 +143,14 @@ checkSuccess($cols[3],"testvarchar");
 print("\n");
 
 print("COLUMN TYPES: \n");
-checkSuccess($cur->getColumnType(0),"UNKNOWN");
-checkSuccess($cur->getColumnType('testint'),"UNKNOWN");
-checkSuccess($cur->getColumnType(1),"UNKNOWN");
-checkSuccess($cur->getColumnType('testfloat'),"UNKNOWN");
-checkSuccess($cur->getColumnType(2),"UNKNOWN");
-checkSuccess($cur->getColumnType('testchar'),"UNKNOWN");
-checkSuccess($cur->getColumnType(3),"UNKNOWN");
-checkSuccess($cur->getColumnType('testvarchar'),"UNKNOWN");
+checkSuccess($cur->getColumnType(0),"INTEGER");
+checkSuccess($cur->getColumnType('testint'),"INTEGER");
+checkSuccess($cur->getColumnType(1),"FLOAT");
+checkSuccess($cur->getColumnType('testfloat'),"FLOAT");
+checkSuccess($cur->getColumnType(2),"STRING");
+checkSuccess($cur->getColumnType('testchar'),"STRING");
+checkSuccess($cur->getColumnType(3),"STRING");
+checkSuccess($cur->getColumnType('testvarchar'),"STRING");
 print("\n");
 
 print("COLUMN LENGTH: \n");
@@ -184,7 +180,7 @@ checkSuccess($cur->rowCount(),8);
 print("\n");
 
 print("TOTAL ROWS: \n");
-checkSuccess($cur->totalRows(),8);
+checkSuccess($cur->totalRows(),0);
 print("\n");
 
 print("FIRST ROW INDEX: \n");
@@ -377,7 +373,7 @@ $cur->getColumnInfo();
 checkSuccess($cur->sendQuery("select * from testtable order by testint"),1);
 checkSuccess($cur->getColumnName(0),"testint");
 checkSuccess($cur->getColumnLength(0),0);
-checkSuccess($cur->getColumnType(0),"UNKNOWN");
+checkSuccess($cur->getColumnType(0),"INTEGER");
 print("\n");
 
 print("SUSPENDED SESSION: \n");
@@ -558,9 +554,8 @@ $cur->setResultSetBufferSize(0);
 print("\n");
 
 print("COMMIT AND ROLLBACK: \n");
-$secondcon=SQLRelay::Connection->new($ARGV[0],
-				$ARGV[1], 
-				$ARGV[2],$ARGV[3],$ARGV[4],0,1);
+$secondcon=SQLRelay::Connection->new("sqlrserver",9000,"/tmp/test.socket",
+							"test","test",0,1);
 $secondcur=SQLRelay::Cursor->new($secondcon);
 checkSuccess($secondcur->sendQuery("select count(*) from testtable"),1);
 checkSuccess($secondcur->getField(0,0),"0");
