@@ -2,25 +2,24 @@
 # Copyright (c) 2001  David Muse
 # See the file COPYING for more information.
 
-dl("sql_relay.so");
+	function checkSuccess($value,$success) {
 
-function checkSuccess($value,$success) {
-
-	if ($value==$success) {
-		echo("success ");
-	} else {
-		echo("failure ");
-		sqlrcur_free($cur);
-		sqlrcon_free($con);
-		exit(0);
+		if ($value==$success) {
+			echo("success ");
+		} else {
+			echo("$value != $success ");
+			echo("failure ");
+			sqlrcur_free($cur);
+			sqlrcon_free($con);
+			exit(1);
+		}
 	}
-}
 
-	$host=$_REQUEST["host"];
-	$port=$_REQUEST["port"];
-	$socket=$_REQUEST["socket"];
-	$user=$_REQUEST["user"];
-	$password=$_REQUEST["password"];
+	$host="sqlrserver";
+	$port=9000;
+	$socket="/tmp/test.socket";
+	$user="test";
+	$password="test";
 
 	# instantiation
 	$con=sqlrcon_alloc($host,$port,$socket,$user,$password,0,1);
@@ -100,9 +99,9 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_sendQuery($cur,"create procedure testproc(in invar int, out outvar int) language sql begin set outvar = invar; end"),1);
 	sqlrcur_prepareQuery($cur,"call testproc(?,?)");
 	sqlrcur_inputBind($cur,"1",5);
-	sqlrcur_defineOutputBind($cur,"2",10);
+	sqlrcur_defineOutputBindString($cur,"2",10);
 	checkSuccess(sqlrcur_executeQuery($cur),1);
-	checkSuccess(sqlrcur_getOutputBind($cur,"2"),"5");
+	checkSuccess(sqlrcur_getOutputBindString($cur,"2"),"5");
 	checkSuccess(sqlrcur_sendQuery($cur,"drop procedure testproc"),1);
 	echo("\n");
 
@@ -574,11 +573,11 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("CACHED RESULT SET: \n");
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testsmallint"),1);
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	sqlrcur_cacheOff($cur);
 	checkSuccess(sqlrcur_openCachedResultSet($cur,$filename),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
@@ -616,11 +615,11 @@ function checkSuccess($value,$success) {
 
 	echo("CACHED RESULT SET WITH RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testsmallint"),1);
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	sqlrcur_cacheOff($cur);
 	checkSuccess(sqlrcur_openCachedResultSet($cur,$filename),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
@@ -629,20 +628,20 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("FROM ONE CACHE FILE TO ANOTHER: \n");
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile2");
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile1"),1);
+	sqlrcur_cacheToFile($cur,"cachefile2");
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile1"),1);
 	sqlrcur_cacheOff($cur);
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile2"),1);
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile2"),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
 	checkSuccess(sqlrcur_getField($cur,8,0),NULL);
 	echo("\n");
 
 	echo("FROM ONE CACHE FILE TO ANOTHER WITH RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile2");
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile1"),1);
+	sqlrcur_cacheToFile($cur,"cachefile2");
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile1"),1);
 	sqlrcur_cacheOff($cur);
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile2"),1);
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile2"),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
 	checkSuccess(sqlrcur_getField($cur,8,0),NULL);
 	sqlrcur_setResultSetBufferSize($cur,0);
@@ -650,12 +649,12 @@ function checkSuccess($value,$success) {
 
 	echo("CACHED RESULT SET WITH SUSPEND AND RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testsmallint"),1);
 	checkSuccess(sqlrcur_getField($cur,2,0),"3");
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	$id=sqlrcur_getResultSetId($cur);
 	sqlrcur_suspendResultSet($cur);
 	checkSuccess(sqlrcon_suspendSession($con),1);
