@@ -2,25 +2,24 @@
 # Copyright (c) 2001  David Muse
 # See the file COPYING for more information.
 
-dl("sql_relay.so");
+	function checkSuccess($value,$success) {
 
-function checkSuccess($value,$success) {
-
-	if ($value==$success) {
-		echo("success ");
-	} else {
-		echo("failure ");
-		sqlrcur_free($cur);
-		sqlrcon_free($con);
-		exit(0);
+		if ($value==$success) {
+			echo("success ");
+		} else {
+			echo("$value != $success ");
+			echo("failure ");
+			sqlrcur_free($cur);
+			sqlrcon_free($con);
+			exit(1);
+		}
 	}
-}
 
-	$host=$_REQUEST["host"];
-	$port=$_REQUEST["port"];
-	$socket=$_REQUEST["socket"];
-	$user=$_REQUEST["user"];
-	$password=$_REQUEST["password"];
+	$host="sqlrserver";
+	$port=9000;
+	$socket="/tmp/test.socket";
+	$user="test";
+	$password="test";
 
 	$subvars=array("var1","var2","var3");
 	$subvalstrings=array("hi","hello","bye");
@@ -48,12 +47,12 @@ function checkSuccess($value,$success) {
 	sqlrcon_commit($con);
 
 	echo("INSERT: \n");
-	checkSuccess(sqlrcur_sendQuery($cur,"insert into testtable values (1,1,1.1,1.1,1.1,1.1,'01-JAN-2001','01:00:00','testchar1','testvarchar1',NULL)"),1);
+	checkSuccess(sqlrcur_sendQuery($cur,"insert into testtable values (1,1,1.1,1.1,1.1,1.1,'01-JAN-2001','01:00:00','testchar1','testvarchar1',NULL,NULL)"),1);
 	echo("\n");
 
 
 	echo("BIND BY POSITION: \n");
-	sqlrcur_prepareQuery($cur,"insert into testtable values (?,?,?,?,?,?,?,?,?,?,?)");
+	sqlrcur_prepareQuery($cur,"insert into testtable values (?,?,?,?,?,?,?,?,?,?,?,NULL)");
 	checkSuccess(sqlrcur_countBindVariables($cur),11);
 	sqlrcur_inputBind($cur,"1",2);
 	sqlrcur_inputBind($cur,"2",2);
@@ -94,10 +93,10 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("INSERT: \n");
-	checkSuccess(sqlrcur_sendQuery($cur,"insert into testtable values (5,5,5.5,5.5,5.5,5.5,'01-JAN-2005','05:00:00','testchar5','testvarchar5',NULL)"),1);
-	checkSuccess(sqlrcur_sendQuery($cur,"insert into testtable values (6,6,6.6,6.6,6.6,6.6,'01-JAN-2006','06:00:00','testchar6','testvarchar6',NULL)"),1);
-	checkSuccess(sqlrcur_sendQuery($cur,"insert into testtable values (7,7,7.7,7.7,7.7,7.7,'01-JAN-2007','07:00:00','testchar7','testvarchar7',NULL)"),1);
-	checkSuccess(sqlrcur_sendQuery($cur,"insert into testtable values (8,8,8.8,8.8,8.8,8.8,'01-JAN-2008','08:00:00','testchar8','testvarchar8',NULL)"),1);
+	checkSuccess(sqlrcur_sendQuery($cur,"insert into testtable values (5,5,5.5,5.5,5.5,5.5,'01-JAN-2005','05:00:00','testchar5','testvarchar5',NULL,NULL)"),1);
+	checkSuccess(sqlrcur_sendQuery($cur,"insert into testtable values (6,6,6.6,6.6,6.6,6.6,'01-JAN-2006','06:00:00','testchar6','testvarchar6',NULL,NULL)"),1);
+	checkSuccess(sqlrcur_sendQuery($cur,"insert into testtable values (7,7,7.7,7.7,7.7,7.7,'01-JAN-2007','07:00:00','testchar7','testvarchar7',NULL,NULL)"),1);
+	checkSuccess(sqlrcur_sendQuery($cur,"insert into testtable values (8,8,8.8,8.8,8.8,8.8,'01-JAN-2008','08:00:00','testchar8','testvarchar8',NULL,NULL)"),1);
 	echo("\n");
 
 	echo("AFFECTED ROWS: \n");
@@ -105,12 +104,26 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("STORED PROCEDURE: \n");
-	checkSuccess(sqlrcur_sendQuery($cur,"create procedure testproc(invar integer) returns (outvar integer) as begin outvar = invar; suspend; end"),1);
-	sqlrcur_prepareQuery($cur,"select * from testproc(?)");
-	sqlrcur_inputBind($cur,"1",5);
+	sqlrcur_prepareQuery($cur,"select * from testproc(?,?,?,NULL)");
+	sqlrcur_inputBind($cur,"1",1);
+	sqlrcur_inputBind($cur,"2",1.1,2,1);
+	sqlrcur_inputBind($cur,"3","hello");
 	checkSuccess(sqlrcur_executeQuery($cur),1);
-	checkSuccess(sqlrcur_getField($cur,0,0),"5");
-	checkSuccess(sqlrcur_sendQuery($cur,"drop procedure testproc"),1);
+	checkSuccess(sqlrcur_getField($cur,0,0),"1");
+	checkSuccess(sqlrcur_getField($cur,0,1),"1.1000");
+	checkSuccess(sqlrcur_getField($cur,0,2),"hello");
+	sqlrcur_prepareQuery($cur,"execute procedure testproc ?, ?, ?, NULL");
+	sqlrcur_inputBind($cur,"1",1);
+	sqlrcur_inputBind($cur,"2",1.1,2,1);
+	sqlrcur_inputBind($cur,"3","hello");
+	sqlrcur_defineOutputBindInteger($cur,"1");
+	sqlrcur_defineOutputBindDouble($cur,"2");
+	sqlrcur_defineOutputBindString($cur,"3",20);
+	sqlrcur_defineOutputBindBlob($cur,"4");
+	checkSuccess(sqlrcur_executeQuery($cur),1);
+	checkSuccess(sqlrcur_getOutputBindInteger($cur,"1"),1);
+	//checkSuccess(sqlrcur_getOutputBindDouble($cur,"2"),1.1);
+	checkSuccess(sqlrcur_getOutputBindString($cur,"3"),"hello               ");
 	echo("\n");
 
 	echo("SELECT: \n");
@@ -118,7 +131,7 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("COLUMN COUNT: \n");
-	checkSuccess(sqlrcur_colCount($cur),11);
+	checkSuccess(sqlrcur_colCount($cur),12);
 	echo("\n");
 
 	echo("COLUMN NAMES: \n");
@@ -581,18 +594,18 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("CACHED RESULT SET: \n");
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testinteger"),1);
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	sqlrcur_cacheOff($cur);
 	checkSuccess(sqlrcur_openCachedResultSet($cur,$filename),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
 	echo("\n");
 
 	echo("COLUMN COUNT FOR CACHED RESULT SET: \n");
-	checkSuccess(sqlrcur_colCount($cur),11);
+	checkSuccess(sqlrcur_colCount($cur),12);
 	echo("\n");
 
 	echo("COLUMN NAMES FOR CACHED RESULT SET: \n");
@@ -623,11 +636,11 @@ function checkSuccess($value,$success) {
 
 	echo("CACHED RESULT SET WITH RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testinteger"),1);
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	sqlrcur_cacheOff($cur);
 	checkSuccess(sqlrcur_openCachedResultSet($cur,$filename),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
@@ -636,20 +649,20 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("FROM ONE CACHE FILE TO ANOTHER: \n");
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile2");
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile1"),1);
+	sqlrcur_cacheToFile($cur,"cachefile2");
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile1"),1);
 	sqlrcur_cacheOff($cur);
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile2"),1);
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile2"),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
 	checkSuccess(sqlrcur_getField($cur,8,0),NULL);
 	echo("\n");
 
 	echo("FROM ONE CACHE FILE TO ANOTHER WITH RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile2");
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile1"),1);
+	sqlrcur_cacheToFile($cur,"cachefile2");
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile1"),1);
 	sqlrcur_cacheOff($cur);
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile2"),1);
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile2"),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
 	checkSuccess(sqlrcur_getField($cur,8,0),NULL);
 	sqlrcur_setResultSetBufferSize($cur,0);
@@ -657,12 +670,12 @@ function checkSuccess($value,$success) {
 
 	echo("CACHED RESULT SET WITH SUSPEND AND RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testinteger"),1);
 	checkSuccess(sqlrcur_getField($cur,2,0),"3");
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	$id=sqlrcur_getResultSetId($cur);
 	sqlrcur_suspendResultSet($cur);
 	checkSuccess(sqlrcon_suspendSession($con),1);
@@ -704,7 +717,7 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_sendQuery($secondcur,"select count(*) from testtable"),1);
 	checkSuccess(sqlrcur_getField($secondcur,0,0),"8");
 	checkSuccess(sqlrcon_autoCommitOn($con),1);
-	checkSuccess(sqlrcur_sendQuery($cur,"insert into testtable values (10,10,10.1,10.1,10.1,10.1,'01-JAN-2010','10:00:00','testchar10','testvarchar10',NULL)"),1);
+	checkSuccess(sqlrcur_sendQuery($cur,"insert into testtable values (10,10,10.1,10.1,10.1,10.1,'01-JAN-2010','10:00:00','testchar10','testvarchar10',NULL,NULL)"),1);
 	checkSuccess(sqlrcur_sendQuery($secondcur,"select count(*) from testtable"),1);
 	checkSuccess(sqlrcur_getField($secondcur,0,0),"9");
 	checkSuccess(sqlrcon_autoCommitOff($con),1);
