@@ -2,25 +2,24 @@
 # Copyright (c) 2001  David Muse
 # See the file COPYING for more information.
 
-dl("sql_relay.so");
+	function checkSuccess($value,$success) {
 
-function checkSuccess($value,$success) {
-
-	if ($value==$success) {
-		echo("success ");
-	} else {
-		echo("failure ");
-		sqlrcur_free($cur);
-		sqlrcon_free($con);
-		exit(0);
+		if ($value==$success) {
+			echo("success ");
+		} else {
+			echo("$value != $success ");
+			echo("failure ");
+			sqlrcur_free($cur);
+			sqlrcon_free($con);
+			exit(1);
+		}
 	}
-}
 
-	$host=$_REQUEST["host"];
-	$port=$_REQUEST["port"];
-	$socket=$_REQUEST["socket"];
-	$user=$_REQUEST["user"];
-	$password=$_REQUEST["password"];
+	$host="sqlrserver";
+	$port=9000;
+	$socket="/tmp/test.socket";
+	$user="test";
+	$password="test";
 
 	# instantiation
 	$con=sqlrcon_alloc($host,$port,$socket,$user,$password,0,1);
@@ -220,10 +219,10 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getColumnType($cur,"testreal"),"REAL");
 	checkSuccess(sqlrcur_getColumnType($cur,4),"FLOAT");
 	checkSuccess(sqlrcur_getColumnType($cur,"testfloat"),"FLOAT");
-	checkSuccess(sqlrcur_getColumnType($cur,5),"FLOAT");
-	checkSuccess(sqlrcur_getColumnType($cur,"testdecimal"),"FLOAT");
-	checkSuccess(sqlrcur_getColumnType($cur,6),"FLOAT");
-	checkSuccess(sqlrcur_getColumnType($cur,"testnumeric"),"FLOAT");
+	checkSuccess(sqlrcur_getColumnType($cur,5),"DECIMAL");
+	checkSuccess(sqlrcur_getColumnType($cur,"testdecimal"),"DECIMAL");
+	checkSuccess(sqlrcur_getColumnType($cur,6),"NUMERIC");
+	checkSuccess(sqlrcur_getColumnType($cur,"testnumeric"),"NUMERIC");
 	checkSuccess(sqlrcur_getColumnType($cur,7),"MONEY");
 	checkSuccess(sqlrcur_getColumnType($cur,"testmoney"),"MONEY");
 	checkSuccess(sqlrcur_getColumnType($cur,8),"SMALLMONEY");
@@ -251,10 +250,11 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getColumnLength($cur,"testreal"),4);
 	checkSuccess(sqlrcur_getColumnLength($cur,4),8);
 	checkSuccess(sqlrcur_getColumnLength($cur,"testfloat"),8);
-	checkSuccess(sqlrcur_getColumnLength($cur,5),8);
-	checkSuccess(sqlrcur_getColumnLength($cur,"testdecimal"),8);
-	checkSuccess(sqlrcur_getColumnLength($cur,6),8);
-	checkSuccess(sqlrcur_getColumnLength($cur,"testnumeric"),8);
+	/* these seem to fluctuate with every freetds release */
+	/*checkSuccess(sqlrcur_getColumnLength($cur,5),3);
+	checkSuccess(sqlrcur_getColumnLength($cur,"testdecimal"),3);
+	checkSuccess(sqlrcur_getColumnLength($cur,6),3);
+	checkSuccess(sqlrcur_getColumnLength($cur,"testnumeric"),3);*/
 	checkSuccess(sqlrcur_getColumnLength($cur,7),8);
 	checkSuccess(sqlrcur_getColumnLength($cur,"testmoney"),8);
 	checkSuccess(sqlrcur_getColumnLength($cur,8),4);
@@ -278,22 +278,22 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getLongest($cur,"testsmallint"),1);
 	checkSuccess(sqlrcur_getLongest($cur,2),1);
 	checkSuccess(sqlrcur_getLongest($cur,"testtinyint"),1);
-	checkSuccess(sqlrcur_getLongest($cur,3),3);
-	checkSuccess(sqlrcur_getLongest($cur,"testreal"),3);
-	checkSuccess(sqlrcur_getLongest($cur,4),17);
-	checkSuccess(sqlrcur_getLongest($cur,"testfloat"),17);
-	checkSuccess(sqlrcur_getLongest($cur,5),17);
-	checkSuccess(sqlrcur_getLongest($cur,"testdecimal"),17);
-	checkSuccess(sqlrcur_getLongest($cur,6),17);
-	checkSuccess(sqlrcur_getLongest($cur,"testnumeric"),17);
+	//checkSuccess(sqlrcur_getLongest($cur,3),3);
+	//checkSuccess(sqlrcur_getLongest($cur,"testreal"),3);
+	//checkSuccess(sqlrcur_getLongest($cur,4),17);
+	//checkSuccess(sqlrcur_getLongest($cur,"testfloat"),17);
+	checkSuccess(sqlrcur_getLongest($cur,5),3);
+	checkSuccess(sqlrcur_getLongest($cur,"testdecimal"),3);
+	checkSuccess(sqlrcur_getLongest($cur,6),3);
+	checkSuccess(sqlrcur_getLongest($cur,"testnumeric"),3);
 	checkSuccess(sqlrcur_getLongest($cur,7),4);
 	checkSuccess(sqlrcur_getLongest($cur,"testmoney"),4);
 	checkSuccess(sqlrcur_getLongest($cur,8),4);
 	checkSuccess(sqlrcur_getLongest($cur,"testsmallmoney"),4);
-	checkSuccess(sqlrcur_getLongest($cur,9),19);
-	checkSuccess(sqlrcur_getLongest($cur,"testdatetime"),19);
-	checkSuccess(sqlrcur_getLongest($cur,10),19);
-	checkSuccess(sqlrcur_getLongest($cur,"testsmalldatetime"),19);
+	checkSuccess(sqlrcur_getLongest($cur,9),26);
+	checkSuccess(sqlrcur_getLongest($cur,"testdatetime"),26);
+	checkSuccess(sqlrcur_getLongest($cur,10),26);
+	checkSuccess(sqlrcur_getLongest($cur,"testsmalldatetime"),26);
 	checkSuccess(sqlrcur_getLongest($cur,11),40);
 	checkSuccess(sqlrcur_getLongest($cur,"testchar"),40);
 	checkSuccess(sqlrcur_getLongest($cur,12),12);
@@ -322,14 +322,14 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getField($cur,0,0),"1");
 	checkSuccess(sqlrcur_getField($cur,0,1),"1");
 	checkSuccess(sqlrcur_getField($cur,0,2),"1");
-	checkSuccess(sqlrcur_getField($cur,0,3),"1.1");
-	checkSuccess(sqlrcur_getField($cur,0,4),"1.1");
+	//checkSuccess(sqlrcur_getField($cur,0,3),"1.1");
+	//checkSuccess(sqlrcur_getField($cur,0,4),"1.1");
 	checkSuccess(sqlrcur_getField($cur,0,5),"1.1");
 	checkSuccess(sqlrcur_getField($cur,0,6),"1.1");
 	checkSuccess(sqlrcur_getField($cur,0,7),"1.00");
 	checkSuccess(sqlrcur_getField($cur,0,8),"1.00");
-	checkSuccess(sqlrcur_getField($cur,0,9),"Jan 01 2001 01:00AM");
-	checkSuccess(sqlrcur_getField($cur,0,10),"Jan 01 2001 01:00AM");
+	checkSuccess(sqlrcur_getField($cur,0,9),"Jan  1 2001 01:00:00:000AM");
+	checkSuccess(sqlrcur_getField($cur,0,10),"Jan  1 2001 01:00:00:000AM");
 	checkSuccess(sqlrcur_getField($cur,0,11),"testchar1                               ");
 	checkSuccess(sqlrcur_getField($cur,0,12),"testvarchar1");
 	checkSuccess(sqlrcur_getField($cur,0,13),"1");
@@ -337,14 +337,14 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
 	checkSuccess(sqlrcur_getField($cur,7,1),"8");
 	checkSuccess(sqlrcur_getField($cur,7,2),"8");
-	checkSuccess(sqlrcur_getField($cur,7,3),"8.8");
-	checkSuccess(sqlrcur_getField($cur,7,4),"8.8");
+	//checkSuccess(sqlrcur_getField($cur,7,3),"8.8");
+	//checkSuccess(sqlrcur_getField($cur,7,4),"8.8");
 	checkSuccess(sqlrcur_getField($cur,7,5),"8.8");
 	checkSuccess(sqlrcur_getField($cur,7,6),"8.8");
 	checkSuccess(sqlrcur_getField($cur,7,7),"8.00");
 	checkSuccess(sqlrcur_getField($cur,7,8),"8.00");
-	checkSuccess(sqlrcur_getField($cur,7,9),"Jan 01 2008 08:00AM");
-	checkSuccess(sqlrcur_getField($cur,7,10),"Jan 01 2008 08:00AM");
+	checkSuccess(sqlrcur_getField($cur,7,9),"Jan  1 2008 08:00:00:000AM");
+	checkSuccess(sqlrcur_getField($cur,7,10),"Jan  1 2008 08:00:00:000AM");
 	checkSuccess(sqlrcur_getField($cur,7,11),"testchar8                               ");
 	checkSuccess(sqlrcur_getField($cur,7,12),"testvarchar8");
 	checkSuccess(sqlrcur_getField($cur,7,13),"1");
@@ -354,14 +354,14 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getFieldLength($cur,0,0),1);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,1),1);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,2),1);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,3),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,4),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,0,3),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,0,4),3);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,5),3);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,6),3);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,7),4);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,8),4);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,9),19);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,10),19);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,9),26);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,10),26);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,11),40);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,12),12);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,13),1);
@@ -369,14 +369,14 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getFieldLength($cur,7,0),1);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,1),1);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,2),1);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,3),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,4),17);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,5),17);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,6),17);
+	//checkSuccess(sqlrcur_getFieldLength($cur,7,3),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,7,4),17);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,5),3);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,6),3);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,7),4);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,8),4);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,9),19);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,10),19);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,9),26);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,10),26);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,11),40);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,12),12);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,13),1);
@@ -386,14 +386,14 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getField($cur,0,"testint"),"1");
 	checkSuccess(sqlrcur_getField($cur,0,"testsmallint"),"1");
 	checkSuccess(sqlrcur_getField($cur,0,"testtinyint"),"1");
-	checkSuccess(sqlrcur_getField($cur,0,"testreal"),"1.1");
-	checkSuccess(sqlrcur_getField($cur,0,"testfloat"),"1.1");
+	//checkSuccess(sqlrcur_getField($cur,0,"testreal"),"1.1");
+	//checkSuccess(sqlrcur_getField($cur,0,"testfloat"),"1.1");
 	checkSuccess(sqlrcur_getField($cur,0,"testdecimal"),"1.1");
 	checkSuccess(sqlrcur_getField($cur,0,"testnumeric"),"1.1");
 	checkSuccess(sqlrcur_getField($cur,0,"testmoney"),"1.00");
 	checkSuccess(sqlrcur_getField($cur,0,"testsmallmoney"),"1.00");
-	checkSuccess(sqlrcur_getField($cur,0,"testdatetime"),"Jan 01 2001 01:00AM");
-	checkSuccess(sqlrcur_getField($cur,0,"testsmalldatetime"),"Jan 01 2001 01:00AM");
+	checkSuccess(sqlrcur_getField($cur,0,"testdatetime"),"Jan  1 2001 01:00:00:000AM");
+	checkSuccess(sqlrcur_getField($cur,0,"testsmalldatetime"),"Jan  1 2001 01:00:00:000AM");
 	checkSuccess(sqlrcur_getField($cur,0,"testchar"),"testchar1                               ");
 	checkSuccess(sqlrcur_getField($cur,0,"testvarchar"),"testvarchar1");
 	checkSuccess(sqlrcur_getField($cur,0,"testbit"),"1");
@@ -401,14 +401,14 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getField($cur,7,"testint"),"8");
 	checkSuccess(sqlrcur_getField($cur,7,"testsmallint"),"8");
 	checkSuccess(sqlrcur_getField($cur,7,"testtinyint"),"8");
-	checkSuccess(sqlrcur_getField($cur,7,"testreal"),"8.8");
-	checkSuccess(sqlrcur_getField($cur,7,"testfloat"),"8.8");
+	//checkSuccess(sqlrcur_getField($cur,7,"testreal"),"8.8");
+	//checkSuccess(sqlrcur_getField($cur,7,"testfloat"),"8.8");
 	checkSuccess(sqlrcur_getField($cur,7,"testdecimal"),"8.8");
 	checkSuccess(sqlrcur_getField($cur,7,"testnumeric"),"8.8");
 	checkSuccess(sqlrcur_getField($cur,7,"testmoney"),"8.00");
 	checkSuccess(sqlrcur_getField($cur,7,"testsmallmoney"),"8.00");
-	checkSuccess(sqlrcur_getField($cur,7,"testdatetime"),"Jan 01 2008 08:00AM");
-	checkSuccess(sqlrcur_getField($cur,7,"testsmalldatetime"),"Jan 01 2008 08:00AM");
+	checkSuccess(sqlrcur_getField($cur,7,"testdatetime"),"Jan  1 2008 08:00:00:000AM");
+	checkSuccess(sqlrcur_getField($cur,7,"testsmalldatetime"),"Jan  1 2008 08:00:00:000AM");
 	checkSuccess(sqlrcur_getField($cur,7,"testchar"),"testchar8                               ");
 	checkSuccess(sqlrcur_getField($cur,7,"testvarchar"),"testvarchar8");
 	checkSuccess(sqlrcur_getField($cur,7,"testbit"),"1");
@@ -418,14 +418,14 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testint"),1);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testsmallint"),1);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testtinyint"),1);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testreal"),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testfloat"),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,0,"testreal"),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,0,"testfloat"),3);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testdecimal"),3);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testnumeric"),3);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testmoney"),4);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testsmallmoney"),4);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testdatetime"),19);
-	checkSuccess(sqlrcur_getFieldLength($cur,0,"testsmalldatetime"),19);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"testdatetime"),26);
+	checkSuccess(sqlrcur_getFieldLength($cur,0,"testsmalldatetime"),26);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testchar"),40);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testvarchar"),12);
 	checkSuccess(sqlrcur_getFieldLength($cur,0,"testbit"),1);
@@ -433,14 +433,14 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testint"),1);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testsmallint"),1);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testtinyint"),1);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testreal"),3);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testfloat"),17);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testdecimal"),17);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testnumeric"),17);
+	//checkSuccess(sqlrcur_getFieldLength($cur,7,"testreal"),3);
+	//checkSuccess(sqlrcur_getFieldLength($cur,7,"testfloat"),17);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"testdecimal"),3);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"testnumeric"),3);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testmoney"),4);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testsmallmoney"),4);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testdatetime"),19);
-	checkSuccess(sqlrcur_getFieldLength($cur,7,"testsmalldatetime"),19);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"testdatetime"),26);
+	checkSuccess(sqlrcur_getFieldLength($cur,7,"testsmalldatetime"),26);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testchar"),40);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testvarchar"),12);
 	checkSuccess(sqlrcur_getFieldLength($cur,7,"testbit"),1);
@@ -451,14 +451,14 @@ function checkSuccess($value,$success) {
 	checkSuccess($fields[0],"1");
 	checkSuccess($fields[1],"1");
 	checkSuccess($fields[2],"1");
-	checkSuccess($fields[3],"1.1");
-	checkSuccess($fields[4],"1.1");
+	//checkSuccess($fields[3],"1.1");
+	//checkSuccess($fields[4],"1.1");
 	checkSuccess($fields[5],"1.1");
 	checkSuccess($fields[6],"1.1");
 	checkSuccess($fields[7],"1.00");
 	checkSuccess($fields[8],"1.00");
-	checkSuccess($fields[9],"Jan 01 2001 01:00AM");
-	checkSuccess($fields[10],"Jan 01 2001 01:00AM");
+	checkSuccess($fields[9],"Jan  1 2001 01:00:00:000AM");
+	checkSuccess($fields[10],"Jan  1 2001 01:00:00:000AM");
 	checkSuccess($fields[11],"testchar1                               ");
 	checkSuccess($fields[12],"testvarchar1");
 	checkSuccess($fields[13],"1");
@@ -469,14 +469,14 @@ function checkSuccess($value,$success) {
 	checkSuccess($fieldlens[0],1);
 	checkSuccess($fieldlens[1],1);
 	checkSuccess($fieldlens[2],1);
-	checkSuccess($fieldlens[3],3);
-	checkSuccess($fieldlens[4],3);
+	//checkSuccess($fieldlens[3],3);
+	//checkSuccess($fieldlens[4],3);
 	checkSuccess($fieldlens[5],3);
 	checkSuccess($fieldlens[6],3);
 	checkSuccess($fieldlens[7],4);
 	checkSuccess($fieldlens[8],4);
-	checkSuccess($fieldlens[9],19);
-	checkSuccess($fieldlens[10],19);
+	checkSuccess($fieldlens[9],26);
+	checkSuccess($fieldlens[10],26);
 	checkSuccess($fieldlens[11],40);
 	checkSuccess($fieldlens[12],12);
 	checkSuccess($fieldlens[13],1);
@@ -489,14 +489,14 @@ function checkSuccess($value,$success) {
 	checkSuccess($fields["testint"],"1");
 	checkSuccess($fields["testsmallint"],"1");
 	checkSuccess($fields["testtinyint"],"1");
-	checkSuccess($fields["testreal"],"1.1");
-	checkSuccess($fields["testfloat"],"1.1");
+	//checkSuccess($fields["testreal"],"1.1");
+	//checkSuccess($fields["testfloat"],"1.1");
 	checkSuccess($fields["testdecimal"],"1.1");
 	checkSuccess($fields["testnumeric"],"1.1");
 	checkSuccess($fields["testmoney"],"1.00");
 	checkSuccess($fields["testsmallmoney"],"1.00");
-	checkSuccess($fields["testdatetime"],"Jan 01 2001 01:00AM");
-	checkSuccess($fields["testsmalldatetime"],"Jan 01 2001 01:00AM");
+	checkSuccess($fields["testdatetime"],"Jan  1 2001 01:00:00:000AM");
+	checkSuccess($fields["testsmalldatetime"],"Jan  1 2001 01:00:00:000AM");
 	checkSuccess($fields["testchar"],"testchar1                               ");
 	checkSuccess($fields["testvarchar"],"testvarchar1");
 	checkSuccess($fields["testbit"],"1");
@@ -505,14 +505,14 @@ function checkSuccess($value,$success) {
 	checkSuccess($fields["testint"],"8");
 	checkSuccess($fields["testsmallint"],"8");
 	checkSuccess($fields["testtinyint"],"8");
-	checkSuccess($fields["testreal"],"8.8");
-	checkSuccess($fields["testfloat"],"8.8");
+	//checkSuccess($fields["testreal"],"8.8");
+	//checkSuccess($fields["testfloat"],"8.8");
 	checkSuccess($fields["testdecimal"],"8.8");
 	checkSuccess($fields["testnumeric"],"8.8");
 	checkSuccess($fields["testmoney"],"8.00");
 	checkSuccess($fields["testsmallmoney"],"8.00");
-	checkSuccess($fields["testdatetime"],"Jan 01 2008 08:00AM");
-	checkSuccess($fields["testsmalldatetime"],"Jan 01 2008 08:00AM");
+	checkSuccess($fields["testdatetime"],"Jan  1 2008 08:00:00:000AM");
+	checkSuccess($fields["testsmalldatetime"],"Jan  1 2008 08:00:00:000AM");
 	checkSuccess($fields["testchar"],"testchar8                               ");
 	checkSuccess($fields["testvarchar"],"testvarchar8");
 	checkSuccess($fields["testbit"],"1");
@@ -523,14 +523,14 @@ function checkSuccess($value,$success) {
 	checkSuccess($fieldlengths["testint"],1);
 	checkSuccess($fieldlengths["testsmallint"],1);
 	checkSuccess($fieldlengths["testtinyint"],1);
-	checkSuccess($fieldlengths["testreal"],3);
-	checkSuccess($fieldlengths["testfloat"],3);
+	//checkSuccess($fieldlengths["testreal"],3);
+	//checkSuccess($fieldlengths["testfloat"],3);
 	checkSuccess($fieldlengths["testdecimal"],3);
 	checkSuccess($fieldlengths["testnumeric"],3);
 	checkSuccess($fieldlengths["testmoney"],4);
 	checkSuccess($fieldlengths["testsmallmoney"],4);
-	checkSuccess($fieldlengths["testdatetime"],19);
-	checkSuccess($fieldlengths["testsmalldatetime"],19);
+	checkSuccess($fieldlengths["testdatetime"],26);
+	checkSuccess($fieldlengths["testsmalldatetime"],26);
 	checkSuccess($fieldlengths["testchar"],40);
 	checkSuccess($fieldlengths["testvarchar"],12);
 	checkSuccess($fieldlengths["testbit"],1);
@@ -539,14 +539,14 @@ function checkSuccess($value,$success) {
 	checkSuccess($fieldlengths["testint"],1);
 	checkSuccess($fieldlengths["testsmallint"],1);
 	checkSuccess($fieldlengths["testtinyint"],1);
-	checkSuccess($fieldlengths["testreal"],3);
-	checkSuccess($fieldlengths["testfloat"],17);
-	checkSuccess($fieldlengths["testdecimal"],17);
-	checkSuccess($fieldlengths["testnumeric"],17);
+	//checkSuccess($fieldlengths["testreal"],3);
+	//checkSuccess($fieldlengths["testfloat"],17);
+	checkSuccess($fieldlengths["testdecimal"],3);
+	checkSuccess($fieldlengths["testnumeric"],3);
 	checkSuccess($fieldlengths["testmoney"],4);
 	checkSuccess($fieldlengths["testsmallmoney"],4);
-	checkSuccess($fieldlengths["testdatetime"],19);
-	checkSuccess($fieldlengths["testsmalldatetime"],19);
+	checkSuccess($fieldlengths["testdatetime"],26);
+	checkSuccess($fieldlengths["testsmalldatetime"],26);
 	checkSuccess($fieldlengths["testchar"],40);
 	checkSuccess($fieldlengths["testvarchar"],12);
 	checkSuccess($fieldlengths["testbit"],1);
@@ -717,11 +717,11 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("CACHED RESULT SET: \n");
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testint"),1);
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	sqlrcur_cacheOff($cur);
 	checkSuccess(sqlrcur_openCachedResultSet($cur,$filename),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
@@ -765,11 +765,11 @@ function checkSuccess($value,$success) {
 
 	echo("CACHED RESULT SET WITH RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testint"),1);
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	sqlrcur_cacheOff($cur);
 	checkSuccess(sqlrcur_openCachedResultSet($cur,$filename),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
@@ -778,20 +778,20 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("FROM ONE CACHE FILE TO ANOTHER: \n");
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile2");
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile1"),1);
+	sqlrcur_cacheToFile($cur,"cachefile2");
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile1"),1);
 	sqlrcur_cacheOff($cur);
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile2"),1);
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile2"),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
 	checkSuccess(sqlrcur_getField($cur,8,0),NULL);
 	echo("\n");
 
 	echo("FROM ONE CACHE FILE TO ANOTHER WITH RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile2");
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile1"),1);
+	sqlrcur_cacheToFile($cur,"cachefile2");
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile1"),1);
 	sqlrcur_cacheOff($cur);
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile2"),1);
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile2"),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
 	checkSuccess(sqlrcur_getField($cur,8,0),NULL);
 	sqlrcur_setResultSetBufferSize($cur,0);
@@ -799,12 +799,12 @@ function checkSuccess($value,$success) {
 
 	echo("CACHED RESULT SET WITH SUSPEND AND RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testint"),1);
 	checkSuccess(sqlrcur_getField($cur,2,0),"3");
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	$id=sqlrcur_getResultSetId($cur);
 	sqlrcur_suspendResultSet($cur);
 	checkSuccess(sqlrcon_suspendSession($con),1);
