@@ -2,24 +2,24 @@
 # Copyright (c) 2001  David Muse
 # See the file COPYING for more information.
 
-dl("sql_relay.so");
-function checkSuccess($value,$success) {
+	function checkSuccess($value,$success) {
 
-	if ($value==$success) {
-		echo("success ");
-	} else {
-		echo("failure ");
-		sqlrcur_free($cur);
-		sqlrcon_free($con);
-		exit(0);
+		if ($value==$success) {
+			echo("success ");
+		} else {
+			echo("$value != $success ");
+			echo("failure ");
+			sqlrcur_free($cur);
+			sqlrcon_free($con);
+			exit(1);
+		}
 	}
-}
 
-	$host=$_REQUEST["host"];
-	$port=$_REQUEST["port"];
-	$socket=$_REQUEST["socket"];
-	$user=$_REQUEST["user"];
-	$password=$_REQUEST["password"];
+	$host="sqlrserver";
+	$port=9000;
+	$socket="/tmp/test.socket";
+	$user="test";
+	$password="test";
 
 	# instantiation
 	$con=sqlrcon_alloc($host,$port,$socket,$user,$password,0,1);
@@ -28,6 +28,7 @@ function checkSuccess($value,$success) {
 	# get database type
 	echo("IDENTIFY: \n");
 	checkSuccess(sqlrcon_identify($con),"mysql");
+	echo("\n");
 
 	# ping
 	echo("PING: \n");
@@ -39,7 +40,7 @@ function checkSuccess($value,$success) {
 
 	# create a new table
 	echo("CREATE TEMPTABLE: \n");
-	checkSuccess(sqlrcur_sendQuery($cur,"create table testdb.testtable (testtinyint tinyint, testsmallint smallint, testmediumint mediumint, testint int, testbigint bigint, testfloat float, testreal real, testdecimal decimal(1,1), testdate date, testtime time, testdatetime datetime, testyear year, testchar char(40), testtext text, testvarchar varchar(40), testtinytext tinytext, testmediumtext mediumtext, testlongtext longtext, testtimestamp timestamp)"),1);
+	checkSuccess(sqlrcur_sendQuery($cur,"create table testdb.testtable (testtinyint tinyint, testsmallint smallint, testmediumint mediumint, testint int, testbigint bigint, testfloat float, testreal real, testdecimal decimal(2,1), testdate date, testtime time, testdatetime datetime, testyear year, testchar char(40), testtext text, testvarchar varchar(40), testtinytext tinytext, testmediumtext mediumtext, testlongtext longtext, testtimestamp timestamp)"),1);
 	echo("\n");
 
 	echo("INSERT: \n");
@@ -53,52 +54,52 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_affectedRows($cur),1);
 	echo("\n");
 
-	echo("BIND BY NAME: \n");
-	sqlrcur_prepareQuery($cur,"insert into testdb.testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7,:var8,:var9,:var10,:var11,:var12,:var13,:var14,:var15,:var16,:var17,:var18,NULL)");
+	echo("BIND BY POSITION: \n");
+	sqlrcur_prepareQuery($cur,"insert into testdb.testtable values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,NULL)");
 	checkSuccess(sqlrcur_countBindVariables($cur),18);
-	sqlrcur_inputBind($cur,"var1",5);
-	sqlrcur_inputBind($cur,"var2",5);
-	sqlrcur_inputBind($cur,"var3",5);
-	sqlrcur_inputBind($cur,"var4",5);
-	sqlrcur_inputBind($cur,"var5",5);
-	sqlrcur_inputBind($cur,"var6",5.1,2,1);
-	sqlrcur_inputBind($cur,"var7",5.1,2,1);
-	sqlrcur_inputBind($cur,"var8",5.1,2,1);
-	sqlrcur_inputBind($cur,"var9","2005-01-01");
-	sqlrcur_inputBind($cur,"var10","05:00:00");
-	sqlrcur_inputBind($cur,"var11","2005-01-01 05:00:00");
-	sqlrcur_inputBind($cur,"var12","2005");
-	sqlrcur_inputBind($cur,"var13","char5");
-	sqlrcur_inputBind($cur,"var14","text5");
-	sqlrcur_inputBind($cur,"var15","varchar5");
-	sqlrcur_inputBind($cur,"var16","tinytext5");
-	sqlrcur_inputBind($cur,"var17","mediumtext5");
-	sqlrcur_inputBind($cur,"var18","longtext5");
+	sqlrcur_inputBind($cur,"1",5);
+	sqlrcur_inputBind($cur,"2",5);
+	sqlrcur_inputBind($cur,"3",5);
+	sqlrcur_inputBind($cur,"4",5);
+	sqlrcur_inputBind($cur,"5",5);
+	sqlrcur_inputBind($cur,"6",5.1,2,1);
+	sqlrcur_inputBind($cur,"7",5.1,2,1);
+	sqlrcur_inputBind($cur,"8",5.1,2,1);
+	sqlrcur_inputBind($cur,"9","2005-01-01");
+	sqlrcur_inputBind($cur,"10","05:00:00");
+	sqlrcur_inputBind($cur,"11","2005-01-01 05:00:00");
+	sqlrcur_inputBind($cur,"12","2005");
+	sqlrcur_inputBind($cur,"13","char5");
+	sqlrcur_inputBind($cur,"14","text5");
+	sqlrcur_inputBind($cur,"15","varchar5");
+	sqlrcur_inputBind($cur,"16","tinytext5");
+	sqlrcur_inputBind($cur,"17","mediumtext5");
+	sqlrcur_inputBind($cur,"18","longtext5");
 	checkSuccess(sqlrcur_executeQuery($cur),1);
 	sqlrcur_clearBinds($cur);
-	sqlrcur_inputBind($cur,"var1",6);
-	sqlrcur_inputBind($cur,"var2",6);
-	sqlrcur_inputBind($cur,"var3",6);
-	sqlrcur_inputBind($cur,"var4",6);
-	sqlrcur_inputBind($cur,"var5",6);
-	sqlrcur_inputBind($cur,"var6",6.1,2,1);
-	sqlrcur_inputBind($cur,"var7",6.1,2,1);
-	sqlrcur_inputBind($cur,"var8",6.1,2,1);
-	sqlrcur_inputBind($cur,"var9","2006-01-01");
-	sqlrcur_inputBind($cur,"var10","06:00:00");
-	sqlrcur_inputBind($cur,"var11","2006-01-01 06:00:00");
-	sqlrcur_inputBind($cur,"var12","2006");
-	sqlrcur_inputBind($cur,"var13","char6");
-	sqlrcur_inputBind($cur,"var14","text6");
-	sqlrcur_inputBind($cur,"var15","varchar6");
-	sqlrcur_inputBind($cur,"var16","tinytext6");
-	sqlrcur_inputBind($cur,"var17","mediumtext6");
-	sqlrcur_inputBind($cur,"var18","longtext6");
+	sqlrcur_inputBind($cur,"1",6);
+	sqlrcur_inputBind($cur,"2",6);
+	sqlrcur_inputBind($cur,"3",6);
+	sqlrcur_inputBind($cur,"4",6);
+	sqlrcur_inputBind($cur,"5",6);
+	sqlrcur_inputBind($cur,"6",6.1,2,1);
+	sqlrcur_inputBind($cur,"7",6.1,2,1);
+	sqlrcur_inputBind($cur,"8",6.1,2,1);
+	sqlrcur_inputBind($cur,"9","2006-01-01");
+	sqlrcur_inputBind($cur,"10","06:00:00");
+	sqlrcur_inputBind($cur,"11","2006-01-01 06:00:00");
+	sqlrcur_inputBind($cur,"12","2006");
+	sqlrcur_inputBind($cur,"13","char6");
+	sqlrcur_inputBind($cur,"14","text6");
+	sqlrcur_inputBind($cur,"15","varchar6");
+	sqlrcur_inputBind($cur,"16","tinytext6");
+	sqlrcur_inputBind($cur,"17","mediumtext6");
+	sqlrcur_inputBind($cur,"18","longtext6");
 	checkSuccess(sqlrcur_executeQuery($cur),1);
 
-	echo("ARRAY BIND BY NAME: \n");
+	echo("ARRAY BIND BY POSITION: \n");
 	sqlrcur_clearBinds($cur);
-	$bindvars=array("var1","var2","var3","var4","var5","var6","var7","var8","var9","var10","var11","var12","var13","var14","var15","var16","var17","var18");
+	$bindvars=array("1","2","3","4","5","6","7","8","9","10","11","12","13","14","15","16","17","18");
 	$bindvals=array(7,7,7,7,7,7.1,7.1,7.1,"2007-01-01","07:00:00","2007-01-01 07:00:00","2007","char7","text7","varchar7","tinytext7","mediumtext7","longtext7");
 	$precs=array(0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0);
 	$scales=array(0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0);
@@ -106,26 +107,26 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_executeQuery($cur),1);
 	echo("\n");
 
-	echo("BIND BY NAME WITH VALIDATION: \n");
+	echo("BIND BY POSITION WITH VALIDATION: \n");
 	sqlrcur_clearBinds($cur);
-	sqlrcur_inputBind($cur,"var1",8);
-	sqlrcur_inputBind($cur,"var2",8);
-	sqlrcur_inputBind($cur,"var3",8);
-	sqlrcur_inputBind($cur,"var4",8);
-	sqlrcur_inputBind($cur,"var5",8);
-	sqlrcur_inputBind($cur,"var6",8.1,2,1);
-	sqlrcur_inputBind($cur,"var7",8.1,2,1);
-	sqlrcur_inputBind($cur,"var8",8.1,2,1);
-	sqlrcur_inputBind($cur,"var9","2008-01-01");
-	sqlrcur_inputBind($cur,"var10","08:00:00");
-	sqlrcur_inputBind($cur,"var11","2008-01-01 08:00:00");
-	sqlrcur_inputBind($cur,"var12","2008");
-	sqlrcur_inputBind($cur,"var13","char8");
-	sqlrcur_inputBind($cur,"var14","text8");
-	sqlrcur_inputBind($cur,"var15","varchar8");
-	sqlrcur_inputBind($cur,"var16","tinytext8");
-	sqlrcur_inputBind($cur,"var17","mediumtext8");
-	sqlrcur_inputBind($cur,"var18","longtext8");
+	sqlrcur_inputBind($cur,"1",8);
+	sqlrcur_inputBind($cur,"2",8);
+	sqlrcur_inputBind($cur,"3",8);
+	sqlrcur_inputBind($cur,"4",8);
+	sqlrcur_inputBind($cur,"5",8);
+	sqlrcur_inputBind($cur,"6",8.1,2,1);
+	sqlrcur_inputBind($cur,"7",8.1,2,1);
+	sqlrcur_inputBind($cur,"8",8.1,2,1);
+	sqlrcur_inputBind($cur,"9","2008-01-01");
+	sqlrcur_inputBind($cur,"10","08:00:00");
+	sqlrcur_inputBind($cur,"11","2008-01-01 08:00:00");
+	sqlrcur_inputBind($cur,"12","2008");
+	sqlrcur_inputBind($cur,"13","char8");
+	sqlrcur_inputBind($cur,"14","text8");
+	sqlrcur_inputBind($cur,"15","varchar8");
+	sqlrcur_inputBind($cur,"16","tinytext8");
+	sqlrcur_inputBind($cur,"17","mediumtext8");
+	sqlrcur_inputBind($cur,"18","longtext8");
 	sqlrcur_validateBinds($cur);
 	checkSuccess(sqlrcur_executeQuery($cur),1);
 	echo("\n");
@@ -193,7 +194,7 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getColumnType($cur,9),"TIME");
 	checkSuccess(sqlrcur_getColumnType($cur,10),"DATETIME");
 	checkSuccess(sqlrcur_getColumnType($cur,11),"YEAR");
-	checkSuccess(sqlrcur_getColumnType($cur,12),"CHAR");
+	checkSuccess(sqlrcur_getColumnType($cur,12),"STRING");
 	checkSuccess(sqlrcur_getColumnType($cur,13),"BLOB");
 	checkSuccess(sqlrcur_getColumnType($cur,14),"CHAR");
 	checkSuccess(sqlrcur_getColumnType($cur,15),"TINYBLOB");
@@ -212,7 +213,7 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getColumnType($cur,"testtime"),"TIME");
 	checkSuccess(sqlrcur_getColumnType($cur,"testdatetime"),"DATETIME");
 	checkSuccess(sqlrcur_getColumnType($cur,"testyear"),"YEAR");
-	checkSuccess(sqlrcur_getColumnType($cur,"testchar"),"CHAR");
+	checkSuccess(sqlrcur_getColumnType($cur,"testchar"),"STRING");
 	checkSuccess(sqlrcur_getColumnType($cur,"testtext"),"BLOB");
 	checkSuccess(sqlrcur_getColumnType($cur,"testvarchar"),"CHAR");
 	checkSuccess(sqlrcur_getColumnType($cur,"testtinytext"),"TINYBLOB");
@@ -234,7 +235,7 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getColumnLength($cur,9),3);
 	checkSuccess(sqlrcur_getColumnLength($cur,10),8);
 	checkSuccess(sqlrcur_getColumnLength($cur,11),1);
-	checkSuccess(sqlrcur_getColumnLength($cur,12),41);
+	checkSuccess(sqlrcur_getColumnLength($cur,12),40);
 	checkSuccess(sqlrcur_getColumnLength($cur,13),65535);
 	checkSuccess(sqlrcur_getColumnLength($cur,14),41);
 	checkSuccess(sqlrcur_getColumnLength($cur,15),255);
@@ -253,7 +254,7 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_getColumnLength($cur,"testtime"),3);
 	checkSuccess(sqlrcur_getColumnLength($cur,"testdatetime"),8);
 	checkSuccess(sqlrcur_getColumnLength($cur,"testyear"),1);
-	checkSuccess(sqlrcur_getColumnLength($cur,"testchar"),41);
+	checkSuccess(sqlrcur_getColumnLength($cur,"testchar"),40);
 	checkSuccess(sqlrcur_getColumnLength($cur,"testtext"),65535);
 	checkSuccess(sqlrcur_getColumnLength($cur,"testvarchar"),41);
 	checkSuccess(sqlrcur_getColumnLength($cur,"testtinytext"),255);
@@ -775,11 +776,11 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("CACHED RESULT SET: \n");
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testtinyint"),1);
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	sqlrcur_cacheOff($cur);
 	checkSuccess(sqlrcur_openCachedResultSet($cur,$filename),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
@@ -831,11 +832,11 @@ function checkSuccess($value,$success) {
 
 	echo("CACHED RESULT SET WITH RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testtinyint"),1);
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	sqlrcur_cacheOff($cur);
 	checkSuccess(sqlrcur_openCachedResultSet($cur,$filename),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
@@ -844,20 +845,20 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("FROM ONE CACHE FILE TO ANOTHER: \n");
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile2");
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile1"),1);
+	sqlrcur_cacheToFile($cur,"cachefile2");
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile1"),1);
 	sqlrcur_cacheOff($cur);
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile2"),1);
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile2"),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
 	checkSuccess(sqlrcur_getField($cur,8,0),NULL);
 	echo("\n");
 
 	echo("FROM ONE CACHE FILE TO ANOTHER WITH RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile2");
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile1"),1);
+	sqlrcur_cacheToFile($cur,"cachefile2");
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile1"),1);
 	sqlrcur_cacheOff($cur);
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile2"),1);
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile2"),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
 	checkSuccess(sqlrcur_getField($cur,8,0),NULL);
 	sqlrcur_setResultSetBufferSize($cur,0);
@@ -865,12 +866,12 @@ function checkSuccess($value,$success) {
 
 	echo("CACHED RESULT SET WITH SUSPEND AND RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testtinyint"),1);
 	checkSuccess(sqlrcur_getField($cur,2,0),"3");
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	$id=sqlrcur_getResultSetId($cur);
 	sqlrcur_suspendResultSet($cur);
 	checkSuccess(sqlrcon_suspendSession($con),1);
@@ -906,15 +907,18 @@ function checkSuccess($value,$success) {
 					$socket,$user,$password,0,1);
 	$secondcur=sqlrcur_alloc($secondcon);
 	checkSuccess(sqlrcur_sendQuery($secondcur,"select count(*) from testtable"),1);
-	checkSuccess(sqlrcur_getField($secondcur,0,0),"8");
+	checkSuccess(sqlrcur_getField($secondcur,0,0),"0");
 	checkSuccess(sqlrcon_commit($con),1);
+	checkSuccess(sqlrcon_commit($secondcon),1);
 	checkSuccess(sqlrcur_sendQuery($secondcur,"select count(*) from testtable"),1);
 	checkSuccess(sqlrcur_getField($secondcur,0,0),"8");
 	checkSuccess(sqlrcon_autoCommitOn($con),1);
 	checkSuccess(sqlrcur_sendQuery($cur,"insert into testdb.testtable values (10,10,10,10,10,10.1,10.1,10.1,'2010-01-01','10:00:00','2010-01-01 10:00:00','2010','char10','text10','varchar10','tinytext10','mediumtext10','longtext10',NULL)"),1);
+	checkSuccess(sqlrcon_commit($secondcon),1);
 	checkSuccess(sqlrcur_sendQuery($secondcur,"select count(*) from testtable"),1);
 	checkSuccess(sqlrcur_getField($secondcur,0,0),"9");
 	checkSuccess(sqlrcon_autoCommitOff($con),1);
+	sqlrcon_commit($secondcon);
 	echo("\n");
 
 	# drop existing table
