@@ -2,25 +2,24 @@
 # Copyright (c) 2001  David Muse
 # See the file COPYING for more information.
 
-dl("sql_relay.so");
+	function checkSuccess($value,$success) {
 
-function checkSuccess($value,$success) {
-
-	if ($value==$success) {
-		echo("success ");
-	} else {
-		echo("failure ");
-		sqlrcur_free($cur);
-		sqlrcon_free($con);
-		exit(0);
+		if ($value==$success) {
+			echo("success ");
+		} else {
+			echo("$value != $success ");
+			echo("failure ");
+			sqlrcur_free($cur);
+			sqlrcon_free($con);
+			exit(1);
+		}
 	}
-}
 
-	$host=$_REQUEST["host"];
-	$port=$_REQUEST["port"];
-	$socket=$_REQUEST["socket"];
-	$user=$_REQUEST["user"];
-	$password=$_REQUEST["password"];
+	$host="sqlrserver";
+	$port=9000;
+	$socket="/tmp/test.socket";
+	$user="test";
+	$password="test";
 
 	# instantiation
 	$con=sqlrcon_alloc($host,$port,$socket,$user,$password,0,1);
@@ -117,14 +116,14 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("COLUMN TYPES: \n");
-	checkSuccess(sqlrcur_getColumnType($cur,0),"UNKNOWN");
-	checkSuccess(sqlrcur_getColumnType($cur,"testint"),"UNKNOWN");
-	checkSuccess(sqlrcur_getColumnType($cur,1),"UNKNOWN");
-	checkSuccess(sqlrcur_getColumnType($cur,"testfloat"),"UNKNOWN");
-	checkSuccess(sqlrcur_getColumnType($cur,2),"UNKNOWN");
-	checkSuccess(sqlrcur_getColumnType($cur,"testchar"),"UNKNOWN");
-	checkSuccess(sqlrcur_getColumnType($cur,3),"UNKNOWN");
-	checkSuccess(sqlrcur_getColumnType($cur,"testvarchar"),"UNKNOWN");
+	checkSuccess(sqlrcur_getColumnType($cur,0),"INTEGER");
+	checkSuccess(sqlrcur_getColumnType($cur,"testint"),"INTEGER");
+	checkSuccess(sqlrcur_getColumnType($cur,1),"FLOAT");
+	checkSuccess(sqlrcur_getColumnType($cur,"testfloat"),"FLOAT");
+	checkSuccess(sqlrcur_getColumnType($cur,2),"STRING");
+	checkSuccess(sqlrcur_getColumnType($cur,"testchar"),"STRING");
+	checkSuccess(sqlrcur_getColumnType($cur,3),"STRING");
+	checkSuccess(sqlrcur_getColumnType($cur,"testvarchar"),"STRING");
 	echo("\n");
 
 	echo("COLUMN LENGTH: \n");
@@ -154,7 +153,7 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("TOTAL ROWS: \n");
-	checkSuccess(sqlrcur_totalRows($cur),8);
+	checkSuccess(sqlrcur_totalRows($cur),0);
 	echo("\n");
 
 	echo("FIRST ROW INDEX: \n");
@@ -351,7 +350,7 @@ function checkSuccess($value,$success) {
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testint"),1);
 	checkSuccess(sqlrcur_getColumnName($cur,0),"testint");
 	checkSuccess(sqlrcur_getColumnLength($cur,0),0);
-	checkSuccess(sqlrcur_getColumnType($cur,0),"UNKNOWN");
+	checkSuccess(sqlrcur_getColumnType($cur,0),"INTEGER");
 	echo("\n");
 
 	echo("SUSPENDED SESSION: \n");
@@ -433,11 +432,11 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("CACHED RESULT SET: \n");
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testint"),1);
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	sqlrcur_cacheOff($cur);
 	checkSuccess(sqlrcur_openCachedResultSet($cur,$filename),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
@@ -461,11 +460,11 @@ function checkSuccess($value,$success) {
 
 	echo("CACHED RESULT SET WITH RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testint"),1);
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	sqlrcur_cacheOff($cur);
 	checkSuccess(sqlrcur_openCachedResultSet($cur,$filename),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
@@ -474,20 +473,20 @@ function checkSuccess($value,$success) {
 	echo("\n");
 
 	echo("FROM ONE CACHE FILE TO ANOTHER: \n");
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile2");
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile1"),1);
+	sqlrcur_cacheToFile($cur,"cachefile2");
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile1"),1);
 	sqlrcur_cacheOff($cur);
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile2"),1);
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile2"),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
 	checkSuccess(sqlrcur_getField($cur,8,0),NULL);
 	echo("\n");
 
 	echo("FROM ONE CACHE FILE TO ANOTHER WITH RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile2");
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile1"),1);
+	sqlrcur_cacheToFile($cur,"cachefile2");
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile1"),1);
 	sqlrcur_cacheOff($cur);
-	checkSuccess(sqlrcur_openCachedResultSet($cur,"/tmp/cachefile2"),1);
+	checkSuccess(sqlrcur_openCachedResultSet($cur,"cachefile2"),1);
 	checkSuccess(sqlrcur_getField($cur,7,0),"8");
 	checkSuccess(sqlrcur_getField($cur,8,0),NULL);
 	sqlrcur_setResultSetBufferSize($cur,0);
@@ -495,12 +494,12 @@ function checkSuccess($value,$success) {
 
 	echo("CACHED RESULT SET WITH SUSPEND AND RESULT SET BUFFER SIZE: \n");
 	sqlrcur_setResultSetBufferSize($cur,2);
-	sqlrcur_cacheToFile($cur,"/tmp/cachefile1");
+	sqlrcur_cacheToFile($cur,"cachefile1");
 	sqlrcur_setCacheTtl($cur,200);
 	checkSuccess(sqlrcur_sendQuery($cur,"select * from testtable order by testint"),1);
 	checkSuccess(sqlrcur_getField($cur,2,0),"3");
 	$filename=sqlrcur_getCacheFileName($cur);
-	checkSuccess($filename,"/tmp/cachefile1");
+	checkSuccess($filename,"cachefile1");
 	$id=sqlrcur_getResultSetId($cur);
 	sqlrcur_suspendResultSet($cur);
 	checkSuccess(sqlrcon_suspendSession($con),1);
