@@ -4,51 +4,49 @@
 # See the file COPYING for more information.
 
 from SQLRelay import PySQLRClient
+from decimal import *
 import sys
 import string
 
 def checkSuccess(value,success):
 	if value==success:
-		print "success",
+		print("success")
 	else:
-		print "failure"
-		print "wanted", type(success), ":", success
-		print "got   ", type(value), ":", value
-		sys.exit(0)
+		print("wanted", type(success), ":", success)
+		print("got   ", type(value), ":", value)
+		print("failure")
+		sys.exit(1)
 
 def main():
 
-	# usage...
-	if len(sys.argv) < 5:
-		print "usage: firebird.py host port socket user password"
-		sys.exit(0)
+	PySQLRClient.getNumericFieldsAsNumbers()
 
 	# instantiation
-	con=PySQLRClient.sqlrconnection(sys.argv[1],string.atoi(sys.argv[2]), 
-					sys.argv[3],sys.argv[4],sys.argv[5])
+	con=PySQLRClient.sqlrconnection("sqlrserver",9000,"/tmp/test.socket",
+								"test","test")
 	cur=PySQLRClient.sqlrcursor(con)
 
 	# get database type
-	print "IDENTIFY: "
+	print("IDENTIFY: ")
 	checkSuccess(con.identify(),"firebird")
-	print
+	print()
 
 	# ping
-	print "PING: "
+	print("PING: ")
 	checkSuccess(con.ping(),1)
-	print
+	print()
 
 	# clear table
 	cur.sendQuery("delete from testtable")
 	con.commit()
 
-	print "INSERT: "
-	checkSuccess(cur.sendQuery("insert into testtable values (1,1,1.1,1.1,1.1,1.1,'01-JAN-2001','01:00:00','testchar1','testvarchar1',NULL)"),1)
-	print
+	print("INSERT: ")
+	checkSuccess(cur.sendQuery("insert into testtable values (1,1,1.1,1.1,1.1,1.1,'01-JAN-2001','01:00:00','testchar1','testvarchar1',NULL,NULL)"),1)
+	print()
 
 
-	print "BIND BY POSITION: "
-	cur.prepareQuery("insert into testtable values (?,?,?,?,?,?,?,?,?,?,?)")
+	print("BIND BY POSITION: ")
+	cur.prepareQuery("insert into testtable values (?,?,?,?,?,?,?,?,?,?,?,NULL)")
 	checkSuccess(cur.countBindVariables(),11)
 	cur.inputBind("1",2)
 	cur.inputBind("2",2)
@@ -56,29 +54,29 @@ def main():
 	cur.inputBind("4",2.2,2,1)
 	cur.inputBind("5",2.2,2,1)
 	cur.inputBind("6",2.2,2,1)
-	cur.inputBind("7","01-JAN-2002");
-	cur.inputBind("8","02:00:00");
-	cur.inputBind("9","testchar2");
-	cur.inputBind("10","testvarchar2");
-	cur.inputBind("11",None);
+	cur.inputBind("7","01-JAN-2002")
+	cur.inputBind("8","02:00:00")
+	cur.inputBind("9","testchar2")
+	cur.inputBind("10","testvarchar2")
+	cur.inputBind("11",None)
 	checkSuccess(cur.executeQuery(),1)
-	cur.clearBinds();
+	cur.clearBinds()
 	cur.inputBind("1",3)
 	cur.inputBind("2",3)
 	cur.inputBind("3",3.3,2,1)
 	cur.inputBind("4",3.3,2,1)
 	cur.inputBind("5",3.3,2,1)
 	cur.inputBind("6",3.3,2,1)
-	cur.inputBind("7","01-JAN-2003");
-	cur.inputBind("8","03:00:00");
-	cur.inputBind("9","testchar3");
-	cur.inputBind("10","testvarchar3");
-	cur.inputBind("11",None);
+	cur.inputBind("7","01-JAN-2003")
+	cur.inputBind("8","03:00:00")
+	cur.inputBind("9","testchar3")
+	cur.inputBind("10","testvarchar3")
+	cur.inputBind("11",None)
 	checkSuccess(cur.executeQuery(),1)
-	print
+	print()
 
-	print "ARRAY OF BINDS BY POSITION: "
-	cur.clearBinds();
+	print("ARRAY OF BINDS BY POSITION: ")
+	cur.clearBinds()
 	cur.inputBinds(["1","2","3","4","5","6",
 			"7","8","9","10","11"],
 		[4,4,4.4,4.4,4.4,4.4,"01-JAN-2004","04:00:00",
@@ -86,37 +84,51 @@ def main():
 		[0,0,2,2,2,2,0,0,0,0,0],
 		[0,0,1,1,1,1,0,0,0,0,0])
 	checkSuccess(cur.executeQuery(),1)
-	print
+	print()
 
-	print "INSERT: "
-	checkSuccess(cur.sendQuery("insert into testtable values (5,5,5.5,5.5,5.5,5.5,'01-JAN-2005','05:00:00','testchar5','testvarchar5',NULL)"),1)
-	checkSuccess(cur.sendQuery("insert into testtable values (6,6,6.6,6.6,6.6,6.6,'01-JAN-2006','06:00:00','testchar6','testvarchar6',NULL)"),1)
-	checkSuccess(cur.sendQuery("insert into testtable values (7,7,7.7,7.7,7.7,7.7,'01-JAN-2007','07:00:00','testchar7','testvarchar7',NULL)"),1)
-	checkSuccess(cur.sendQuery("insert into testtable values (8,8,8.8,8.8,8.8,8.8,'01-JAN-2008','08:00:00','testchar8','testvarchar8',NULL)"),1)
-	print
+	print("INSERT: ")
+	checkSuccess(cur.sendQuery("insert into testtable values (5,5,5.5,5.5,5.5,5.5,'01-JAN-2005','05:00:00','testchar5','testvarchar5',NULL,NULL)"),1)
+	checkSuccess(cur.sendQuery("insert into testtable values (6,6,6.6,6.6,6.6,6.6,'01-JAN-2006','06:00:00','testchar6','testvarchar6',NULL,NULL)"),1)
+	checkSuccess(cur.sendQuery("insert into testtable values (7,7,7.7,7.7,7.7,7.7,'01-JAN-2007','07:00:00','testchar7','testvarchar7',NULL,NULL)"),1)
+	checkSuccess(cur.sendQuery("insert into testtable values (8,8,8.8,8.8,8.8,8.8,'01-JAN-2008','08:00:00','testchar8','testvarchar8',NULL,NULL)"),1)
+	print()
 
-	print "AFFECTED ROWS: "
+	print("AFFECTED ROWS: ")
 	checkSuccess(cur.affectedRows(),0)
-	print
+	print()
 
-	print "STORED PROCEDURE: "
-	checkSuccess(cur.sendQuery("create procedure testproc(invar integer) returns (outvar integer) as begin outvar = invar; suspend; end"),1);
-	cur.prepareQuery("select * from testproc(?)");
-	cur.inputBind("1",5);
-	checkSuccess(cur.executeQuery(),1);
-	checkSuccess(cur.getField(0,0),"5");
-	checkSuccess(cur.sendQuery("drop procedure testproc"),1);
-	print
+	print("STORED PROCEDURE: ")
+	cur.prepareQuery("select * from testproc(?,?,?,NULL)")
+	cur.inputBind("1",1)
+	cur.inputBind("2",1.1,2,1)
+	cur.inputBind("3","hello")
+	checkSuccess(cur.executeQuery(),1)
+	checkSuccess(cur.getField(0,0),1)
+	checkSuccess(cur.getField(0,1),Decimal(Decimal("1.1000")))
+	checkSuccess(cur.getField(0,2),"hello")
+	cur.prepareQuery("execute procedure testproc ?, ?, ?, NULL")
+	cur.inputBind("1",1)
+	cur.inputBind("2",1.1,2,1)
+	cur.inputBind("3","hello")
+	cur.defineOutputBindInteger("1")
+	cur.defineOutputBindDouble("2")
+	cur.defineOutputBindString("3",20)
+	cur.defineOutputBindBlob("4")
+	checkSuccess(cur.executeQuery(),1)
+	checkSuccess(cur.getOutputBindInteger("1"),1)
+	#checkSuccess(cur.getOutputBindDouble("2"),1.1)
+	checkSuccess(cur.getOutputBindString("3"),"hello               ")
+	print()
 
-	print "SELECT: "
+	print("SELECT: ")
 	checkSuccess(cur.sendQuery("select * from testtable order by testinteger"),1)
-	print
+	print()
 
-	print "COLUMN COUNT: "
-	checkSuccess(cur.colCount(),11)
-	print
+	print("COLUMN COUNT: ")
+	checkSuccess(cur.colCount(),12)
+	print()
 
-	print "COLUMN NAMES: "
+	print("COLUMN NAMES: ")
 	checkSuccess(cur.getColumnName(0),"TESTINTEGER")
 	checkSuccess(cur.getColumnName(1),"TESTSMALLINT")
 	checkSuccess(cur.getColumnName(2),"TESTDECIMAL")
@@ -140,9 +152,9 @@ def main():
 	checkSuccess(cols[8],"TESTCHAR")
 	checkSuccess(cols[9],"TESTVARCHAR")
 	checkSuccess(cols[10],"TESTTIMESTAMP")
-	print
+	print()
 
-	print "COLUMN TYPES: "
+	print("COLUMN TYPES: ")
 	checkSuccess(cur.getColumnType(0),"INTEGER")
 	checkSuccess(cur.getColumnType('TESTINTEGER'),"INTEGER")
 	checkSuccess(cur.getColumnType(1),"SMALLINT")
@@ -165,9 +177,9 @@ def main():
 	checkSuccess(cur.getColumnType('TESTVARCHAR'),"VARCHAR")
 	checkSuccess(cur.getColumnType(10),"TIMESTAMP")
 	checkSuccess(cur.getColumnType('TESTTIMESTAMP'),"TIMESTAMP")
-	print
+	print()
 
-	print "COLUMN LENGTH: "
+	print("COLUMN LENGTH: ")
 	checkSuccess(cur.getColumnLength(0),4)
 	checkSuccess(cur.getColumnLength('TESTINTEGER'),4)
 	checkSuccess(cur.getColumnLength(1),2)
@@ -190,9 +202,9 @@ def main():
 	checkSuccess(cur.getColumnLength('TESTVARCHAR'),50)
 	checkSuccess(cur.getColumnLength(10),8)
 	checkSuccess(cur.getColumnLength('TESTTIMESTAMP'),8)
-	print
+	print()
 
-	print "LONGEST COLUMN: "
+	print("LONGEST COLUMN: ")
 	checkSuccess(cur.getLongest(0),1)
 	checkSuccess(cur.getLongest('TESTINTEGER'),1)
 	checkSuccess(cur.getLongest(1),1)
@@ -215,49 +227,49 @@ def main():
 	checkSuccess(cur.getLongest('TESTVARCHAR'),12)
 	checkSuccess(cur.getLongest(10),0)
 	checkSuccess(cur.getLongest('TESTTIMESTAMP'),0)
-	print
+	print()
 
-	print "ROW COUNT: "
+	print("ROW COUNT: ")
 	checkSuccess(cur.rowCount(),8)
-	print
+	print()
 
-	print "TOTAL ROWS: "
+	print("TOTAL ROWS: ")
 	checkSuccess(cur.totalRows(),0)
-	print
+	print()
 
-	print "FIRST ROW INDEX: "
+	print("FIRST ROW INDEX: ")
 	checkSuccess(cur.firstRowIndex(),0)
-	print
+	print()
 
-	print "END OF RESULT SET: "
+	print("END OF RESULT SET: ")
 	checkSuccess(cur.endOfResultSet(),1)
-	print
+	print()
 
-	print "FIELDS BY INDEX: "
-	checkSuccess(cur.getField(0,0),"1")
-	checkSuccess(cur.getField(0,1),"1")
-	checkSuccess(cur.getField(0,2),"1.10")
-	checkSuccess(cur.getField(0,3),"1.10")
-	checkSuccess(cur.getField(0,4),"1.1000")
-	checkSuccess(cur.getField(0,5),"1.1000")
+	print("FIELDS BY INDEX: ")
+	checkSuccess(cur.getField(0,0),1)
+	checkSuccess(cur.getField(0,1),1)
+	checkSuccess(cur.getField(0,2),Decimal(Decimal("1.10")))
+	checkSuccess(cur.getField(0,3),Decimal(Decimal("1.10")))
+	checkSuccess(cur.getField(0,4),Decimal(Decimal("1.1000")))
+	checkSuccess(cur.getField(0,5),Decimal(Decimal("1.1000")))
 	checkSuccess(cur.getField(0,6),"2001:01:01")
 	checkSuccess(cur.getField(0,7),"01:00:00")
 	checkSuccess(cur.getField(0,8),"testchar1                                         ")
 	checkSuccess(cur.getField(0,9),"testvarchar1")
-	print
-	checkSuccess(cur.getField(7,0),"8")
-	checkSuccess(cur.getField(7,1),"8")
-	checkSuccess(cur.getField(7,2),"8.80")
-	checkSuccess(cur.getField(7,3),"8.80")
-	checkSuccess(cur.getField(7,4),"8.8000")
-	checkSuccess(cur.getField(7,5),"8.8000")
+	print()
+	checkSuccess(cur.getField(7,0),8)
+	checkSuccess(cur.getField(7,1),8)
+	checkSuccess(cur.getField(7,2),Decimal("8.80"))
+	checkSuccess(cur.getField(7,3),Decimal("8.80"))
+	checkSuccess(cur.getField(7,4),Decimal("8.8000"))
+	checkSuccess(cur.getField(7,5),Decimal("8.8000"))
 	checkSuccess(cur.getField(7,6),"2008:01:01")
 	checkSuccess(cur.getField(7,7),"08:00:00")
 	checkSuccess(cur.getField(7,8),"testchar8                                         ")
 	checkSuccess(cur.getField(7,9),"testvarchar8")
-	print
+	print()
 
-	print "FIELD LENGTHS BY INDEX: "
+	print("FIELD LENGTHS BY INDEX: ")
 	checkSuccess(cur.getFieldLength(0,0),1)
 	checkSuccess(cur.getFieldLength(0,1),1)
 	checkSuccess(cur.getFieldLength(0,2),4)
@@ -268,7 +280,7 @@ def main():
 	checkSuccess(cur.getFieldLength(0,7),8)
 	checkSuccess(cur.getFieldLength(0,8),50)
 	checkSuccess(cur.getFieldLength(0,9),12)
-	print
+	print()
 	checkSuccess(cur.getFieldLength(7,0),1)
 	checkSuccess(cur.getFieldLength(7,1),1)
 	checkSuccess(cur.getFieldLength(7,2),4)
@@ -279,33 +291,33 @@ def main():
 	checkSuccess(cur.getFieldLength(7,7),8)
 	checkSuccess(cur.getFieldLength(7,8),50)
 	checkSuccess(cur.getFieldLength(7,9),12)
-	print
+	print()
 
-	print "FIELDS BY NAME: "
-	checkSuccess(cur.getField(0,"TESTINTEGER"),"1")
-	checkSuccess(cur.getField(0,"TESTSMALLINT"),"1")
-	checkSuccess(cur.getField(0,"TESTDECIMAL"),"1.10")
-	checkSuccess(cur.getField(0,"TESTNUMERIC"),"1.10")
-	checkSuccess(cur.getField(0,"TESTFLOAT"),"1.1000")
-	checkSuccess(cur.getField(0,"TESTDOUBLE"),"1.1000")
+	print("FIELDS BY NAME: ")
+	checkSuccess(cur.getField(0,"TESTINTEGER"),1)
+	checkSuccess(cur.getField(0,"TESTSMALLINT"),1)
+	checkSuccess(cur.getField(0,"TESTDECIMAL"),Decimal("1.10"))
+	checkSuccess(cur.getField(0,"TESTNUMERIC"),Decimal("1.10"))
+	checkSuccess(cur.getField(0,"TESTFLOAT"),Decimal("1.1000"))
+	checkSuccess(cur.getField(0,"TESTDOUBLE"),Decimal("1.1000"))
 	checkSuccess(cur.getField(0,"TESTDATE"),"2001:01:01")
 	checkSuccess(cur.getField(0,"TESTTIME"),"01:00:00")
 	checkSuccess(cur.getField(0,"TESTCHAR"),"testchar1                                         ")
 	checkSuccess(cur.getField(0,"TESTVARCHAR"),"testvarchar1")
-	print
-	checkSuccess(cur.getField(7,"TESTINTEGER"),"8")
-	checkSuccess(cur.getField(7,"TESTSMALLINT"),"8")
-	checkSuccess(cur.getField(7,"TESTDECIMAL"),"8.80")
-	checkSuccess(cur.getField(7,"TESTNUMERIC"),"8.80")
-	checkSuccess(cur.getField(7,"TESTFLOAT"),"8.8000")
-	checkSuccess(cur.getField(7,"TESTDOUBLE"),"8.8000")
+	print()
+	checkSuccess(cur.getField(7,"TESTINTEGER"),8)
+	checkSuccess(cur.getField(7,"TESTSMALLINT"),8)
+	checkSuccess(cur.getField(7,"TESTDECIMAL"),Decimal("8.80"))
+	checkSuccess(cur.getField(7,"TESTNUMERIC"),Decimal("8.80"))
+	checkSuccess(cur.getField(7,"TESTFLOAT"),Decimal("8.8000"))
+	checkSuccess(cur.getField(7,"TESTDOUBLE"),Decimal("8.8000"))
 	checkSuccess(cur.getField(7,"TESTDATE"),"2008:01:01")
 	checkSuccess(cur.getField(7,"TESTTIME"),"08:00:00")
 	checkSuccess(cur.getField(7,"TESTCHAR"),"testchar8                                         ")
 	checkSuccess(cur.getField(7,"TESTVARCHAR"),"testvarchar8")
-	print
+	print()
 
-	print "FIELD LENGTHS BY NAME: "
+	print("FIELD LENGTHS BY NAME: ")
 	checkSuccess(cur.getFieldLength(0,"TESTINTEGER"),1)
 	checkSuccess(cur.getFieldLength(0,"TESTSMALLINT"),1)
 	checkSuccess(cur.getFieldLength(0,"TESTDECIMAL"),4)
@@ -316,7 +328,7 @@ def main():
 	checkSuccess(cur.getFieldLength(0,"TESTTIME"),8)
 	checkSuccess(cur.getFieldLength(0,"TESTCHAR"),50)
 	checkSuccess(cur.getFieldLength(0,"TESTVARCHAR"),12)
-	print
+	print()
 	checkSuccess(cur.getFieldLength(7,"TESTINTEGER"),1)
 	checkSuccess(cur.getFieldLength(7,"TESTSMALLINT"),1)
 	checkSuccess(cur.getFieldLength(7,"TESTDECIMAL"),4)
@@ -327,23 +339,23 @@ def main():
 	checkSuccess(cur.getFieldLength(7,"TESTTIME"),8)
 	checkSuccess(cur.getFieldLength(7,"TESTCHAR"),50)
 	checkSuccess(cur.getFieldLength(7,"TESTVARCHAR"),12)
-	print
+	print()
 
-	print "FIELDS BY ARRAY: "
+	print("FIELDS BY ARRAY: ")
 	fields=cur.getRow(0)
 	checkSuccess(fields[0],1)
 	checkSuccess(fields[1],1)
-	checkSuccess(fields[2],1.1)
-	checkSuccess(fields[3],1.1)
-	checkSuccess(fields[4],1.1)
-	checkSuccess(fields[5],1.1)
+	checkSuccess(fields[2],Decimal("1.1"))
+	checkSuccess(fields[3],Decimal("1.1"))
+	checkSuccess(fields[4],Decimal("1.1"))
+	checkSuccess(fields[5],Decimal("1.1"))
 	checkSuccess(fields[6],"2001:01:01")
 	checkSuccess(fields[7],"01:00:00")
 	checkSuccess(fields[8],"testchar1                                         ")
 	checkSuccess(fields[9],"testvarchar1")
-	print
+	print()
 
-	print "FIELD LENGTHS BY ARRAY: "
+	print("FIELD LENGTHS BY ARRAY: ")
 	fieldlens=cur.getRowLengths(0)
 	checkSuccess(fieldlens[0],1)
 	checkSuccess(fieldlens[1],1)
@@ -355,35 +367,35 @@ def main():
 	checkSuccess(fieldlens[7],8)
 	checkSuccess(fieldlens[8],50)
 	checkSuccess(fieldlens[9],12)
-	print
+	print()
 
-	print "FIELDS BY DICTIONARY: "
+	print("FIELDS BY DICTIONARY: ")
 	fields=cur.getRowDictionary(0)
 	checkSuccess(fields["TESTINTEGER"],1)
 	checkSuccess(fields["TESTSMALLINT"],1)
-	checkSuccess(fields["TESTDECIMAL"],1.1)
-	checkSuccess(fields["TESTNUMERIC"],1.1)
-	checkSuccess(fields["TESTFLOAT"],1.1)
-	checkSuccess(fields["TESTDOUBLE"],1.1)
+	checkSuccess(fields["TESTDECIMAL"],Decimal("1.1"))
+	checkSuccess(fields["TESTNUMERIC"],Decimal("1.1"))
+	checkSuccess(fields["TESTFLOAT"],Decimal("1.1"))
+	checkSuccess(fields["TESTDOUBLE"],Decimal("1.1"))
 	checkSuccess(fields["TESTDATE"],"2001:01:01")
 	checkSuccess(fields["TESTTIME"],"01:00:00")
 	checkSuccess(fields["TESTCHAR"],"testchar1                                         ")
 	checkSuccess(fields["TESTVARCHAR"],"testvarchar1")
-	print
+	print()
 	fields=cur.getRowDictionary(7)
 	checkSuccess(fields["TESTINTEGER"],8)
 	checkSuccess(fields["TESTSMALLINT"],8)
-	checkSuccess(fields["TESTDECIMAL"],8.8)
-	checkSuccess(fields["TESTNUMERIC"],8.8)
-	checkSuccess(fields["TESTFLOAT"],8.8)
-	checkSuccess(fields["TESTDOUBLE"],8.8)
+	checkSuccess(fields["TESTDECIMAL"],Decimal("8.8"))
+	checkSuccess(fields["TESTNUMERIC"],Decimal("8.8"))
+	checkSuccess(fields["TESTFLOAT"],Decimal("8.8"))
+	checkSuccess(fields["TESTDOUBLE"],Decimal("8.8"))
 	checkSuccess(fields["TESTDATE"],"2008:01:01")
 	checkSuccess(fields["TESTTIME"],"08:00:00")
 	checkSuccess(fields["TESTCHAR"],"testchar8                                         ")
 	checkSuccess(fields["TESTVARCHAR"],"testvarchar8")
-	print
+	print()
 
-	print "FIELD LENGTHS BY DICTIONARY: "
+	print("FIELD LENGTHS BY DICTIONARY: ")
 	fieldlengths=cur.getRowLengthsDictionary(0)
 	checkSuccess(fieldlengths["TESTINTEGER"],1)
 	checkSuccess(fieldlengths["TESTSMALLINT"],1)
@@ -395,7 +407,7 @@ def main():
 	checkSuccess(fieldlengths["TESTTIME"],8)
 	checkSuccess(fieldlengths["TESTCHAR"],50)
 	checkSuccess(fieldlengths["TESTVARCHAR"],12)
-	print
+	print()
 	fieldlengths=cur.getRowLengthsDictionary(7)
 	checkSuccess(fieldlengths["TESTINTEGER"],1)
 	checkSuccess(fieldlengths["TESTSMALLINT"],1)
@@ -407,79 +419,79 @@ def main():
 	checkSuccess(fieldlengths["TESTTIME"],8)
 	checkSuccess(fieldlengths["TESTCHAR"],50)
 	checkSuccess(fieldlengths["TESTVARCHAR"],12)
-	print
+	print()
 	
-	print "INDIVIDUAL SUBSTITUTIONS: "
+	print("INDIVIDUAL SUBSTITUTIONS: ")
 	cur.prepareQuery("select $(var1),'$(var2)','$(var3)' from rdb$database")
 	cur.substitution("var1",1)
 	cur.substitution("var2","hello")
 	cur.substitution("var3",10.5556,6,4)
 	checkSuccess(cur.executeQuery(),1)
-	print
+	print()
 
-	print "FIELDS: "
-	checkSuccess(cur.getField(0,0),"1")
+	print("FIELDS: ")
+	checkSuccess(cur.getField(0,0),1)
 	checkSuccess(cur.getField(0,1),"hello")
 	checkSuccess(cur.getField(0,2),"10.5556")
-	print
+	print()
 
-	print "ARRAY SUBSTITUTIONS: "
+	print("ARRAY SUBSTITUTIONS: ")
 	cur.prepareQuery("select $(var1),'$(var2)','$(var3)' from rdb$database")
 	cur.substitutions(["var1","var2","var3"],
 				[1,"hello",10.5556],[0,0,6],[0,0,4])
 	checkSuccess(cur.executeQuery(),1)
-	print
+	print()
 
-	print "FIELDS: "
-	checkSuccess(cur.getField(0,0),"1")
+	print("FIELDS: ")
+	checkSuccess(cur.getField(0,0),1)
 	checkSuccess(cur.getField(0,1),"hello")
 	checkSuccess(cur.getField(0,2),"10.5556")
-	print
+	print()
 
-	print "NULLS as Nones: "
+	print("NULLS as Nones: ")
 	cur.getNullsAsNone()
 	checkSuccess(cur.sendQuery("select 1,NULL,NULL from rdb$database"),1)
-	checkSuccess(cur.getField(0,0),"1")
+	checkSuccess(cur.getField(0,0),1)
 	checkSuccess(cur.getField(0,1),None)
 	checkSuccess(cur.getField(0,2),None)
 	cur.getNullsAsEmptyStrings()
 	checkSuccess(cur.sendQuery("select 1,NULL,NULL from rdb$database"),1)
-	checkSuccess(cur.getField(0,0),"1")
+	checkSuccess(cur.getField(0,0),1)
 	checkSuccess(cur.getField(0,1),"")
 	checkSuccess(cur.getField(0,2),"")
 	cur.getNullsAsNone()
-	print
+	print()
 
-	print "RESULT SET BUFFER SIZE: "
+	print("RESULT SET BUFFER SIZE: ")
 	checkSuccess(cur.getResultSetBufferSize(),0)
 	cur.setResultSetBufferSize(2)
 	checkSuccess(cur.sendQuery("select * from testtable order by testinteger"),1)
 	checkSuccess(cur.getResultSetBufferSize(),2)
-	print
+	print()
 	checkSuccess(cur.firstRowIndex(),0)
 	checkSuccess(cur.endOfResultSet(),0)
 	checkSuccess(cur.rowCount(),2)
-	checkSuccess(cur.getField(0,0),"1")
-	checkSuccess(cur.getField(1,0),"2")
-	checkSuccess(cur.getField(2,0),"3")
-	print
+	checkSuccess(cur.getField(0,0),1)
+	checkSuccess(cur.getField(1,0),2)
+	checkSuccess(cur.getField(2,0),3)
+	print()
 	checkSuccess(cur.firstRowIndex(),2)
 	checkSuccess(cur.endOfResultSet(),0)
 	checkSuccess(cur.rowCount(),4)
-	checkSuccess(cur.getField(6,0),"7")
-	checkSuccess(cur.getField(7,0),"8")
-	print
+	checkSuccess(cur.getField(6,0),7)
+	checkSuccess(cur.getField(7,0),8)
+	print()
 	checkSuccess(cur.firstRowIndex(),6)
 	checkSuccess(cur.endOfResultSet(),0)
 	checkSuccess(cur.rowCount(),8)
 	checkSuccess(cur.getField(8,0),None)
-	print
+	print()
 	checkSuccess(cur.firstRowIndex(),8)
 	checkSuccess(cur.endOfResultSet(),1)
 	checkSuccess(cur.rowCount(),8)
-	print
+	print()
 
-	print "DONT GET COLUMN INFO: "
+	print("DONT GET COLUMN INFO: ")
 	cur.dontGetColumnInfo()
 	checkSuccess(cur.sendQuery("select * from testtable order by testinteger"),1)
 	checkSuccess(cur.getColumnName(0),None)
@@ -490,62 +502,62 @@ def main():
 	checkSuccess(cur.getColumnName(0),"TESTINTEGER")
 	checkSuccess(cur.getColumnLength(0),4)
 	checkSuccess(cur.getColumnType(0),"INTEGER")
-	print
+	print()
 
-	print "SUSPENDED SESSION: "
+	print("SUSPENDED SESSION: ")
 	checkSuccess(cur.sendQuery("select * from testtable order by testinteger"),1)
 	cur.suspendResultSet()
 	checkSuccess(con.suspendSession(),1)
 	port=con.getConnectionPort()
 	socket=con.getConnectionSocket()
 	checkSuccess(con.resumeSession(port,socket),1)
-	print
-	checkSuccess(cur.getField(0,0),"1")
-	checkSuccess(cur.getField(1,0),"2")
-	checkSuccess(cur.getField(2,0),"3")
-	checkSuccess(cur.getField(3,0),"4")
-	checkSuccess(cur.getField(4,0),"5")
-	checkSuccess(cur.getField(5,0),"6")
-	checkSuccess(cur.getField(6,0),"7")
-	checkSuccess(cur.getField(7,0),"8")
-	print
+	print()
+	checkSuccess(cur.getField(0,0),1)
+	checkSuccess(cur.getField(1,0),2)
+	checkSuccess(cur.getField(2,0),3)
+	checkSuccess(cur.getField(3,0),4)
+	checkSuccess(cur.getField(4,0),5)
+	checkSuccess(cur.getField(5,0),6)
+	checkSuccess(cur.getField(6,0),7)
+	checkSuccess(cur.getField(7,0),8)
+	print()
 	checkSuccess(cur.sendQuery("select * from testtable order by testinteger"),1)
 	cur.suspendResultSet()
 	checkSuccess(con.suspendSession(),1)
 	port=con.getConnectionPort()
 	socket=con.getConnectionSocket()
 	checkSuccess(con.resumeSession(port,socket),1)
-	print
-	checkSuccess(cur.getField(0,0),"1")
-	checkSuccess(cur.getField(1,0),"2")
-	checkSuccess(cur.getField(2,0),"3")
-	checkSuccess(cur.getField(3,0),"4")
-	checkSuccess(cur.getField(4,0),"5")
-	checkSuccess(cur.getField(5,0),"6")
-	checkSuccess(cur.getField(6,0),"7")
-	checkSuccess(cur.getField(7,0),"8")
-	print
+	print()
+	checkSuccess(cur.getField(0,0),1)
+	checkSuccess(cur.getField(1,0),2)
+	checkSuccess(cur.getField(2,0),3)
+	checkSuccess(cur.getField(3,0),4)
+	checkSuccess(cur.getField(4,0),5)
+	checkSuccess(cur.getField(5,0),6)
+	checkSuccess(cur.getField(6,0),7)
+	checkSuccess(cur.getField(7,0),8)
+	print()
 	checkSuccess(cur.sendQuery("select * from testtable order by testinteger"),1)
 	cur.suspendResultSet()
 	checkSuccess(con.suspendSession(),1)
 	port=con.getConnectionPort()
 	socket=con.getConnectionSocket()
 	checkSuccess(con.resumeSession(port,socket),1)
-	print
-	checkSuccess(cur.getField(0,0),"1")
-	checkSuccess(cur.getField(1,0),"2")
-	checkSuccess(cur.getField(2,0),"3")
-	checkSuccess(cur.getField(3,0),"4")
-	checkSuccess(cur.getField(4,0),"5")
-	checkSuccess(cur.getField(5,0),"6")
-	checkSuccess(cur.getField(6,0),"7")
-	checkSuccess(cur.getField(7,0),"8")
-	print
+	print()
+	checkSuccess(cur.getField(0,0),1)
+	checkSuccess(cur.getField(1,0),2)
+	checkSuccess(cur.getField(2,0),3)
+	checkSuccess(cur.getField(3,0),4)
+	checkSuccess(cur.getField(4,0),5)
+	checkSuccess(cur.getField(5,0),6)
+	checkSuccess(cur.getField(6,0),7)
+	checkSuccess(cur.getField(7,0),8)
+	print()
 
-	print "SUSPENDED RESULT SET: "
+	print("SUSPENDED RESULT SET: ")
 	cur.setResultSetBufferSize(2)
 	checkSuccess(cur.sendQuery("select * from testtable order by testinteger"),1)
-	checkSuccess(cur.getField(2,0),"3")
+	checkSuccess(cur.getField(2,0),3)
 	id=cur.getResultSetId()
 	cur.suspendResultSet()
 	checkSuccess(con.suspendSession(),1)
@@ -553,24 +565,24 @@ def main():
 	socket=con.getConnectionSocket()
 	checkSuccess(con.resumeSession(port,socket),1)
 	checkSuccess(cur.resumeResultSet(id),1)
-	print
+	print()
 	checkSuccess(cur.firstRowIndex(),4)
 	checkSuccess(cur.endOfResultSet(),0)
 	checkSuccess(cur.rowCount(),6)
-	checkSuccess(cur.getField(7,0),"8")
-	print
+	checkSuccess(cur.getField(7,0),8)
+	print()
 	checkSuccess(cur.firstRowIndex(),6)
 	checkSuccess(cur.endOfResultSet(),0)
 	checkSuccess(cur.rowCount(),8)
 	checkSuccess(cur.getField(8,0),None)
-	print
+	print()
 	checkSuccess(cur.firstRowIndex(),8)
 	checkSuccess(cur.endOfResultSet(),1)
 	checkSuccess(cur.rowCount(),8)
 	cur.setResultSetBufferSize(0)
-	print
+	print()
 
-	print "CACHED RESULT SET: "
+	print("CACHED RESULT SET: ")
 	cur.cacheToFile("cachefile1")
 	cur.setCacheTtl(200)
 	checkSuccess(cur.sendQuery("select * from testtable order by testinteger"),1)
@@ -578,14 +590,14 @@ def main():
 	checkSuccess(filename,"cachefile1")
 	cur.cacheOff()
 	checkSuccess(cur.openCachedResultSet(filename),1)
-	checkSuccess(cur.getField(7,0),"8")
-	print
+	checkSuccess(cur.getField(7,0),8)
+	print()
 
-	print "COLUMN COUNT FOR CACHED RESULT SET: "
-	checkSuccess(cur.colCount(),11)
-	print
+	print("COLUMN COUNT FOR CACHED RESULT SET: ")
+	checkSuccess(cur.colCount(),12)
+	print()
 
-	print "COLUMN NAMES FOR CACHED RESULT SET: "
+	print("COLUMN NAMES FOR CACHED RESULT SET: ")
 	checkSuccess(cur.getColumnName(0),"TESTINTEGER")
 	checkSuccess(cur.getColumnName(1),"TESTSMALLINT")
 	checkSuccess(cur.getColumnName(2),"TESTDECIMAL")
@@ -609,9 +621,9 @@ def main():
 	checkSuccess(cols[8],"TESTCHAR")
 	checkSuccess(cols[9],"TESTVARCHAR")
 	checkSuccess(cols[10],"TESTTIMESTAMP")
-	print
+	print()
 
-	print "CACHED RESULT SET WITH RESULT SET BUFFER SIZE: "
+	print("CACHED RESULT SET WITH RESULT SET BUFFER SIZE: ")
 	cur.setResultSetBufferSize(2)
 	cur.cacheToFile("cachefile1")
 	cur.setCacheTtl(200)
@@ -620,37 +632,37 @@ def main():
 	checkSuccess(filename,"cachefile1")
 	cur.cacheOff()
 	checkSuccess(cur.openCachedResultSet(filename),1)
-	checkSuccess(cur.getField(7,0),"8")
+	checkSuccess(cur.getField(7,0),8)
 	checkSuccess(cur.getField(8,0),None)
 	cur.setResultSetBufferSize(0)
-	print
+	print()
 
-	print "FROM ONE CACHE FILE TO ANOTHER: "
+	print("FROM ONE CACHE FILE TO ANOTHER: ")
 	cur.cacheToFile("cachefile2")
 	checkSuccess(cur.openCachedResultSet("cachefile1"),1)
 	cur.cacheOff()
 	checkSuccess(cur.openCachedResultSet("cachefile2"),1)
-	checkSuccess(cur.getField(7,0),"8")
+	checkSuccess(cur.getField(7,0),8)
 	checkSuccess(cur.getField(8,0),None)
-	print
+	print()
 
-	print "FROM ONE CACHE FILE TO ANOTHER WITH RESULT SET BUFFER SIZE: "
+	print("FROM ONE CACHE FILE TO ANOTHER WITH RESULT SET BUFFER SIZE: ")
 	cur.setResultSetBufferSize(2)
 	cur.cacheToFile("cachefile2")
 	checkSuccess(cur.openCachedResultSet("cachefile1"),1)
 	cur.cacheOff()
 	checkSuccess(cur.openCachedResultSet("cachefile2"),1)
-	checkSuccess(cur.getField(7,0),"8")
+	checkSuccess(cur.getField(7,0),8)
 	checkSuccess(cur.getField(8,0),None)
 	cur.setResultSetBufferSize(0)
-	print
+	print()
 
-	print "CACHED RESULT SET WITH SUSPEND AND RESULT SET BUFFER SIZE: "
+	print("CACHED RESULT SET WITH SUSPEND AND RESULT SET BUFFER SIZE: ")
 	cur.setResultSetBufferSize(2)
 	cur.cacheToFile("cachefile1")
 	cur.setCacheTtl(200)
 	checkSuccess(cur.sendQuery("select * from testtable order by testinteger"),1)
-	checkSuccess(cur.getField(2,0),"3")
+	checkSuccess(cur.getField(2,0),3)
 	filename=cur.getCacheFileName()
 	checkSuccess(filename,"cachefile1")
 	id=cur.getResultSetId()
@@ -658,125 +670,125 @@ def main():
 	checkSuccess(con.suspendSession(),1)
 	port=con.getConnectionPort()
 	socket=con.getConnectionSocket()
-	print
+	print()
 	checkSuccess(con.resumeSession(port,socket),1)
 	checkSuccess(cur.resumeCachedResultSet(id,filename),1)
-	print
+	print()
 	checkSuccess(cur.firstRowIndex(),4)
 	checkSuccess(cur.endOfResultSet(),0)
 	checkSuccess(cur.rowCount(),6)
-	checkSuccess(cur.getField(7,0),"8")
-	print
+	checkSuccess(cur.getField(7,0),8)
+	print()
 	checkSuccess(cur.firstRowIndex(),6)
 	checkSuccess(cur.endOfResultSet(),0)
 	checkSuccess(cur.rowCount(),8)
 	checkSuccess(cur.getField(8,0),None)
-	print
+	print()
 	checkSuccess(cur.firstRowIndex(),8)
 	checkSuccess(cur.endOfResultSet(),1)
 	checkSuccess(cur.rowCount(),8)
 	cur.cacheOff()
-	print
+	print()
 	checkSuccess(cur.openCachedResultSet(filename),1)
-	checkSuccess(cur.getField(7,0),"8")
+	checkSuccess(cur.getField(7,0),8)
 	checkSuccess(cur.getField(8,0),None)
 	cur.setResultSetBufferSize(0)
-	print
+	print()
 
-	#print "COMMIT AND ROLLBACK: "
-	secondcon=PySQLRClient.sqlrconnection(sys.argv[1],
-				string.atoi(sys.argv[2]), 
-				sys.argv[3],sys.argv[4],sys.argv[5])
+	#print("COMMIT AND ROLLBACK: ")
+	secondcon=PySQLRClient.sqlrconnection("sqlrserver",9000,
+							"/tmp/test.socket",
+							"test","test")
 	secondcur=PySQLRClient.sqlrcursor(secondcon)
 	checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
-	checkSuccess(secondcur.getField(0,0),"0")
+	checkSuccess(secondcur.getField(0,0),0)
 	checkSuccess(con.commit(),1)
 	checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
-	checkSuccess(secondcur.getField(0,0),"8")
+	checkSuccess(secondcur.getField(0,0),8)
 	checkSuccess(con.autoCommitOn(),1)
-	checkSuccess(cur.sendQuery("insert into testtable values (10,10,10.1,10.1,10.1,10.1,'01-JAN-2010','10:00:00','testchar10','testvarchar10',NULL)"),1)
+	checkSuccess(cur.sendQuery("insert into testtable values (10,10,10.1,10.1,10.1,10.1,'01-JAN-2010','10:00:00','testchar10','testvarchar10',NULL,NULL)"),1)
 	checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
-	checkSuccess(secondcur.getField(0,0),"9")
+	checkSuccess(secondcur.getField(0,0),9)
 	checkSuccess(con.autoCommitOff(),1)
-	print
+	print()
 
-	print "ROW RANGE:"
+	print("ROW RANGE:")
 	checkSuccess(cur.sendQuery("select * from testtable order by testinteger"),1)
-	print
+	print()
 	rows=cur.getRowRange(0,5)
-	checkSuccess(rows[0][0],1);
-	checkSuccess(rows[0][1],1);
-	checkSuccess(rows[0][2],1.1);
-	checkSuccess(rows[0][3],1.1);
-	checkSuccess(rows[0][4],1.1);
-	checkSuccess(rows[0][5],1.1);
+	checkSuccess(rows[0][0],1)
+	checkSuccess(rows[0][1],1)
+	checkSuccess(rows[0][2],Decimal("1.1"))
+	checkSuccess(rows[0][3],Decimal("1.1"))
+	checkSuccess(rows[0][4],Decimal("1.1"))
+	checkSuccess(rows[0][5],Decimal("1.1"))
 	checkSuccess(rows[0][6],"2001:01:01")
 	checkSuccess(rows[0][7],"01:00:00")
 	checkSuccess(rows[0][8],"testchar1                                         ")
 	checkSuccess(rows[0][9],"testvarchar1")
-	print
-	checkSuccess(rows[1][0],2);
-	checkSuccess(rows[1][1],2);
-	checkSuccess(rows[1][2],2.2);
-	checkSuccess(rows[1][3],2.2);
-	checkSuccess(rows[1][4],2.2);
-	checkSuccess(rows[1][5],2.2);
+	print()
+	checkSuccess(rows[1][0],2)
+	checkSuccess(rows[1][1],2)
+	checkSuccess(rows[1][2],Decimal("2.2"))
+	checkSuccess(rows[1][3],Decimal("2.2"))
+	checkSuccess(rows[1][4],Decimal("2.2"))
+	checkSuccess(rows[1][5],Decimal("2.2"))
 	checkSuccess(rows[1][6],"2002:01:01")
 	checkSuccess(rows[1][7],"02:00:00")
 	checkSuccess(rows[1][8],"testchar2                                         ")
 	checkSuccess(rows[1][9],"testvarchar2")
-	print
-	checkSuccess(rows[2][0],3);
-	checkSuccess(rows[2][1],3);
-	checkSuccess(rows[2][2],3.3);
-	checkSuccess(rows[2][3],3.3);
-	checkSuccess(rows[2][4],3.3);
-	checkSuccess(rows[2][5],3.3);
+	print()
+	checkSuccess(rows[2][0],3)
+	checkSuccess(rows[2][1],3)
+	checkSuccess(rows[2][2],Decimal("3.3"))
+	checkSuccess(rows[2][3],Decimal("3.3"))
+	checkSuccess(rows[2][4],Decimal("3.3"))
+	checkSuccess(rows[2][5],Decimal("3.3"))
 	checkSuccess(rows[2][6],"2003:01:01")
 	checkSuccess(rows[2][7],"03:00:00")
 	checkSuccess(rows[2][8],"testchar3                                         ")
 	checkSuccess(rows[2][9],"testvarchar3")
-	print
-	checkSuccess(rows[3][0],4);
-	checkSuccess(rows[3][1],4);
-	checkSuccess(rows[3][2],4.4);
-	checkSuccess(rows[3][3],4.4);
-	checkSuccess(rows[3][4],4.4);
-	checkSuccess(rows[3][5],4.4);
+	print()
+	checkSuccess(rows[3][0],4)
+	checkSuccess(rows[3][1],4)
+	checkSuccess(rows[3][2],Decimal("4.4"))
+	checkSuccess(rows[3][3],Decimal("4.4"))
+	checkSuccess(rows[3][4],Decimal("4.4"))
+	checkSuccess(rows[3][5],Decimal("4.4"))
 	checkSuccess(rows[3][6],"2004:01:01")
 	checkSuccess(rows[3][7],"04:00:00")
 	checkSuccess(rows[3][8],"testchar4                                         ")
 	checkSuccess(rows[3][9],"testvarchar4")
-	print
-	checkSuccess(rows[4][0],5);
-	checkSuccess(rows[4][1],5);
-	checkSuccess(rows[4][2],5.5);
-	checkSuccess(rows[4][3],5.5);
-	checkSuccess(rows[4][4],5.5);
-	checkSuccess(rows[4][5],5.5);
+	print()
+	checkSuccess(rows[4][0],5)
+	checkSuccess(rows[4][1],5)
+	checkSuccess(rows[4][2],Decimal("5.5"))
+	checkSuccess(rows[4][3],Decimal("5.5"))
+	checkSuccess(rows[4][4],Decimal("5.5"))
+	checkSuccess(rows[4][5],Decimal("5.5"))
 	checkSuccess(rows[4][6],"2005:01:01")
 	checkSuccess(rows[4][7],"05:00:00")
 	checkSuccess(rows[4][8],"testchar5                                         ")
 	checkSuccess(rows[4][9],"testvarchar5")
-	print
-	checkSuccess(rows[5][0],6);
-	checkSuccess(rows[5][1],6);
-	checkSuccess(rows[5][2],6.6);
-	checkSuccess(rows[5][3],6.6);
-	checkSuccess(rows[5][4],6.6);
-	checkSuccess(rows[5][5],6.6);
+	print()
+	checkSuccess(rows[5][0],6)
+	checkSuccess(rows[5][1],6)
+	checkSuccess(rows[5][2],Decimal("6.6"))
+	checkSuccess(rows[5][3],Decimal("6.6"))
+	checkSuccess(rows[5][4],Decimal("6.6"))
+	checkSuccess(rows[5][5],Decimal("6.6"))
 	checkSuccess(rows[5][6],"2006:01:01")
 	checkSuccess(rows[5][7],"06:00:00")
 	checkSuccess(rows[5][8],"testchar6                                         ")
 	checkSuccess(rows[5][9],"testvarchar6")
-	print
+	print()
 
-	print "FINISHED SUSPENDED SESSION: "
+	print("FINISHED SUSPENDED SESSION: ")
 	checkSuccess(cur.sendQuery("select * from testtable order by testinteger"),1)
-	checkSuccess(cur.getField(4,0),"5")
-	checkSuccess(cur.getField(5,0),"6")
-	checkSuccess(cur.getField(6,0),"7")
-	checkSuccess(cur.getField(7,0),"8")
+	checkSuccess(cur.getField(4,0),5)
+	checkSuccess(cur.getField(5,0),6)
+	checkSuccess(cur.getField(6,0),7)
+	checkSuccess(cur.getField(7,0),8)
 	id=cur.getResultSetId()
 	cur.suspendResultSet()
 	checkSuccess(con.suspendSession(),1)
@@ -788,31 +800,31 @@ def main():
 	checkSuccess(cur.getField(5,0),None)
 	checkSuccess(cur.getField(6,0),None)
 	checkSuccess(cur.getField(7,0),None)
-	print
+	print()
 
 	# drop existing table
 	con.commit()
 	cur.sendQuery("delete from testtable")
 	con.commit()
-	print
+	print()
 
 	# invalid queries...
-	print "INVALID QUERIES: "
+	print("INVALID QUERIES: ")
 	checkSuccess(cur.sendQuery("select * from testtable1 order by testinteger"),0)
 	checkSuccess(cur.sendQuery("select * from testtable1 order by testinteger"),0)
 	checkSuccess(cur.sendQuery("select * from testtable1 order by testinteger"),0)
 	checkSuccess(cur.sendQuery("select * from testtable1 order by testinteger"),0)
-	print
+	print()
 	checkSuccess(cur.sendQuery("insert into testtable1 values (1,2,3,4)"),0)
 	checkSuccess(cur.sendQuery("insert into testtable1 values (1,2,3,4)"),0)
 	checkSuccess(cur.sendQuery("insert into testtable1 values (1,2,3,4)"),0)
 	checkSuccess(cur.sendQuery("insert into testtable1 values (1,2,3,4)"),0)
-	print
+	print()
 	checkSuccess(cur.sendQuery("create table testtable"),0)
 	checkSuccess(cur.sendQuery("create table testtable"),0)
 	checkSuccess(cur.sendQuery("create table testtable"),0)
 	checkSuccess(cur.sendQuery("create table testtable"),0)
-	print
+	print()
 
 if __name__ == "__main__":
 	main()
