@@ -11,22 +11,16 @@ def checkSuccess(value,success)
 	if value==success
 		print "success "
 	else
+		print value , " != " , success, " "
 		print "failure "
-		exit(0)
+		exit(1)
 	end
 end
 
 
 
-	# usage...
-if ARGV.length < 5
-	print "usage: db2.rb host port socket user password\n"
-	exit(0)
-end
-
 # instantiation
-con=SQLRConnection.new(ARGV[0],ARGV[1].to_i, 
-				ARGV[2],ARGV[3],ARGV[4],0,1)
+con=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket","test","test",0,1)
 cur=SQLRCursor.new(con)
 
 # get database type
@@ -104,9 +98,9 @@ cur.sendQuery("drop procedure testproc");
 checkSuccess(cur.sendQuery("create procedure testproc(in invar int, out outvar int) language sql begin set outvar = invar; end"),1)
 cur.prepareQuery("call testproc(?,?)")
 cur.inputBind("1",5)
-cur.defineOutputBind("2",10)
+cur.defineOutputBindString("2",10)
 checkSuccess(cur.executeQuery(),1)
-checkSuccess(cur.getOutputBind("2"),"5")
+checkSuccess(cur.getOutputBindString("2"),"5")
 checkSuccess(cur.sendQuery("drop procedure testproc"),1)
 print "\n"
 
