@@ -11,22 +11,16 @@ def checkSuccess(value,success)
 	if value==success
 		print "success "
 	else
+		print value , " != " , success, " "
 		print "failure "
-		exit(0)
+		exit(1)
 	end
 end
 
 
 
-# usage...
-if ARGV.length < 5
-	print "usage: firebird.rb host port socket user password\n"
-	exit(0)
-end
-
 # instantiation
-con=SQLRConnection.new(ARGV[0],ARGV[1].to_i, 
-				ARGV[2],ARGV[3],ARGV[4],0,1)
+con=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket","test","test",0,1)
 cur=SQLRCursor.new(con)
 
 # get database type
@@ -45,12 +39,12 @@ con.commit()
 
 
 print "INSERT: \n"
-checkSuccess(cur.sendQuery("insert into testtable values (1,1,1.1,1.1,1.1,1.1,'01-JAN-2001','01:00:00','testchar1','testvarchar1',NULL)"),1)
+checkSuccess(cur.sendQuery("insert into testtable values (1,1,1.1,1.1,1.1,1.1,'01-JAN-2001','01:00:00','testchar1','testvarchar1',NULL,NULL)"),1)
 print "\n"
 
 
 print "BIND BY POSITION: \n"
-cur.prepareQuery("insert into testtable values (?,?,?,?,?,?,?,?,?,?,?)")
+cur.prepareQuery("insert into testtable values (?,?,?,?,?,?,?,?,?,?,?,NULL)")
 checkSuccess(cur.countBindVariables(),11)
 cur.inputBind("1",2)
 cur.inputBind("2",2)
@@ -91,10 +85,10 @@ checkSuccess(cur.executeQuery(),1)
 print "\n"
 
 print "INSERT: \n"
-checkSuccess(cur.sendQuery("insert into testtable values (5,5,5.5,5.5,5.5,5.5,'01-JAN-2005','05:00:00','testchar5','testvarchar5',NULL)"),1)
-checkSuccess(cur.sendQuery("insert into testtable values (6,6,6.6,6.6,6.6,6.6,'01-JAN-2006','06:00:00','testchar6','testvarchar6',NULL)"),1)
-checkSuccess(cur.sendQuery("insert into testtable values (7,7,7.7,7.7,7.7,7.7,'01-JAN-2007','07:00:00','testchar7','testvarchar7',NULL)"),1)
-checkSuccess(cur.sendQuery("insert into testtable values (8,8,8.8,8.8,8.8,8.8,'01-JAN-2008','08:00:00','testchar8','testvarchar8',NULL)"),1)
+checkSuccess(cur.sendQuery("insert into testtable values (5,5,5.5,5.5,5.5,5.5,'01-JAN-2005','05:00:00','testchar5','testvarchar5',NULL,NULL)"),1)
+checkSuccess(cur.sendQuery("insert into testtable values (6,6,6.6,6.6,6.6,6.6,'01-JAN-2006','06:00:00','testchar6','testvarchar6',NULL,NULL)"),1)
+checkSuccess(cur.sendQuery("insert into testtable values (7,7,7.7,7.7,7.7,7.7,'01-JAN-2007','07:00:00','testchar7','testvarchar7',NULL,NULL)"),1)
+checkSuccess(cur.sendQuery("insert into testtable values (8,8,8.8,8.8,8.8,8.8,'01-JAN-2008','08:00:00','testchar8','testvarchar8',NULL,NULL)"),1)
 print "\n"
 
 print "AFFECTED ROWS: \n"
@@ -102,12 +96,26 @@ checkSuccess(cur.affectedRows(),0)
 print "\n"
 
 print "STORED PROCEDURE: \n"
-checkSuccess(cur.sendQuery("create procedure testproc(invar integer) returns (outvar integer) as begin outvar = invar; suspend; end"),1);
-cur.prepareQuery("select * from testproc(?)");
-cur.inputBind("1",5);
-checkSuccess(cur.executeQuery(),1);
-checkSuccess(cur.getField(0,0),"5");
-checkSuccess(cur.sendQuery("drop procedure testproc"),1);
+cur.prepareQuery("select * from testproc(?,?,?,NULL)")
+cur.inputBind("1",1)
+cur.inputBind("2",1.1,2,1)
+cur.inputBind("3","hello")
+checkSuccess(cur.executeQuery(),1)
+checkSuccess(cur.getField(0,0),"1")
+checkSuccess(cur.getField(0,1),"1.1000")
+checkSuccess(cur.getField(0,2),"hello")
+cur.prepareQuery("execute procedure testproc ?, ?, ?, NULL")
+cur.inputBind("1",1)
+cur.inputBind("2",1.1,2,1)
+cur.inputBind("3","hello")
+cur.defineOutputBindInteger("1")
+cur.defineOutputBindDouble("2")
+cur.defineOutputBindString("3",20)
+cur.defineOutputBindBlob("4")
+checkSuccess(cur.executeQuery(),1)
+checkSuccess(cur.getOutputBindInteger("1"),1)
+#checkSuccess(cur.getOutputBindDouble("2"),1.1)
+checkSuccess(cur.getOutputBindString("3"),"hello               ")
 print "\n"
 
 print "SELECT: \n"
@@ -115,7 +123,7 @@ checkSuccess(cur.sendQuery("select * from testtable order by testinteger"),1)
 print "\n"
 
 print "COLUMN COUNT: \n"
-checkSuccess(cur.colCount(),11)
+checkSuccess(cur.colCount(),12)
 print "\n"
 
 print "COLUMN NAMES: \n"
@@ -584,7 +592,7 @@ checkSuccess(cur.getField(7,0),"8")
 print "\n"
 
 print "COLUMN COUNT FOR CACHED RESULT SET: \n"
-checkSuccess(cur.colCount(),11)
+checkSuccess(cur.colCount(),12)
 print "\n"
 
 print "COLUMN NAMES FOR CACHED RESULT SET: \n"
@@ -686,9 +694,8 @@ cur.setResultSetBufferSize(0)
 print "\n"
 
 print "COMMIT AND ROLLBACK: \n"
-secondcon=SQLRConnection.new(ARGV[0],
-			ARGV[1].to_i, 
-			ARGV[2],ARGV[3],ARGV[4],0,1)
+secondcon=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket",
+						"test","test",0,1)
 secondcur=SQLRCursor.new(secondcon)
 checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
 checkSuccess(secondcur.getField(0,0),"0")
@@ -696,7 +703,7 @@ checkSuccess(con.commit(),1)
 checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
 checkSuccess(secondcur.getField(0,0),"8")
 checkSuccess(con.autoCommitOn(),1)
-checkSuccess(cur.sendQuery("insert into testtable values (10,10,10.1,10.1,10.1,10.1,'01-JAN-2010','10:00:00','testchar10','testvarchar10',NULL)"),1)
+checkSuccess(cur.sendQuery("insert into testtable values (10,10,10.1,10.1,10.1,10.1,'01-JAN-2010','10:00:00','testchar10','testvarchar10',NULL,NULL)"),1)
 checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
 checkSuccess(secondcur.getField(0,0),"9")
 checkSuccess(con.autoCommitOff(),1)
