@@ -11,24 +11,19 @@ def checkSuccess(value,success)
 	if value==success
 		print "success "
 	else
+		print value , " != " , success, " "
 		print "failure "
-		exit(0)
+		exit(1)
 	end
 end
 
 
 
 
-# usage...
-if ARGV.length < 5
-	print "usage: mysql.rb host port socket user password\n"
-	exit(0)
-end
-
 
 # instantiation
-con=SQLRConnection.new(ARGV[0],ARGV[1].to_i, 
-				ARGV[2],ARGV[3],ARGV[4],0,1)
+con=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket",
+						"test","test",0,1)
 cur=SQLRCursor.new(con)
 
 # get database type
@@ -59,82 +54,82 @@ print "AFFECTED ROWS: \n"
 checkSuccess(cur.affectedRows(),1)
 print "\n"
 
-print "BIND BY NAME: \n"
-cur.prepareQuery("insert into testdb.testtable values (:var1,:var2,:var3,:var4,:var5,:var6,:var7,:var8,:var9,:var10,:var11,:var12,:var13,:var14,:var15,:var16,:var17,:var18,NULL)")
+print "BIND BY POSITION: \n"
+cur.prepareQuery("insert into testdb.testtable values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,NULL)")
 checkSuccess(cur.countBindVariables(),18)
-cur.inputBind("var1",5)
-cur.inputBind("var2",5)
-cur.inputBind("var3",5)
-cur.inputBind("var4",5)
-cur.inputBind("var5",5)
-cur.inputBind("var6",5.1,2,1)
-cur.inputBind("var7",5.1,2,1)
-cur.inputBind("var8",5.1,2,1)
-cur.inputBind("var9","2005-01-01")
-cur.inputBind("var10","05:00:00")
-cur.inputBind("var11","2005-01-01 05:00:00")
-cur.inputBind("var12","2005")
-cur.inputBind("var13","char5")
-cur.inputBind("var14","text5")
-cur.inputBind("var15","varchar5")
-cur.inputBind("var16","tinytext5")
-cur.inputBind("var17","mediumtext5")
-cur.inputBind("var18","longtext5")
+cur.inputBind("1",5)
+cur.inputBind("2",5)
+cur.inputBind("3",5)
+cur.inputBind("4",5)
+cur.inputBind("5",5)
+cur.inputBind("6",5.1,2,1)
+cur.inputBind("7",5.1,2,1)
+cur.inputBind("8",5.1,2,1)
+cur.inputBind("9","2005-01-01")
+cur.inputBind("10","05:00:00")
+cur.inputBind("11","2005-01-01 05:00:00")
+cur.inputBind("12","2005")
+cur.inputBind("13","char5")
+cur.inputBind("14","text5")
+cur.inputBind("15","varchar5")
+cur.inputBind("16","tinytext5")
+cur.inputBind("17","mediumtext5")
+cur.inputBind("18","longtext5")
 checkSuccess(cur.executeQuery(),1)
 cur.clearBinds()
-cur.inputBind("var1",6)
-cur.inputBind("var2",6)
-cur.inputBind("var3",6)
-cur.inputBind("var4",6)
-cur.inputBind("var5",6)
-cur.inputBind("var6",6.1,2,1)
-cur.inputBind("var7",6.1,2,1)
-cur.inputBind("var8",6.1,2,1)
-cur.inputBind("var9",'2006-01-01')
-cur.inputBind("var10",'06:00:00')
-cur.inputBind("var11",'2006-01-01 06:00:00')
-cur.inputBind("var12",'2006')
-cur.inputBind("var13",'char6')
-cur.inputBind("var14",'text6')
-cur.inputBind("var15",'varchar6')
-cur.inputBind("var16",'tinytext6')
-cur.inputBind("var17",'mediumtext6')
-cur.inputBind("var18",'longtext6')
+cur.inputBind("1",6)
+cur.inputBind("2",6)
+cur.inputBind("3",6)
+cur.inputBind("4",6)
+cur.inputBind("5",6)
+cur.inputBind("6",6.1,2,1)
+cur.inputBind("7",6.1,2,1)
+cur.inputBind("8",6.1,2,1)
+cur.inputBind("9",'2006-01-01')
+cur.inputBind("10",'06:00:00')
+cur.inputBind("11",'2006-01-01 06:00:00')
+cur.inputBind("12",'2006')
+cur.inputBind("13",'char6')
+cur.inputBind("14",'text6')
+cur.inputBind("15",'varchar6')
+cur.inputBind("16",'tinytext6')
+cur.inputBind("17",'mediumtext6')
+cur.inputBind("18",'longtext6')
 checkSuccess(cur.executeQuery(),1)
 print "\n"
 
-print "ARRAY OF BINDS BY NAME: \n"
+print "ARRAY OF BINDS BY POSITION: \n"
 cur.clearBinds()
-cur.inputBinds(["var1","var2","var3","var4","var5","var6",
-		"var7","var8","var9","var10","var11","var12",
-		"var13","var14","var15",
-		"var16","var17","var18",],
+cur.inputBinds(["1","2","3","4","5","6",
+		"7","8","9","10","11","12",
+		"13","14","15",
+		"16","17","18",],
 	[7,7,7,7,7,7.1,7.1,7.1,'2007-01-01','07:00:00','2007-01-01 07:00:00','2007','char7','text7','varchar7','tinytext7','mediumtext7','longtext7'],
 	[0,0,0,0,0,2,2,2,0,0,0,0,0,0,0,0,0,0],
 	[0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0])
 checkSuccess(cur.executeQuery(),1)
 print "\n"
 
-print "BIND BY NAME WITH VALIDATION: \n"
+print "BIND BY POSITION WITH VALIDATION: \n"
 cur.clearBinds()
-cur.inputBind("var1",8)
-cur.inputBind("var2",8)
-cur.inputBind("var3",8)
-cur.inputBind("var4",8)
-cur.inputBind("var5",8)
-cur.inputBind("var6",8.1,2,1)
-cur.inputBind("var7",8.1,2,1)
-cur.inputBind("var8",8.1,2,1)
-cur.inputBind("var9",'2008-01-01')
-cur.inputBind("var10",'08:00:00')
-cur.inputBind("var11",'2008-01-01 08:00:00')
-cur.inputBind("var12",'2008')
-cur.inputBind("var13",'char8')
-cur.inputBind("var14",'text8')
-cur.inputBind("var15",'varchar8')
-cur.inputBind("var16",'tinytext8')
-cur.inputBind("var17",'mediumtext8')
-cur.inputBind("var18",'longtext8')
+cur.inputBind("1",8)
+cur.inputBind("2",8)
+cur.inputBind("3",8)
+cur.inputBind("4",8)
+cur.inputBind("5",8)
+cur.inputBind("6",8.1,2,1)
+cur.inputBind("7",8.1,2,1)
+cur.inputBind("8",8.1,2,1)
+cur.inputBind("9",'2008-01-01')
+cur.inputBind("10",'08:00:00')
+cur.inputBind("11",'2008-01-01 08:00:00')
+cur.inputBind("12",'2008')
+cur.inputBind("13",'char8')
+cur.inputBind("14",'text8')
+cur.inputBind("15",'varchar8')
+cur.inputBind("16",'tinytext8')
+cur.inputBind("17",'mediumtext8')
+cur.inputBind("18",'longtext8')
 cur.validateBinds()
 checkSuccess(cur.executeQuery(),1)
 print "\n"
@@ -202,7 +197,7 @@ checkSuccess(cur.getColumnType(8),"DATE")
 checkSuccess(cur.getColumnType(9),"TIME")
 checkSuccess(cur.getColumnType(10),"DATETIME")
 checkSuccess(cur.getColumnType(11),"YEAR")
-checkSuccess(cur.getColumnType(12),"CHAR")
+checkSuccess(cur.getColumnType(12),"STRING")
 checkSuccess(cur.getColumnType(13),"BLOB")
 checkSuccess(cur.getColumnType(14),"CHAR")
 checkSuccess(cur.getColumnType(15),"TINYBLOB")
@@ -221,7 +216,7 @@ checkSuccess(cur.getColumnType("testdate"),"DATE")
 checkSuccess(cur.getColumnType("testtime"),"TIME")
 checkSuccess(cur.getColumnType("testdatetime"),"DATETIME")
 checkSuccess(cur.getColumnType("testyear"),"YEAR")
-checkSuccess(cur.getColumnType("testchar"),"CHAR")
+checkSuccess(cur.getColumnType("testchar"),"STRING")
 checkSuccess(cur.getColumnType("testtext"),"BLOB")
 checkSuccess(cur.getColumnType("testvarchar"),"CHAR")
 checkSuccess(cur.getColumnType("testtinytext"),"TINYBLOB")
@@ -243,7 +238,7 @@ checkSuccess(cur.getColumnLength(8),3)
 checkSuccess(cur.getColumnLength(9),3)
 checkSuccess(cur.getColumnLength(10),8)
 checkSuccess(cur.getColumnLength(11),1)
-checkSuccess(cur.getColumnLength(12),41)
+checkSuccess(cur.getColumnLength(12),40)
 checkSuccess(cur.getColumnLength(13),65535)
 checkSuccess(cur.getColumnLength(14),41)
 checkSuccess(cur.getColumnLength(15),255)
@@ -262,7 +257,7 @@ checkSuccess(cur.getColumnLength("testdate"),3)
 checkSuccess(cur.getColumnLength("testtime"),3)
 checkSuccess(cur.getColumnLength("testdatetime"),8)
 checkSuccess(cur.getColumnLength("testyear"),1)
-checkSuccess(cur.getColumnLength("testchar"),41)
+checkSuccess(cur.getColumnLength("testchar"),40)
 checkSuccess(cur.getColumnLength("testtext"),65535)
 checkSuccess(cur.getColumnLength("testvarchar"),41)
 checkSuccess(cur.getColumnLength("testtinytext"),255)
@@ -906,21 +901,25 @@ cur.setResultSetBufferSize(0)
 print "\n"
 
 print "COMMIT AND ROLLBACK: \n"
-secondcon=SQLRConnection.new(ARGV[0],
-			ARGV[1].to_i, 
-			ARGV[2],ARGV[3],ARGV[4],0,1)
+# Note: Mysql's default isolation level is repeatable-read,
+# not read-committed like most other db's.  Both sessions must
+# commit to see the changes that each other has made.
+secondcon=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket",
+						"test","test",0,1)
 secondcur=SQLRCursor.new(secondcon)
 checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
-checkSuccess(secondcur.getField(0,0),"8")
+checkSuccess(secondcur.getField(0,0),"0")
 checkSuccess(con.commit(),1)
 checkSuccess(secondcon.commit(),1)
 checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
 checkSuccess(secondcur.getField(0,0),"8")
 checkSuccess(con.autoCommitOn(),1)
 checkSuccess(cur.sendQuery("insert into testdb.testtable values (10,10,10,10,10,10.1,10.1,10.1,'2010-01-01','10:00:00','2010-01-01 10:00:00','2010','char10','text10','varchar10','tinytext10','mediumtext10','longtext10',NULL)"),1)
+checkSuccess(secondcon.commit(),1)
 checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
 checkSuccess(secondcur.getField(0,0),"9")
 checkSuccess(con.autoCommitOff(),1)
+secondcon.commit()
 print "\n"
 
 print "FINISHED SUSPENDED SESSION: \n"
