@@ -11,22 +11,17 @@ def checkSuccess(value,success)
 	if value==success
 		print "success "
 	else
+		print value , " != " , success, " "
 		print "failure "
-		exit(0)
+		exit(1)
 	end
 end
 
 
 
-# usage...
-if ARGV.length < 5
-	print "usage: sqlite.rb host port socket user password\n"
-	exit(0)
-end
-
 # instantiation
-con=SQLRConnection.new(ARGV[0],ARGV[1].to_i, 
-				ARGV[2],ARGV[3],ARGV[4],0,1)
+con=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket",
+						"test","test",0,1);
 cur=SQLRCursor.new(con)
 
 # get database type
@@ -117,14 +112,14 @@ checkSuccess(cols[3],"testvarchar")
 print "\n"
 
 print "COLUMN TYPES: \n"
-checkSuccess(cur.getColumnType(0),"UNKNOWN")
-checkSuccess(cur.getColumnType('testint'),"UNKNOWN")
-checkSuccess(cur.getColumnType(1),"UNKNOWN")
-checkSuccess(cur.getColumnType('testfloat'),"UNKNOWN")
-checkSuccess(cur.getColumnType(2),"UNKNOWN")
-checkSuccess(cur.getColumnType('testchar'),"UNKNOWN")
-checkSuccess(cur.getColumnType(3),"UNKNOWN")
-checkSuccess(cur.getColumnType('testvarchar'),"UNKNOWN")
+checkSuccess(cur.getColumnType(0),"INTEGER")
+checkSuccess(cur.getColumnType('testint'),"INTEGER")
+checkSuccess(cur.getColumnType(1),"FLOAT")
+checkSuccess(cur.getColumnType('testfloat'),"FLOAT")
+checkSuccess(cur.getColumnType(2),"STRING")
+checkSuccess(cur.getColumnType('testchar'),"STRING")
+checkSuccess(cur.getColumnType(3),"STRING")
+checkSuccess(cur.getColumnType('testvarchar'),"STRING")
 print "\n"
 
 print "COLUMN LENGTH: \n"
@@ -154,7 +149,7 @@ checkSuccess(cur.rowCount(),8)
 print "\n"
 
 print "TOTAL ROWS: \n"
-checkSuccess(cur.totalRows(),8)
+checkSuccess(cur.totalRows(),0)
 print "\n"
 
 print "FIRST ROW INDEX: \n"
@@ -344,7 +339,7 @@ cur.getColumnInfo()
 checkSuccess(cur.sendQuery("select * from testtable order by testint"),1)
 checkSuccess(cur.getColumnName(0),"testint")
 checkSuccess(cur.getColumnLength(0),0)
-checkSuccess(cur.getColumnType(0),"UNKNOWN")
+checkSuccess(cur.getColumnType(0),"INTEGER")
 print "\n"
 
 print "SUSPENDED SESSION: \n"
@@ -525,9 +520,8 @@ cur.setResultSetBufferSize(0)
 print "\n"
 
 print "COMMIT AND ROLLBACK: \n"
-secondcon=SQLRConnection.new(ARGV[0],
-			ARGV[1].to_i, 
-			ARGV[2],ARGV[3],ARGV[4],0,1)
+secondcon=SQLRConnection.new("sqlrserver",9000,"/tmp/test.socket",
+						"test","test",0,1);
 secondcur=SQLRCursor.new(secondcon)
 checkSuccess(secondcur.sendQuery("select count(*) from testtable"),1)
 checkSuccess(secondcur.getField(0,0),"0")
